(in-package :cl-info)
(let (
(deffn-defvr-pairs '(
; CONTENT: (<INDEX TOPIC> . (<FILENAME> <BYTE OFFSET> <LENGTH IN CHARACTERS> <NODE NAME>))
("!" . ("maxima.info-1" 88719 2475 "Operadores Geral"))
("!!" . ("maxima.info-1" 91233 764 "Operadores Geral"))
("#" . ("maxima.info-1" 92018 1034 "Operadores Geral"))
("%" . ("maxima.info-1" 281966 621 "Funções e Variáveis Definidas para Entrada e Saída"))
("%%" . ("maxima.info-1" 282603 1177 "Funções e Variáveis Definidas para Entrada e Saída"))
("%e" . ("maxima.info-2" 76422 216 "Funções e Variáveis Definidas para Constantes"))
("%e_to_numlog" . ("maxima.info-2" 80276 384 "Funções e Variáveis Definidas para Logarítmos"))
("%edispflag" . ("maxima.info-1" 283811 221 "Funções e Variáveis Definidas para Entrada e Saída"))
("%emode" . ("maxima.info-1" 184109 578 "Funções e Variáveis Definidas para Expressões"))
("%enumer" . ("maxima.info-1" 184700 342 "Funções e Variáveis Definidas para Expressões"))
("%gamma" . ("maxima.info-3" 260039 84 "Funções e Variáveis Definidas para Teoria dos Números"))
("%i" . ("maxima.info-2" 76645 72 "Funções e Variáveis Definidas para Constantes"))
("%phi" . ("maxima.info-2" 77083 2415 "Funções e Variáveis Definidas para Constantes"))
("%pi" . ("maxima.info-2" 79517 202 "Funções e Variáveis Definidas para Constantes"))
("%rnum_list" . ("maxima.info-2" 200779 371 "Funções e Variáveis Definidas para Equações"))
("%th" . ("maxima.info-1" 284038 891 "Funções e Variáveis Definidas para Entrada e Saída"))
("%unitexpand" . ("maxima.info-6" 199572 141 "Funções e Variáveis Definidas para Units"))
("'" . ("maxima.info-1" 40222 3115 "Introdução a Linha de Comando"))
("'%c'" . ("maxima.info-5" 3125 88 "Funções e Variáveis Definidas para contrib_ode"))
("'%k1'" . ("maxima.info-5" 3218 103 "Funções e Variáveis Definidas para contrib_ode"))
("'%k2'" . ("maxima.info-5" 3326 102 "Funções e Variáveis Definidas para contrib_ode"))
("''" . ("maxima.info-1" 43414 5983 "Introdução a Linha de Comando"))
("'method'" . ("maxima.info-5" 2994 126 "Funções e Variáveis Definidas para contrib_ode"))
("*" . ("maxima.info-1" 79888 7440 "Operadores Aritméticos"))
("**" . ("maxima.info-1" 87500 808 "Operadores Aritméticos"))
("+" . ("maxima.info-1" 79871 7457 "Operadores Aritméticos"))
("-" . ("maxima.info-1" 79872 7456 "Operadores Aritméticos"))
("." . ("maxima.info-1" 93074 481 "Operadores Geral"))
("/" . ("maxima.info-1" 79904 7424 "Operadores Aritméticos"))
(":" . ("maxima.info-1" 93564 87 "Operadores Geral"))
("::" . ("maxima.info-1" 93655 219 "Operadores Geral"))
("::=" . ("maxima.info-1" 93881 3763 "Operadores Geral"))
(":=" . ("maxima.info-1" 97737 107 "Operadores Geral"))
("<" . ("maxima.info-1" 88497 68 "Operadores Relacionais"))
("<=" . ("maxima.info-1" 88498 67 "Operadores Relacionais"))
("=" . ("maxima.info-1" 97851 4209 "Operadores Geral"))
(">" . ("maxima.info-1" 88531 34 "Operadores Relacionais"))
(">=" . ("maxima.info-1" 88514 51 "Operadores Relacionais"))
("?" . ("maxima.info-1" 284961 607 "Funções e Variáveis Definidas para Entrada e Saída"))
("??" . ("maxima.info-1" 285592 306 "Funções e Variáveis Definidas para Entrada e Saída"))
("Adição" . ("maxima.info-1" 79872 7456 "Operadores Aritméticos"))
("Ajuda" . ("maxima.info-1" 35682 2879 "Funções e Variáveis Definidas para Ajuda"))
("AntiDifference" . ("maxima.info-6" 202413 197 "Funções e Variáveis Definidas para zeilberger"))
("Base do logarítmo natural" . ("maxima.info-2" 76423 215 "Funções e Variáveis Definidas para Constantes"))
("Conjunção lógica" . ("maxima.info-1" 102124 1065 "Operadores Geral"))
("Constante de Euler" . ("maxima.info-2" 76423 215 "Funções e Variáveis Definidas para Constantes"))
("Constante de Euler-Mascheroni" . ("maxima.info-3" 260040 83 "Funções e Variáveis Definidas para Teoria dos Números"))
("Consulta documentação" . ("maxima.info-1" 284962 606 "Funções e Variáveis Definidas para Entrada e Saída"))
("Consulta documentação (busca inexata)" . ("maxima.info-1" 285593 305 "Funções e Variáveis Definidas para Entrada e Saída"))
("Contração com um vetor" . ("maxima.info-3" 135289 1388 "Funções e Variáveis Definidas para itensor"))
("DETCOEF" . ("maxima.info-6" 457 473 "Funções e Variáveis Definidas para lsquares"))
("Delimitador de Lista" . ("maxima.info-3" 52953 1112 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("Disjunção lógica" . ("maxima.info-1" 103218 1050 "Operadores Geral"))
("Divisão" . ("maxima.info-1" 79920 7408 "Operadores Aritméticos"))
("Duplo fatorial" . ("maxima.info-1" 91234 763 "Operadores Geral"))
("Entrada anterior" . ("maxima.info-1" 280427 1520 "Funções e Variáveis Definidas para Entrada e Saída"))
("Exponenciação" . ("maxima.info-1" 79936 7392 "Operadores Aritméticos"))
("Expressão de entrada atual" . ("maxima.info-1" 278528 1869 "Funções e Variáveis Definidas para Entrada e Saída"))
("Fatorial" . ("maxima.info-1" 88720 2474 "Operadores Geral"))
("GGFCFMAX" . ("maxima.info-5" 254265 559 "Funções e Variáveis Definidas para ggf"))
("GGFINFINITY" . ("maxima.info-5" 253623 615 "Funções e Variáveis Definidas para ggf"))
("Gosper" . ("maxima.info-6" 202616 257 "Funções e Variáveis Definidas para zeilberger"))
("GosperSum" . ("maxima.info-6" 202881 2106 "Funções e Variáveis Definidas para zeilberger"))
("Igual (igualdade sintática)" . ("maxima.info-1" 97852 4208 "Operadores Geral"))
("Infinito Complexo" . ("maxima.info-2" 76927 71 "Funções e Variáveis Definidas para Constantes"))
("Infinito negativo" . ("maxima.info-2" 77000 82 "Funções e Variáveis Definidas para Constantes"))
("Infinito positivo real" . ("maxima.info-2" 76859 66 "Funções e Variáveis Definidas para Constantes"))
("JF" . ("maxima.info-5" 66568 825 "Funções e Variáveis Definidas para diag"))
("Lindstedt" . ("maxima.info-5" 295688 1393 "Funções e Variáveis Definidas para lindstedt"))
("MAX_ORD" . ("maxima.info-6" 206151 124 "Funções e Variáveis Definidas para zeilberger"))
("Maior que" . ("maxima.info-1" 88548 17 "Operadores Relacionais"))
("Maior que ou igual a" . ("maxima.info-1" 88531 34 "Operadores Relacionais"))
("Menor que" . ("maxima.info-1" 88498 67 "Operadores Relacionais"))
("Menor que ou igual a" . ("maxima.info-1" 88514 51 "Operadores Relacionais"))
("Menos infinito" . ("maxima.info-2" 77000 82 "Funções e Variáveis Definidas para Constantes"))
("ModeMatrix" . ("maxima.info-5" 70847 1440 "Funções e Variáveis Definidas para diag"))
("Multiplicação" . ("maxima.info-1" 79904 7424 "Operadores Aritméticos"))
("Multiplicação não comutativa matricial" . ("maxima.info-1" 93075 480 "Operadores Geral"))
("N'ésima saída anterior" . ("maxima.info-1" 284039 890 "Funções e Variáveis Definidas para Entrada e Saída"))
("Negação lógica" . ("maxima.info-1" 104297 586 "Operadores Geral"))
("Não igual (desigualdade sintática)" . ("maxima.info-1" 92019 1033 "Operadores Geral"))
("Número áureo" . ("maxima.info-2" 77084 2414 "Funções e Variáveis Definidas para Constantes"))
("Operador Apóstrofo" . ("maxima.info-1" 40223 3114 "Introdução a Linha de Comando"))
("Operador apóstrofo-apóstrofo" . ("maxima.info-1" 43415 5982 "Introdução a Linha de Comando"))
("Operador de Subscrito" . ("maxima.info-3" 52953 1112 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("Operador de atribuição" . ("maxima.info-1" 93565 86 "Operadores Geral"))
("Operador de atribuição (avalia o lado esquerdo da igualdade)" . ("maxima.info-1" 93656 218 "Operadores Geral"))
("Operador de definição de função" . ("maxima.info-1" 97738 106 "Operadores Geral"))
("Operador de definição de função de macro" . ("maxima.info-1" 93882 3762 "Operadores Geral"))
("Operador de equação" . ("maxima.info-1" 97852 4208 "Operadores Geral"))
("Produto Externo" . ("maxima.info-3" 133666 1613 "Funções e Variáveis Definidas para itensor"))
("Resultado anterior em expressão composta" . ("maxima.info-1" 282604 1176 "Funções e Variáveis Definidas para Entrada e Saída"))
("Saída anterior" . ("maxima.info-1" 281967 620 "Funções e Variáveis Definidas para Entrada e Saída"))
("Subtração" . ("maxima.info-1" 79888 7440 "Operadores Aritméticos"))
("Unidade imaginária" . ("maxima.info-2" 76646 71 "Funções e Variáveis Definidas para Constantes"))
("Zeilberger" . ("maxima.info-6" 205350 717 "Funções e Variáveis Definidas para zeilberger"))
("[" . ("maxima.info-3" 52927 1137 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("]" . ("maxima.info-3" 52928 1136 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("^" . ("maxima.info-1" 79920 7408 "Operadores Aritméticos"))
("^^" . ("maxima.info-1" 88701 17 "Operadores Geral"))
("_" . ("maxima.info-1" 280426 1521 "Funções e Variáveis Definidas para Entrada e Saída"))
("__" . ("maxima.info-1" 278527 1870 "Funções e Variáveis Definidas para Entrada e Saída"))
("abasep" . ("maxima.info-3" 221205 260 "Funções e Variáveis Definidas para o Pacote atensor"))
("abs" . ("maxima.info-1" 104899 143 "Operadores Geral"))
("absboxchar" . ("maxima.info-1" 285911 214 "Funções e Variáveis Definidas para Entrada e Saída"))
("absint" . ("maxima.info-2" 268343 589 "Funções e Variáveis Definidas para Séries de Fourier"))
("absint <1>" . ("maxima.info-2" 268344 588 "Funções e Variáveis Definidas para Séries de Fourier"))
("absint <2>" . ("maxima.info-2" 268389 545 "Funções e Variáveis Definidas para Séries de Fourier"))
("absolute_real_time" . ("maxima.info-4" 10714 452 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("acos" . ("maxima.info-2" 90313 44 "Funções e Variáveis Definidas para Trigonometria"))
("acosh" . ("maxima.info-2" 90360 57 "Funções e Variáveis Definidas para Trigonometria"))
("acot" . ("maxima.info-2" 90421 47 "Funções e Variáveis Definidas para Trigonometria"))
("acoth" . ("maxima.info-2" 90471 60 "Funções e Variáveis Definidas para Trigonometria"))
("acsc" . ("maxima.info-2" 90535 47 "Funções e Variáveis Definidas para Trigonometria"))
("acsch" . ("maxima.info-2" 90585 60 "Funções e Variáveis Definidas para Trigonometria"))
("activate" . ("maxima.info-2" 5403 399 "Funções e Variáveis Definidas para Contextos"))
("activecontexts" . ("maxima.info-2" 5820 249 "Funções e Variáveis Definidas para Contextos"))
("adapt_depth" . ("maxima.info-5" 211584 220 "Funções e Variáveis Definidas para draw"))
("addcol" . ("maxima.info-3" 4351 144 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("additive" . ("maxima.info-1" 105047 681 "Operadores Geral"))
("addmatrices" . ("maxima.info-5" 302105 512 "Funções e Variáveis Definidas para linearalgebra"))
("addrow" . ("maxima.info-3" 4498 143 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("adim" . ("maxima.info-3" 219151 201 "Funções e Variáveis Definidas para o Pacote atensor"))
("adjoin" . ("maxima.info-4" 101817 486 "Funções e Variáveis Definidas para Conjuntos"))
("adjoint" . ("maxima.info-3" 4644 141 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("af" . ("maxima.info-3" 219878 285 "Funções e Variáveis Definidas para o Pacote atensor"))
("aform" . ("maxima.info-3" 219358 134 "Funções e Variáveis Definidas para o Pacote atensor"))
("agd" . ("maxima.info-6" 85841 167 "Funções e Variáveis Definidas para simplification"))
("airy_ai" . ("maxima.info-2" 101815 562 "Funções e Variáveis Definidas para Funções Especiais"))
("airy_bi" . ("maxima.info-2" 102499 546 "Funções e Variáveis Definidas para Funções Especiais"))
("airy_dai" . ("maxima.info-2" 102394 100 "Funções e Variáveis Definidas para Funções Especiais"))
("airy_dbi" . ("maxima.info-2" 103065 112 "Funções e Variáveis Definidas para Funções Especiais"))
("alg_type" . ("maxima.info-3" 218992 153 "Funções e Variáveis Definidas para o Pacote atensor"))
("algebraic" . ("maxima.info-2" 22294 189 "Funções e Variáveis Definidas para Polinômios"))
("algepsilon" . ("maxima.info-2" 846 99 "Funções e Variáveis Definidas para ponto Flutuante"))
("algexact" . ("maxima.info-2" 201165 576 "Funções e Variáveis Definidas para Equações"))
("algsys" . ("maxima.info-2" 201759 4810 "Funções e Variáveis Definidas para Equações"))
("algsys <1>" . ("maxima.info-2" 201760 4809 "Funções e Variáveis Definidas para Equações"))
("alias" . ("maxima.info-1" 49740 244 "Funções e Variáveis Definidas para Linha de Comando"))
("aliases" . ("maxima.info-4" 14081 302 "Funções e Variáveis Definidas para Opções Diversas"))
("all_dotsimp_denoms" . ("maxima.info-3" 59817 367 "Funções e Variáveis Definidas para Funções Afins"))
("allbut" . ("maxima.info-1" 105754 1007 "Operadores Geral"))
("allroots" . ("maxima.info-2" 206726 2376 "Funções e Variáveis Definidas para Equações"))
("allroots <1>" . ("maxima.info-2" 206727 2375 "Funções e Variáveis Definidas para Equações"))
("allsym" . ("maxima.info-3" 97269 405 "Funções e Variáveis Definidas para itensor"))
("alphabetic" . ("maxima.info-4" 14396 673 "Funções e Variáveis Definidas para Opções Diversas"))
("alphacharp" . ("maxima.info-6" 157532 101 "Funções e Variáveis para caracteres"))
("alphanumericp" . ("maxima.info-6" 157637 122 "Funções e Variáveis para caracteres"))
("and" . ("maxima.info-1" 102123 1066 "Operadores Geral"))
("antid" . ("maxima.info-2" 128393 2445 "Funções e Variáveis Definidas para Diferenciação"))
("antidiff" . ("maxima.info-2" 130872 2305 "Funções e Variáveis Definidas para Diferenciação"))
("antisymmetric" . ("maxima.info-1" 106766 393 "Operadores Geral"))
("append" . ("maxima.info-4" 78333 317 "Funções e Variáveis Definidas para Listas"))
("appendfile" . ("maxima.info-1" 286826 375 "Funções e Variáveis Definidas para Entrada e Saída"))
("apply" . ("maxima.info-4" 171127 2297 "Funções e Variáveis para Definição de Função"))
("apply1" . ("maxima.info-4" 30583 700 "Funções e Variáveis Definidas para Regras e Modelos"))
("apply2" . ("maxima.info-4" 31301 599 "Funções e Variáveis Definidas para Regras e Modelos"))
("applyb1" . ("maxima.info-4" 31921 743 "Funções e Variáveis Definidas para Regras e Modelos"))
("apropos" . ("maxima.info-4" 15080 630 "Funções e Variáveis Definidas para Opções Diversas"))
("args" . ("maxima.info-4" 15719 517 "Funções e Variáveis Definidas para Opções Diversas"))
("arithmetic" . ("maxima.info-6" 84330 219 "Funções e Variáveis Definidas para simplification"))
("arithsum" . ("maxima.info-6" 85026 169 "Funções e Variáveis Definidas para simplification"))
("array" . ("maxima.info-2" 270911 1539 "Funções e Variáveis Definidas para Arrays"))
("array <1>" . ("maxima.info-2" 270912 1538 "Funções e Variáveis Definidas para Arrays"))
("array <2>" . ("maxima.info-2" 270964 1488 "Funções e Variáveis Definidas para Arrays"))
("arrayapply" . ("maxima.info-2" 272485 261 "Funções e Variáveis Definidas para Arrays"))
("arrayinfo" . ("maxima.info-2" 272755 4077 "Funções e Variáveis Definidas para Arrays"))
("arraymake" . ("maxima.info-2" 276869 1803 "Funções e Variáveis Definidas para Arrays"))
("arrays" . ("maxima.info-2" 278688 1143 "Funções e Variáveis Definidas para Arrays"))
("ascii" . ("maxima.info-6" 157764 378 "Funções e Variáveis para caracteres"))
("asec" . ("maxima.info-2" 90649 44 "Funções e Variáveis Definidas para Trigonometria"))
("asech" . ("maxima.info-2" 90696 57 "Funções e Variáveis Definidas para Trigonometria"))
("asin" . ("maxima.info-2" 90757 41 "Funções e Variáveis Definidas para Trigonometria"))
("asinh" . ("maxima.info-2" 90801 54 "Funções e Variáveis Definidas para Trigonometria"))
("askexp" . ("maxima.info-1" 225399 244 "Funções e Variáveis Definidas para Simplificação"))
("askinteger" . ("maxima.info-1" 225651 704 "Funções e Variáveis Definidas para Simplificação"))
("askinteger <1>" . ("maxima.info-1" 225652 703 "Funções e Variáveis Definidas para Simplificação"))
("askinteger <2>" . ("maxima.info-1" 225695 662 "Funções e Variáveis Definidas para Simplificação"))
("askinteger <3>" . ("maxima.info-1" 225729 630 "Funções e Variáveis Definidas para Simplificação"))
("asksign" . ("maxima.info-1" 226373 426 "Funções e Variáveis Definidas para Simplificação"))
("assoc" . ("maxima.info-4" 78656 567 "Funções e Variáveis Definidas para Listas"))
("assoc <1>" . ("maxima.info-4" 78657 566 "Funções e Variáveis Definidas para Listas"))
("assoc_legendre_p" . ("maxima.info-6" 42312 234 "Funções e Variáveis Definidas para polinômios ortogonais"))
("assoc_legendre_q" . ("maxima.info-6" 42559 160 "Funções e Variáveis Definidas para polinômios ortogonais"))
("assume" . ("maxima.info-2" 6079 2324 "Funções e Variáveis Definidas para Contextos"))
("assume_pos" . ("maxima.info-2" 9446 1226 "Funções e Variáveis Definidas para Contextos"))
("assume_pos_pred" . ("maxima.info-2" 10702 2238 "Funções e Variáveis Definidas para Contextos"))
("assumescalar" . ("maxima.info-2" 8433 990 "Funções e Variáveis Definidas para Contextos"))
("asymbol" . ("maxima.info-3" 219497 83 "Funções e Variáveis Definidas para o Pacote atensor"))
("asympa" . ("maxima.info-2" 103182 317 "Funções e Variáveis Definidas para Funções Especiais"))
("at" . ("maxima.info-1" 162086 2002 "Funções e Variáveis Definidas para Expressões"))
("at <1>" . ("maxima.info-1" 162087 2001 "Funções e Variáveis Definidas para Expressões"))
("atan" . ("maxima.info-2" 90859 45 "Funções e Variáveis Definidas para Trigonometria"))
("atan2" . ("maxima.info-2" 90907 108 "Funções e Variáveis Definidas para Trigonometria"))
("atanh" . ("maxima.info-2" 91018 58 "Funções e Variáveis Definidas para Trigonometria"))
("atensimp" . ("maxima.info-3" 218562 412 "Funções e Variáveis Definidas para o Pacote atensor"))
("atom" . ("maxima.info-4" 79240 295 "Funções e Variáveis Definidas para Listas"))
("atomgrad" . ("maxima.info-2" 133205 146 "Funções e Variáveis Definidas para Diferenciação"))
("atrig1" . ("maxima.info-2" 91080 415 "Funções e Variáveis Definidas para Trigonometria"))
("atvalue" . ("maxima.info-2" 133357 2561 "Funções e Variáveis Definidas para Diferenciação"))
("atvalue <1>" . ("maxima.info-2" 133358 2560 "Funções e Variáveis Definidas para Diferenciação"))
("augcoefmatrix" . ("maxima.info-3" 4789 657 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("augmented_lagrangian_method" . ("maxima.info-4" 274046 2235 "Funções e Variáveis Definidas para augmented_lagrangian"))
("augmented_lagrangian_method <1>" . ("maxima.info-4" 274047 2234 "Funções e Variáveis Definidas para augmented_lagrangian"))
("av" . ("maxima.info-3" 220177 1014 "Funções e Variáveis Definidas para o Pacote atensor"))
("axis_3d" . ("maxima.info-5" 193559 526 "Funções e Variáveis Definidas para draw"))
("axis_bottom" . ("maxima.info-5" 191610 471 "Funções e Variáveis Definidas para draw"))
("axis_left" . ("maxima.info-5" 192099 470 "Funções e Variáveis Definidas para draw"))
("axis_right" . ("maxima.info-5" 193070 471 "Funções e Variáveis Definidas para draw"))
("axis_top" . ("maxima.info-5" 192587 465 "Funções e Variáveis Definidas para draw"))
("backsubst" . ("maxima.info-2" 209142 361 "Funções e Variáveis Definidas para Equações"))
("backtrace" . ("maxima.info-4" 227967 1676 "Funções e Variáveis Definidas para Fluxo de Programa"))
("backtrace <1>" . ("maxima.info-4" 227968 1675 "Funções e Variáveis Definidas para Fluxo de Programa"))
("barsplot" . ("maxima.info-5" 61045 2383 "Funções e Variáveis Definidas para gráficos estatísticos"))
("barsplot <1>" . ("maxima.info-5" 61046 2382 "Funções e Variáveis Definidas para gráficos estatísticos"))
("barsplot <2>" . ("maxima.info-5" 61079 2351 "Funções e Variáveis Definidas para gráficos estatísticos"))
("barsplot <3>" . ("maxima.info-5" 61143 2293 "Funções e Variáveis Definidas para gráficos estatísticos"))
("bashindices" . ("maxima.info-2" 279847 427 "Funções e Variáveis Definidas para Arrays"))
("batch" . ("maxima.info-1" 287209 1792 "Funções e Variáveis Definidas para Entrada e Saída"))
("batchload" . ("maxima.info-1" 289054 664 "Funções e Variáveis Definidas para Entrada e Saída"))
("bc2" . ("maxima.info-2" 243166 614 "Funções e Variáveis Definidas para Equações Diferenciais"))
("bdvac" . ("maxima.info-3" 184444 442 "Funções e Variáveis Definidas para ctensor"))
("belln" . ("maxima.info-4" 102311 986 "Funções e Variáveis Definidas para Conjuntos"))
("berlefact" . ("maxima.info-2" 22491 232 "Funções e Variáveis Definidas para Polinômios"))
("bern" . ("maxima.info-3" 251337 744 "Funções e Variáveis Definidas para Teoria dos Números"))
("bernpoly" . ("maxima.info-3" 252089 97 "Funções e Variáveis Definidas para Teoria dos Números"))
("bessel" . ("maxima.info-2" 103518 162 "Funções e Variáveis Definidas para Funções Especiais"))
("bessel_i" . ("maxima.info-2" 104924 668 "Funções e Variáveis Definidas para Funções Especiais"))
("bessel_j" . ("maxima.info-2" 103688 649 "Funções e Variáveis Definidas para Funções Especiais"))
("bessel_k" . ("maxima.info-2" 105602 586 "Funções e Variáveis Definidas para Funções Especiais"))
("bessel_y" . ("maxima.info-2" 104347 569 "Funções e Variáveis Definidas para Funções Especiais"))
("besselexpand" . ("maxima.info-2" 106197 849 "Funções e Variáveis Definidas para Funções Especiais"))
("beta" . ("maxima.info-2" 107730 96 "Funções e Variáveis Definidas para Funções Especiais"))
("bezout" . ("maxima.info-2" 22737 170 "Funções e Variáveis Definidas para Polinômios"))
("bffac" . ("maxima.info-2" 524 308 "Funções e Variáveis Definidas para ponto Flutuante"))
("bfhzeta" . ("maxima.info-3" 252461 357 "Funções e Variáveis Definidas para Teoria dos Números"))
("bfloat" . ("maxima.info-2" 951 543 "Funções e Variáveis Definidas para ponto Flutuante"))
("bfloatp" . ("maxima.info-2" 1512 160 "Funções e Variáveis Definidas para ponto Flutuante"))
("bfpsi" . ("maxima.info-2" 1678 483 "Funções e Variáveis Definidas para ponto Flutuante"))
("bfpsi0" . ("maxima.info-2" 1679 482 "Funções e Variáveis Definidas para ponto Flutuante"))
("bftorat" . ("maxima.info-2" 2181 389 "Funções e Variáveis Definidas para ponto Flutuante"))
("bftrunc" . ("maxima.info-2" 2582 329 "Funções e Variáveis Definidas para ponto Flutuante"))
("bfzeta" . ("maxima.info-3" 252192 258 "Funções e Variáveis Definidas para Teoria dos Números"))
("bimetric" . ("maxima.info-3" 185376 197 "Funções e Variáveis Definidas para ctensor"))
("binomial" . ("maxima.info-3" 252832 992 "Funções e Variáveis Definidas para Teoria dos Números"))
("block" . ("maxima.info-4" 173458 2865 "Funções e Variáveis para Definição de Função"))
("block <1>" . ("maxima.info-4" 173459 2864 "Funções e Variáveis para Definição de Função"))
("blockmatrixp" . ("maxima.info-5" 302634 137 "Funções e Variáveis Definidas para linearalgebra"))
("bode_gain" . ("maxima.info-4" 276677 1443 "Funções e Variáveis Definidas para bode"))
("bode_phase" . ("maxima.info-4" 278129 1690 "Funções e Variáveis Definidas para bode"))
("border" . ("maxima.info-5" 201252 597 "Funções e Variáveis Definidas para draw"))
("bothcoef" . ("maxima.info-2" 22911 574 "Funções e Variáveis Definidas para Polinômios"))
("box" . ("maxima.info-1" 164117 2047 "Funções e Variáveis Definidas para Expressões"))
("box <1>" . ("maxima.info-1" 164118 2046 "Funções e Variáveis Definidas para Expressões"))
("boxchar" . ("maxima.info-1" 166186 526 "Funções e Variáveis Definidas para Expressões"))
("boxplot" . ("maxima.info-5" 63487 1753 "Funções e Variáveis Definidas para gráficos estatísticos"))
("boxplot <1>" . ("maxima.info-5" 63488 1752 "Funções e Variáveis Definidas para gráficos estatísticos"))
("break" . ("maxima.info-4" 176400 267 "Funções e Variáveis para Definição de Função"))
("breakup" . ("maxima.info-2" 209519 3281 "Funções e Variáveis Definidas para Equações"))
("bug_report" . ("maxima.info-1" 25562 413 "Definições para Detecção e Relato de Erros"))
("build_info" . ("maxima.info-1" 25995 158 "Definições para Detecção e Relato de Erros"))
("buildq" . ("maxima.info-4" 162145 4040 "Macros"))
("burn" . ("maxima.info-3" 253832 527 "Funções e Variáveis Definidas para Teoria dos Números"))
("cabs" . ("maxima.info-1" 107173 96 "Operadores Geral"))
("canform" . ("maxima.info-3" 100421 956 "Funções e Variáveis Definidas para itensor"))
("canten" . ("maxima.info-3" 96442 646 "Funções e Variáveis Definidas para itensor"))
("cardinality" . ("maxima.info-4" 103316 543 "Funções e Variáveis Definidas para Conjuntos"))
("carg" . ("maxima.info-1" 166727 1189 "Funções e Variáveis Definidas para Expressões"))
("cartan" . ("maxima.info-2" 135953 582 "Funções e Variáveis Definidas para Diferenciação"))
("cartesian_product" . ("maxima.info-4" 103866 736 "Funções e Variáveis Definidas para Conjuntos"))
("catch" . ("maxima.info-4" 176675 1126 "Funções e Variáveis para Definição de Função"))
("cauchysum" . ("maxima.info-3" 222500 1267 "Funções e Variáveis Definidas para Séries"))
("cbffac" . ("maxima.info-2" 2919 139 "Funções e Variáveis Definidas para ponto Flutuante"))
("cdf_bernoulli" . ("maxima.info-5" 158669 234 "Funções e Variáveis Definidas para distribuições discretas"))
("cdf_beta" . ("maxima.info-5" 124156 638 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_binomial" . ("maxima.info-5" 151187 690 "Funções e Variáveis Definidas para distribuições discretas"))
("cdf_cauchy" . ("maxima.info-5" 146879 232 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_chi2" . ("maxima.info-5" 99769 686 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_continuous_uniform" . ("maxima.info-5" 127735 256 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_discrete_uniform" . ("maxima.info-5" 166207 279 "Funções e Variáveis Definidas para distribuições discretas"))
("cdf_exp" . ("maxima.info-5" 110734 740 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_f" . ("maxima.info-5" 106284 625 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_gamma" . ("maxima.info-5" 120593 549 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_geometric" . ("maxima.info-5" 163101 234 "Funções e Variáveis Definidas para distribuições discretas"))
("cdf_gumbel" . ("maxima.info-5" 148109 232 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_hypergeometric" . ("maxima.info-5" 168964 310 "Funções e Variáveis Definidas para distribuições discretas"))
("cdf_laplace" . ("maxima.info-5" 144634 234 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_logistic" . ("maxima.info-5" 130255 236 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_lognormal" . ("maxima.info-5" 117600 618 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_negative_binomial" . ("maxima.info-5" 172802 733 "Funções e Variáveis Definidas para distribuições discretas"))
("cdf_normal" . ("maxima.info-5" 91586 598 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_pareto" . ("maxima.info-5" 132521 234 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_poisson" . ("maxima.info-5" 154950 527 "Funções e Variáveis Definidas para distribuições discretas"))
("cdf_rank_sum" . ("maxima.info-6" 142672 258 "Funções e Variáveis Definidas para distribuições especiais"))
("cdf_rayleigh" . ("maxima.info-5" 137646 804 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_signed_rank" . ("maxima.info-6" 142147 241 "Funções e Variáveis Definidas para distribuições especiais"))
("cdf_student_t" . ("maxima.info-5" 94997 665 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdf_weibull" . ("maxima.info-5" 134781 236 "Funções e Variáveis Definidas para distribuições contínuas"))
("cdisplay" . ("maxima.info-3" 186250 13894 "Funções e Variáveis Definidas para ctensor"))
("ceiling" . ("maxima.info-1" 107273 1950 "Operadores Geral"))
("central_moment" . ("maxima.info-5" 29159 966 "Funções e Variáveis Definidas para estatística descritiva"))
("central_moment <1>" . ("maxima.info-5" 29160 965 "Funções e Variáveis Definidas para estatística descritiva"))
("cequal" . ("maxima.info-6" 158147 120 "Funções e Variáveis para caracteres"))
("cequalignore" . ("maxima.info-6" 158270 106 "Funções e Variáveis para caracteres"))
("cf" . ("maxima.info-3" 254375 2772 "Funções e Variáveis Definidas para Teoria dos Números"))
("cfdisrep" . ("maxima.info-3" 257235 673 "Funções e Variáveis Definidas para Teoria dos Números"))
("cfexpand" . ("maxima.info-3" 257919 624 "Funções e Variáveis Definidas para Teoria dos Números"))
("cflength" . ("maxima.info-3" 258551 612 "Funções e Variáveis Definidas para Teoria dos Números"))
("cframe_flag" . ("maxima.info-3" 201312 455 "Funções e Variáveis Definidas para ctensor"))
("cgeodesic" . ("maxima.info-3" 184157 273 "Funções e Variáveis Definidas para ctensor"))
("cgreaterp" . ("maxima.info-6" 158379 178 "Funções e Variáveis para caracteres"))
("cgreaterpignore" . ("maxima.info-6" 158564 112 "Funções e Variáveis para caracteres"))
("changename" . ("maxima.info-3" 73629 383 "Funções e Variáveis Definidas para itensor"))
("changevar" . ("maxima.info-2" 154612 2316 "Funções e Variáveis Definidas para Integração"))
("chaosgame" . ("maxima.info-5" 240280 607 "Funções e Variáveis Definidas para dynamics"))
("charat" . ("maxima.info-6" 161474 241 "Funções e Variáveis para seqüências de caracteres"))
("charfun" . ("maxima.info-1" 109257 622 "Operadores Geral"))
("charfun2" . ("maxima.info-5" 277441 171 "Funções e Variáveis Definidas para interpol"))
("charlist" . ("maxima.info-6" 161720 249 "Funções e Variáveis para seqüências de caracteres"))
("charp" . ("maxima.info-6" 158679 184 "Funções e Variáveis para caracteres"))
("charpoly" . ("maxima.info-3" 5456 1618 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("chebyshev_t" . ("maxima.info-6" 42727 147 "Funções e Variáveis Definidas para polinômios ortogonais"))
("chebyshev_u" . ("maxima.info-6" 42883 146 "Funções e Variáveis Definidas para polinômios ortogonais"))
("check_overlaps" . ("maxima.info-3" 57923 711 "Funções e Variáveis Definidas para Funções Afins"))
("checkdiv" . ("maxima.info-3" 183698 446 "Funções e Variáveis Definidas para ctensor"))
("cholesky" . ("maxima.info-5" 304387 291 "Funções e Variáveis Definidas para linearalgebra"))
("cholesky <1>" . ("maxima.info-5" 304388 290 "Funções e Variáveis Definidas para linearalgebra"))
("christof" . ("maxima.info-3" 157881 931 "Funções e Variáveis Definidas para ctensor"))
("cint" . ("maxima.info-6" 158874 83 "Funções e Variáveis para caracteres"))
("clear_rules" . ("maxima.info-4" 76810 171 "Funções e Variáveis Definidas para Regras e Modelos"))
("clessp" . ("maxima.info-6" 158962 175 "Funções e Variáveis para caracteres"))
("clesspignore" . ("maxima.info-6" 159144 105 "Funções e Variáveis para caracteres"))
("close" . ("maxima.info-6" 151559 113 "Funções e Variáveis para entrada e saída"))
("closefile" . ("maxima.info-1" 289740 97 "Funções e Variáveis Definidas para Entrada e Saída"))
("cmetric" . ("maxima.info-3" 150188 947 "Funções e Variáveis Definidas para ctensor"))
("cmetric <1>" . ("maxima.info-3" 150189 946 "Funções e Variáveis Definidas para ctensor"))
("cnonmet_flag" . ("maxima.info-3" 202064 311 "Funções e Variáveis Definidas para ctensor"))
("coeff" . ("maxima.info-2" 23493 690 "Funções e Variáveis Definidas para Polinômios"))
("coefmatrix" . ("maxima.info-3" 7084 445 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("cograd" . ("maxima.info-3" 181447 1331 "Funções e Variáveis Definidas para ctensor"))
("col" . ("maxima.info-3" 7535 112 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("collapse" . ("maxima.info-1" 289840 560 "Funções e Variáveis Definidas para Entrada e Saída"))
("collectterms" . ("maxima.info-6" 81130 902 "Funções e Variáveis Definidas para simplification"))
("color" . ("maxima.info-5" 207200 2178 "Funções e Variáveis Definidas para draw"))
("colorbox" . ("maxima.info-5" 196062 539 "Funções e Variáveis Definidas para draw"))
("columnop" . ("maxima.info-5" 302775 242 "Funções e Variáveis Definidas para linearalgebra"))
("columns" . ("maxima.info-5" 215882 647 "Funções e Variáveis Definidas para draw"))
("columnspace" . ("maxima.info-5" 303197 347 "Funções e Variáveis Definidas para linearalgebra"))
("columnswap" . ("maxima.info-5" 303023 170 "Funções e Variáveis Definidas para linearalgebra"))
("columnvector" . ("maxima.info-3" 7652 923 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("combination" . ("maxima.info-6" 86604 194 "Funções e Variáveis Definidas para simplification"))
("combine" . ("maxima.info-2" 24193 140 "Funções e Variáveis Definidas para Polinômios"))
("commutative" . ("maxima.info-1" 109883 222 "Operadores Geral"))
("comp2pui" . ("maxima.info-3" 269778 633 "Funções e Variáveis Definidas para Simetrias"))
("compare" . ("maxima.info-1" 110115 1131 "Operadores Geral"))
("compfile" . ("maxima.info-4" 177829 761 "Funções e Variáveis para Definição de Função"))
("compfile <1>" . ("maxima.info-4" 177830 760 "Funções e Variáveis para Definição de Função"))
("compfile <2>" . ("maxima.info-4" 177888 704 "Funções e Variáveis para Definição de Função"))
("compile" . ("maxima.info-4" 178617 559 "Funções e Variáveis para Definição de Função"))
("compile <1>" . ("maxima.info-4" 178618 558 "Funções e Variáveis para Definição de Função"))
("compile <2>" . ("maxima.info-4" 178660 518 "Funções e Variáveis para Definição de Função"))
("compile_file" . ("maxima.info-4" 225004 1369 "Funções e Variáveis para Definição de Função"))
("compile_file <1>" . ("maxima.info-4" 225072 1303 "Funções e Variáveis para Definição de Função"))
("compile_file <2>" . ("maxima.info-4" 225140 1237 "Funções e Variáveis para Definição de Função"))
("components" . ("maxima.info-3" 82114 3966 "Funções e Variáveis Definidas para itensor"))
("concan" . ("maxima.info-3" 97110 94 "Funções e Variáveis Definidas para itensor"))
("concat" . ("maxima.info-1" 290412 1432 "Funções e Variáveis Definidas para Entrada e Saída"))
("conjugate" . ("maxima.info-3" 8591 533 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("conmetderiv" . ("maxima.info-3" 109071 850 "Funções e Variáveis Definidas para itensor"))
("cons" . ("maxima.info-4" 79545 261 "Funções e Variáveis Definidas para Listas"))
("constant" . ("maxima.info-1" 167938 122 "Funções e Variáveis Definidas para Expressões"))
("constantp" . ("maxima.info-1" 168061 1206 "Funções e Variáveis Definidas para Expressões"))
("constituent" . ("maxima.info-6" 159252 661 "Funções e Variáveis para caracteres"))
("cont2part" . ("maxima.info-3" 279147 433 "Funções e Variáveis Definidas para Simetrias"))
("content" . ("maxima.info-2" 24338 450 "Funções e Variáveis Definidas para Polinômios"))
("context" . ("maxima.info-2" 12975 594 "Funções e Variáveis Definidas para Contextos"))
("contexts" . ("maxima.info-2" 13587 1487 "Funções e Variáveis Definidas para Contextos"))
("continuous_freq" . ("maxima.info-5" 15440 909 "Funções e Variáveis Definidas para manipulação da dados"))
("continuous_freq <1>" . ("maxima.info-5" 15441 908 "Funções e Variáveis Definidas para manipulação da dados"))
("contortion" . ("maxima.info-3" 178469 132 "Funções e Variáveis Definidas para ctensor"))
("contour" . ("maxima.info-5" 214383 971 "Funções e Variáveis Definidas para draw"))
("contour_levels" . ("maxima.info-5" 215382 481 "Funções e Variáveis Definidas para draw"))
("contour_plot" . ("maxima.info-1" 247043 1059 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("contract" . ("maxima.info-3" 81325 528 "Funções e Variáveis Definidas para itensor"))
("contract <1>" . ("maxima.info-3" 279588 774 "Funções e Variáveis Definidas para Simetrias"))
("contragrad" . ("maxima.info-3" 181619 1164 "Funções e Variáveis Definidas para ctensor"))
("contrib_ode" . ("maxima.info-5" 363 153 "Funções e Variáveis Definidas para contrib_ode"))
("convert" . ("maxima.info-6" 186010 3585 "Funções e Variáveis Definidas para Units"))
("coord" . ("maxima.info-3" 108078 426 "Funções e Variáveis Definidas para itensor"))
("copy" . ("maxima.info-5" 303552 820 "Funções e Variáveis Definidas para linearalgebra"))
("copylist" . ("maxima.info-4" 79812 70 "Funções e Variáveis Definidas para Listas"))
("copymatrix" . ("maxima.info-3" 9127 440 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("cor" . ("maxima.info-5" 47293 2166 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("cor <1>" . ("maxima.info-5" 47294 2165 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("cos" . ("maxima.info-2" 91512 38 "Funções e Variáveis Definidas para Trigonometria"))
("cosh" . ("maxima.info-2" 91553 51 "Funções e Variáveis Definidas para Trigonometria"))
("cosnpiflag" . ("maxima.info-2" 269338 83 "Funções e Variáveis Definidas para Séries de Fourier"))
("cot" . ("maxima.info-2" 91608 41 "Funções e Variáveis Definidas para Trigonometria"))
("coth" . ("maxima.info-2" 91652 54 "Funções e Variáveis Definidas para Trigonometria"))
("cov" . ("maxima.info-5" 42749 1329 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("cov1" . ("maxima.info-5" 44091 1328 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("covdiff" . ("maxima.info-3" 115181 1732 "Funções e Variáveis Definidas para itensor"))
("covect" . ("maxima.info-3" 7653 922 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("covers" . ("maxima.info-6" 86152 151 "Funções e Variáveis Definidas para simplification"))
("create_list" . ("maxima.info-4" 79886 1167 "Funções e Variáveis Definidas para Listas"))
("csc" . ("maxima.info-2" 91710 41 "Funções e Variáveis Definidas para Trigonometria"))
("csch" . ("maxima.info-2" 91754 54 "Funções e Variáveis Definidas para Trigonometria"))
("csetup" . ("maxima.info-3" 149974 206 "Funções e Variáveis Definidas para ctensor"))
("cspline" . ("maxima.info-5" 280033 4319 "Funções e Variáveis Definidas para interpol"))
("cspline <1>" . ("maxima.info-5" 280034 4318 "Funções e Variáveis Definidas para interpol"))
("ct_coords" . ("maxima.info-3" 207294 381 "Funções e Variáveis Definidas para ctensor"))
("ct_coordsys" . ("maxima.info-3" 151167 5194 "Funções e Variáveis Definidas para ctensor"))
("ct_coordsys <1>" . ("maxima.info-3" 151168 5193 "Funções e Variáveis Definidas para ctensor"))
("ctaylor" . ("maxima.info-3" 164301 5426 "Funções e Variáveis Definidas para ctensor"))
("ctaypov" . ("maxima.info-3" 202809 144 "Funções e Variáveis Definidas para ctensor"))
("ctaypt" . ("maxima.info-3" 202959 156 "Funções e Variáveis Definidas para ctensor"))
("ctayswitch" . ("maxima.info-3" 202391 271 "Funções e Variáveis Definidas para ctensor"))
("ctayvar" . ("maxima.info-3" 202669 132 "Funções e Variáveis Definidas para ctensor"))
("ctorsion_flag" . ("maxima.info-3" 201784 267 "Funções e Variáveis Definidas para ctensor"))
("ctransform" . ("maxima.info-3" 178808 282 "Funções e Variáveis Definidas para ctensor"))
("ctranspose" . ("maxima.info-5" 304690 200 "Funções e Variáveis Definidas para linearalgebra"))
("ctrgsimp" . ("maxima.info-3" 201088 215 "Funções e Variáveis Definidas para ctensor"))
("cunlisp" . ("maxima.info-6" 159923 141 "Funções e Variáveis para caracteres"))
("current_let_rule_package" . ("maxima.info-4" 32686 625 "Funções e Variáveis Definidas para Regras e Modelos"))
("cv" . ("maxima.info-5" 30134 663 "Funções e Variáveis Definidas para estatística descritiva"))
("cv <1>" . ("maxima.info-5" 30135 662 "Funções e Variáveis Definidas para estatística descritiva"))
("dataplot" . ("maxima.info-5" 53167 5391 "Funções e Variáveis Definidas para gráficos estatísticos"))
("dataplot <1>" . ("maxima.info-5" 53168 5390 "Funções e Variáveis Definidas para gráficos estatísticos"))
("dataplot <2>" . ("maxima.info-5" 53201 5359 "Funções e Variáveis Definidas para gráficos estatísticos"))
("dataplot <3>" . ("maxima.info-5" 53265 5301 "Funções e Variáveis Definidas para gráficos estatísticos"))
("dblint" . ("maxima.info-2" 156955 2577 "Funções e Variáveis Definidas para Integração"))
("deactivate" . ("maxima.info-2" 15115 127 "Funções e Variáveis Definidas para Contextos"))
("debugmode" . ("maxima.info-1" 49993 515 "Funções e Variáveis Definidas para Linha de Comando"))
("declare" . ("maxima.info-1" 169281 11277 "Funções e Variáveis Definidas para Expressões"))
("declare_translated" . ("maxima.info-4" 226473 592 "Funções e Variáveis para Definição de Função"))
("declare_weights" . ("maxima.info-3" 56775 258 "Funções e Variáveis Definidas para Funções Afins"))
("decsym" . ("maxima.info-3" 97690 2519 "Funções e Variáveis Definidas para itensor"))
("default_let_rule_package" . ("maxima.info-4" 33327 302 "Funções e Variáveis Definidas para Regras e Modelos"))
("defcon" . ("maxima.info-3" 80016 1018 "Funções e Variáveis Definidas para itensor"))
("defcon <1>" . ("maxima.info-3" 80017 1017 "Funções e Variáveis Definidas para itensor"))
("define" . ("maxima.info-4" 179206 4084 "Funções e Variáveis para Definição de Função"))
("define <1>" . ("maxima.info-4" 179207 4083 "Funções e Variáveis para Definição de Função"))
("define <2>" . ("maxima.info-4" 179261 4031 "Funções e Variáveis para Definição de Função"))
("define <3>" . ("maxima.info-4" 179315 3979 "Funções e Variáveis para Definição de Função"))
("define <4>" . ("maxima.info-4" 179381 3915 "Funções e Variáveis para Definição de Função"))
("define_variable" . ("maxima.info-4" 183380 3856 "Funções e Variáveis para Definição de Função"))
("defint" . ("maxima.info-2" 159611 588 "Funções e Variáveis Definidas para Integração"))
("defmatch" . ("maxima.info-4" 33640 4649 "Funções e Variáveis Definidas para Regras e Modelos"))
("defmatch <1>" . ("maxima.info-4" 33641 4648 "Funções e Variáveis Definidas para Regras e Modelos"))
("defrule" . ("maxima.info-4" 38362 757 "Funções e Variáveis Definidas para Regras e Modelos"))
("deftaylor" . ("maxima.info-3" 223782 1324 "Funções e Variáveis Definidas para Séries"))
("del" . ("maxima.info-2" 136551 681 "Funções e Variáveis Definidas para Diferenciação"))
("delete" . ("maxima.info-4" 81078 768 "Funções e Variáveis Definidas para Listas"))
("delete <1>" . ("maxima.info-4" 81079 767 "Funções e Variáveis Definidas para Listas"))
("deleten" . ("maxima.info-3" 200152 118 "Funções e Variáveis Definidas para ctensor"))
("delta" . ("maxima.info-2" 137241 352 "Funções e Variáveis Definidas para Diferenciação"))
("demo" . ("maxima.info-1" 32628 2964 "Funções e Variáveis Definidas para Ajuda"))
("demoivre" . ("maxima.info-1" 226816 676 "Funções e Variáveis Definidas para Simplificação"))
("demoivre <1>" . ("maxima.info-1" 226817 675 "Funções e Variáveis Definidas para Simplificação"))
("denom" . ("maxima.info-2" 24800 84 "Funções e Variáveis Definidas para Polinômios"))
("dependencies" . ("maxima.info-2" 137600 316 "Funções e Variáveis Definidas para Diferenciação"))
("depends" . ("maxima.info-2" 137925 2506 "Funções e Variáveis Definidas para Diferenciação"))
("derivabbrev" . ("maxima.info-2" 140459 265 "Funções e Variáveis Definidas para Diferenciação"))
("derivdegree" . ("maxima.info-2" 140735 590 "Funções e Variáveis Definidas para Diferenciação"))
("derivlist" . ("maxima.info-2" 141333 145 "Funções e Variáveis Definidas para Diferenciação"))
("derivsubst" . ("maxima.info-2" 141487 217 "Funções e Variáveis Definidas para Diferenciação"))
("describe" . ("maxima.info-1" 35606 2951 "Funções e Variáveis Definidas para Ajuda"))
("describe <1>" . ("maxima.info-1" 35607 2950 "Funções e Variáveis Definidas para Ajuda"))
("describe <2>" . ("maxima.info-1" 35641 2918 "Funções e Variáveis Definidas para Ajuda"))
("desolve" . ("maxima.info-2" 243800 2187 "Funções e Variáveis Definidas para Equações Diferenciais"))
("desolve <1>" . ("maxima.info-2" 243801 2186 "Funções e Variáveis Definidas para Equações Diferenciais"))
("determinant" . ("maxima.info-3" 9584 336 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("detout" . ("maxima.info-3" 9929 997 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dgauss_a" . ("maxima.info-5" 4059 96 "Funções e Variáveis Definidas para contrib_ode"))
("dgauss_b" . ("maxima.info-5" 4160 96 "Funções e Variáveis Definidas para contrib_ode"))
("diag" . ("maxima.info-5" 65631 930 "Funções e Variáveis Definidas para diag"))
("diag_matrix" . ("maxima.info-5" 304895 985 "Funções e Variáveis Definidas para linearalgebra"))
("diagmatrix" . ("maxima.info-3" 10934 526 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("diagmatrixp" . ("maxima.info-3" 185639 100 "Funções e Variáveis Definidas para ctensor"))
("diagmetric" . ("maxima.info-3" 200588 481 "Funções e Variáveis Definidas para ctensor"))
("diff" . ("maxima.info-2" 145073 165 "Funções e Variáveis Definidas para Diferenciação"))
("diff <1>" . ("maxima.info-2" 141714 3288 "Funções e Variáveis Definidas para Diferenciação"))
("diff <2>" . ("maxima.info-2" 141715 3287 "Funções e Variáveis Definidas para Diferenciação"))
("diff <3>" . ("maxima.info-2" 141776 3228 "Funções e Variáveis Definidas para Diferenciação"))
("diff <4>" . ("maxima.info-2" 141814 3192 "Funções e Variáveis Definidas para Diferenciação"))
("diff <5>" . ("maxima.info-3" 101487 819 "Funções e Variáveis Definidas para itensor"))
("digitcharp" . ("maxima.info-6" 160071 108 "Funções e Variáveis para caracteres"))
("dim" . ("maxima.info-3" 200351 223 "Funções e Variáveis Definidas para ctensor"))
("dimension" . ("maxima.info-2" 212820 214 "Funções e Variáveis Definidas para Equações"))
("dimension <1>" . ("maxima.info-2" 212821 213 "Funções e Variáveis Definidas para Equações"))
("direct" . ("maxima.info-3" 281766 3783 "Funções e Variáveis Definidas para Simetrias"))
("discrete_freq" . ("maxima.info-5" 16365 1044 "Funções e Variáveis Definidas para manipulação da dados"))
("disjoin" . ("maxima.info-4" 104607 698 "Funções e Variáveis Definidas para Conjuntos"))
("disjointp" . ("maxima.info-4" 105315 395 "Funções e Variáveis Definidas para Conjuntos"))
("disolate" . ("maxima.info-1" 180686 517 "Funções e Variáveis Definidas para Expressões"))
("disp" . ("maxima.info-1" 292263 294 "Funções e Variáveis Definidas para Entrada e Saída"))
("dispJordan" . ("maxima.info-5" 69085 1061 "Funções e Variáveis Definidas para diag"))
("dispcon" . ("maxima.info-1" 292571 266 "Funções e Variáveis Definidas para Entrada e Saída"))
("dispcon <1>" . ("maxima.info-1" 292572 265 "Funções e Variáveis Definidas para Entrada e Saída"))
("dispflag" . ("maxima.info-2" 213043 286 "Funções e Variáveis Definidas para Equações"))
("dispform" . ("maxima.info-1" 181230 673 "Funções e Variáveis Definidas para Expressões"))
("dispfun" . ("maxima.info-4" 187288 3764 "Funções e Variáveis para Definição de Função"))
("dispfun <1>" . ("maxima.info-4" 187289 3763 "Funções e Variáveis para Definição de Função"))
("display" . ("maxima.info-1" 292846 655 "Funções e Variáveis Definidas para Entrada e Saída"))
("display2d" . ("maxima.info-1" 293523 222 "Funções e Variáveis Definidas para Entrada e Saída"))
("display_format_internal" . ("maxima.info-1" 293754 677 "Funções e Variáveis Definidas para Entrada e Saída"))
("disprule" . ("maxima.info-4" 39154 1401 "Funções e Variáveis Definidas para Regras e Modelos"))
("disprule <1>" . ("maxima.info-4" 39155 1400 "Funções e Variáveis Definidas para Regras e Modelos"))
("dispterms" . ("maxima.info-1" 294443 832 "Funções e Variáveis Definidas para Entrada e Saída"))
("distrib" . ("maxima.info-1" 181927 962 "Funções e Variáveis Definidas para Expressões"))
("divide" . ("maxima.info-2" 24888 604 "Funções e Variáveis Definidas para Polinômios"))
("divisors" . ("maxima.info-4" 105714 1614 "Funções e Variáveis Definidas para Conjuntos"))
("divsum" . ("maxima.info-3" 259179 547 "Funções e Variáveis Definidas para Teoria dos Números"))
("divsum <1>" . ("maxima.info-3" 259180 546 "Funções e Variáveis Definidas para Teoria dos Números"))
("dkummer_m" . ("maxima.info-5" 4867 92 "Funções e Variáveis Definidas para contrib_ode"))
("dkummer_u" . ("maxima.info-5" 4964 94 "Funções e Variáveis Definidas para contrib_ode"))
("do" . ("maxima.info-4" 229666 8891 "Funções e Variáveis Definidas para Fluxo de Programa"))
("doallmxops" . ("maxima.info-3" 11469 274 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("domain" . ("maxima.info-1" 227515 182 "Funções e Variáveis Definidas para Simplificação"))
("domxexpt" . ("maxima.info-3" 11755 1284 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("domxmxops" . ("maxima.info-3" 13049 256 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("domxnctimes" . ("maxima.info-3" 13322 157 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dontfactor" . ("maxima.info-3" 13487 451 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("doscmxops" . ("maxima.info-3" 13964 141 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("doscmxplus" . ("maxima.info-3" 14114 208 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dot0nscsimp" . ("maxima.info-3" 14332 203 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dot0simp" . ("maxima.info-3" 14544 197 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dot1simp" . ("maxima.info-3" 14750 186 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dotassoc" . ("maxima.info-3" 14944 147 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dotconstrules" . ("maxima.info-3" 15098 313 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dotdistrib" . ("maxima.info-3" 15420 156 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dotexptsimp" . ("maxima.info-3" 15583 146 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dotident" . ("maxima.info-3" 15736 102 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dotproduct" . ("maxima.info-5" 305884 225 "Funções e Variáveis Definidas para linearalgebra"))
("dotscrules" . ("maxima.info-3" 15844 196 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("dotsimp" . ("maxima.info-3" 57227 257 "Funções e Variáveis Definidas para Funções Afins"))
("dpart" . ("maxima.info-1" 182903 614 "Funções e Variáveis Definidas para Expressões"))
("draw" . ("maxima.info-5" 236234 932 "Funções e Variáveis Definidas para draw"))
("draw2d" . ("maxima.info-5" 237191 290 "Funções e Variáveis Definidas para draw"))
("draw3d" . ("maxima.info-5" 237497 286 "Funções e Variáveis Definidas para draw"))
("draw_pipes" . ("maxima.info-5" 237798 292 "Funções e Variáveis Definidas para draw"))
("dscalar" . ("maxima.info-2" 145244 134 "Funções e Variáveis Definidas para Diferenciação"))
("dscalar <1>" . ("maxima.info-3" 182790 900 "Funções e Variáveis Definidas para ctensor"))
("e" . ("maxima.info-2" 76423 215 "Funções e Variáveis Definidas para Constantes"))
("echelon" . ("maxima.info-3" 16047 1492 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("eigens_by_jacobi" . ("maxima.info-5" 306113 3178 "Funções e Variáveis Definidas para linearalgebra"))
("eigens_by_jacobi <1>" . ("maxima.info-5" 306114 3177 "Funções e Variáveis Definidas para linearalgebra"))
("eigenvalues" . ("maxima.info-3" 17560 1291 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("eigenvectors" . ("maxima.info-3" 18888 1866 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("eighth" . ("maxima.info-4" 81859 131 "Funções e Variáveis Definidas para Listas"))
("einstein" . ("maxima.info-3" 159821 582 "Funções e Variáveis Definidas para ctensor"))
("eivals" . ("maxima.info-3" 17561 1290 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("eivects" . ("maxima.info-3" 18889 1865 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("elapsed_real_time" . ("maxima.info-4" 11172 512 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("elapsed_run_time" . ("maxima.info-4" 11692 563 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("ele2comp" . ("maxima.info-3" 270632 197 "Funções e Variáveis Definidas para Simetrias"))
("ele2polynome" . ("maxima.info-3" 291521 810 "Funções e Variáveis Definidas para Simetrias"))
("ele2pui" . ("maxima.info-3" 270424 197 "Funções e Variáveis Definidas para Simetrias"))
("elem" . ("maxima.info-3" 270840 1433 "Funções e Variáveis Definidas para Simetrias"))
("elementp" . ("maxima.info-4" 107350 396 "Funções e Variáveis Definidas para Conjuntos"))
("eliminate" . ("maxima.info-2" 25508 1309 "Funções e Variáveis Definidas para Polinômios"))
("elliptic_e" . ("maxima.info-2" 123593 230 "Funções e Variáveis Definidas para Integrais Elípticas"))
("elliptic_ec" . ("maxima.info-2" 124728 286 "Funções e Variáveis Definidas para Integrais Elípticas"))
("elliptic_eu" . ("maxima.info-2" 123828 348 "Funções e Variáveis Definidas para Integrais Elípticas"))
("elliptic_f" . ("maxima.info-2" 123373 215 "Funções e Variáveis Definidas para Integrais Elípticas"))
("elliptic_kc" . ("maxima.info-2" 124433 288 "Funções e Variáveis Definidas para Integrais Elípticas"))
("elliptic_pi" . ("maxima.info-2" 124183 243 "Funções e Variáveis Definidas para Integrais Elípticas"))
("ematrix" . ("maxima.info-3" 20805 171 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("emptyp" . ("maxima.info-4" 107750 319 "Funções e Variáveis Definidas para Conjuntos"))
("endcons" . ("maxima.info-4" 81994 230 "Funções e Variáveis Definidas para Listas"))
("enhanced3d" . ("maxima.info-5" 196607 539 "Funções e Variáveis Definidas para draw"))
("entermatrix" . ("maxima.info-3" 20981 1369 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("entertensor" . ("maxima.info-3" 73274 341 "Funções e Variáveis Definidas para itensor"))
("entier" . ("maxima.info-1" 111261 199 "Operadores Geral"))
("eps_height" . ("maxima.info-5" 190982 607 "Funções e Variáveis Definidas para draw"))
("eps_width" . ("maxima.info-5" 190352 609 "Funções e Variáveis Definidas para draw"))
("epsilon_sx" . ("maxima.info-6" 69974 164 "Funções e Variáveis Definidas para simplex"))
("equal" . ("maxima.info-1" 111470 4293 "Operadores Geral"))
("equalp" . ("maxima.info-2" 267504 186 "Funções e Variáveis Definidas para Séries de Fourier"))
("equiv_classes" . ("maxima.info-4" 108072 1265 "Funções e Variáveis Definidas para Conjuntos"))
("erf" . ("maxima.info-2" 160216 103 "Funções e Variáveis Definidas para Integração"))
("erfflag" . ("maxima.info-2" 160325 203 "Funções e Variáveis Definidas para Integração"))
("errcatch" . ("maxima.info-4" 238758 505 "Funções e Variáveis Definidas para Fluxo de Programa"))
("error" . ("maxima.info-4" 239272 716 "Funções e Variáveis Definidas para Fluxo de Programa"))
("error <1>" . ("maxima.info-4" 239273 715 "Funções e Variáveis Definidas para Fluxo de Programa"))
("error_size" . ("maxima.info-1" 295296 1524 "Funções e Variáveis Definidas para Entrada e Saída"))
("error_syms" . ("maxima.info-1" 296855 657 "Funções e Variáveis Definidas para Entrada e Saída"))
("errormsg" . ("maxima.info-4" 240007 162 "Funções e Variáveis Definidas para Fluxo de Programa"))
("euler" . ("maxima.info-3" 259738 295 "Funções e Variáveis Definidas para Teoria dos Números"))
("ev" . ("maxima.info-1" 50523 8794 "Funções e Variáveis Definidas para Linha de Comando"))
("ev_point" . ("maxima.info-6" 207800 188 "Funções e Variáveis Definidas para zeilberger"))
("eval" . ("maxima.info-1" 118680 135 "Operadores Geral"))
("eval_string" . ("maxima.info-5" 249732 695 "Funções e Variáveis Definidas para eval_string"))
("evenp" . ("maxima.info-1" 118818 132 "Operadores Geral"))
("every" . ("maxima.info-4" 109375 2910 "Funções e Variáveis Definidas para Conjuntos"))
("every <1>" . ("maxima.info-4" 109376 2909 "Funções e Variáveis Definidas para Conjuntos"))
("evflag" . ("maxima.info-1" 59519 2439 "Funções e Variáveis Definidas para Linha de Comando"))
("evfun" . ("maxima.info-1" 61971 2918 "Funções e Variáveis Definidas para Linha de Comando"))
("evolution" . ("maxima.info-5" 240908 655 "Funções e Variáveis Definidas para dynamics"))
("evolution2d" . ("maxima.info-5" 241581 556 "Funções e Variáveis Definidas para dynamics"))
("evundiff" . ("maxima.info-3" 104597 2394 "Funções e Variáveis Definidas para itensor"))
("example" . ("maxima.info-1" 38587 1132 "Funções e Variáveis Definidas para Ajuda"))
("example <1>" . ("maxima.info-1" 38588 1131 "Funções e Variáveis Definidas para Ajuda"))
("exp" . ("maxima.info-1" 183526 573 "Funções e Variáveis Definidas para Expressões"))
("expand" . ("maxima.info-1" 227703 1983 "Funções e Variáveis Definidas para Simplificação"))
("expand <1>" . ("maxima.info-1" 227704 1982 "Funções e Variáveis Definidas para Simplificação"))
("expandwrt" . ("maxima.info-1" 229745 616 "Funções e Variáveis Definidas para Simplificação"))
("expandwrt_denom" . ("maxima.info-1" 230385 393 "Funções e Variáveis Definidas para Simplificação"))
("expandwrt_factored" . ("maxima.info-1" 230789 379 "Funções e Variáveis Definidas para Simplificação"))
("explose" . ("maxima.info-3" 280378 248 "Funções e Variáveis Definidas para Simetrias"))
("expon" . ("maxima.info-1" 231178 275 "Funções e Variáveis Definidas para Simplificação"))
("exponenciação não comutativa" . ("maxima.info-1" 88702 16 "Operadores Geral"))
("exponentialize" . ("maxima.info-1" 231464 575 "Funções e Variáveis Definidas para Simplificação"))
("exponentialize <1>" . ("maxima.info-1" 231465 574 "Funções e Variáveis Definidas para Simplificação"))
("expop" . ("maxima.info-1" 232061 431 "Funções e Variáveis Definidas para Simplificação"))
("express" . ("maxima.info-2" 145385 2733 "Funções e Variáveis Definidas para Diferenciação"))
("expt" . ("maxima.info-1" 297537 264 "Funções e Variáveis Definidas para Entrada e Saída"))
("exptdispflag" . ("maxima.info-1" 297808 198 "Funções e Variáveis Definidas para Entrada e Saída"))
("exptisolate" . ("maxima.info-1" 185054 203 "Funções e Variáveis Definidas para Expressões"))
("exptsubst" . ("maxima.info-1" 185263 162 "Funções e Variáveis Definidas para Expressões"))
("exsec" . ("maxima.info-6" 86308 147 "Funções e Variáveis Definidas para simplification"))
("extdiff" . ("maxima.info-3" 136712 1458 "Funções e Variáveis Definidas para itensor"))
("extract_linear_equations" . ("maxima.info-3" 59102 403 "Funções e Variáveis Definidas para Funções Afins"))
("extremal_subset" . ("maxima.info-4" 112312 713 "Funções e Variáveis Definidas para Conjuntos"))
("extremal_subset <1>" . ("maxima.info-4" 112313 712 "Funções e Variáveis Definidas para Conjuntos"))
("ezgcd" . ("maxima.info-2" 26838 263 "Funções e Variáveis Definidas para Polinômios"))
("f90" . ("maxima.info-5" 251608 1667 "Funções e Variáveis Definidas para f90"))
("facexpand" . ("maxima.info-2" 27109 219 "Funções e Variáveis Definidas para Polinômios"))
("facsum" . ("maxima.info-6" 76945 2247 "Funções e Variáveis Definidas para simplification"))
("facsum_combine" . ("maxima.info-6" 80034 721 "Funções e Variáveis Definidas para simplification"))
("factcomb" . ("maxima.info-2" 27336 293 "Funções e Variáveis Definidas para Polinômios"))
("factlim" . ("maxima.info-1" 232503 186 "Funções e Variáveis Definidas para Simplificação"))
("factor" . ("maxima.info-2" 27635 6156 "Funções e Variáveis Definidas para Polinômios"))
("factor <1>" . ("maxima.info-2" 27636 6155 "Funções e Variáveis Definidas para Polinômios"))
("factorfacsum" . ("maxima.info-6" 80773 352 "Funções e Variáveis Definidas para simplification"))
("factorflag" . ("maxima.info-2" 33858 170 "Funções e Variáveis Definidas para Polinômios"))
("factorial" . ("maxima.info-3" 260124 138 "Funções e Variáveis Definidas para Teoria dos Números"))
("factorout" . ("maxima.info-2" 34036 237 "Funções e Variáveis Definidas para Polinômios"))
("factorsum" . ("maxima.info-2" 34284 858 "Funções e Variáveis Definidas para Polinômios"))
("facts" . ("maxima.info-2" 15245 449 "Funções e Variáveis Definidas para Contextos"))
("facts <1>" . ("maxima.info-2" 15246 448 "Funções e Variáveis Definidas para Contextos"))
("false" . ("maxima.info-2" 76719 137 "Funções e Variáveis Definidas para Constantes"))
("fast_central_elements" . ("maxima.info-3" 57495 421 "Funções e Variáveis Definidas para Funções Afins"))
("fast_linsolve" . ("maxima.info-3" 54529 686 "Funções e Variáveis Definidas para Funções Afins"))
("fasttimes" . ("maxima.info-2" 35154 422 "Funções e Variáveis Definidas para Polinômios"))
("fb" . ("maxima.info-3" 205677 110 "Funções e Variáveis Definidas para ctensor"))
("feature" . ("maxima.info-4" 5468 384 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("featurep" . ("maxima.info-4" 5869 530 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("features" . ("maxima.info-2" 15703 1102 "Funções e Variáveis Definidas para Contextos"))
("fft" . ("maxima.info-2" 254906 2359 "Funções e Variáveis Definidas para Numérico"))
("fib" . ("maxima.info-3" 260267 416 "Funções e Variáveis Definidas para Teoria dos Números"))
("fibtophi" . ("maxima.info-3" 260692 1209 "Funções e Variáveis Definidas para Teoria dos Números"))
("fifth" . ("maxima.info-4" 82229 126 "Funções e Variáveis Definidas para Listas"))
("file_name" . ("maxima.info-5" 188544 579 "Funções e Variáveis Definidas para draw"))
("file_output_append" . ("maxima.info-1" 286133 669 "Funções e Variáveis Definidas para Entrada e Saída"))
("file_search" . ("maxima.info-1" 298365 1980 "Funções e Variáveis Definidas para Entrada e Saída"))
("file_search <1>" . ("maxima.info-1" 298366 1979 "Funções e Variáveis Definidas para Entrada e Saída"))
("file_search_demo" . ("maxima.info-1" 300423 1598 "Funções e Variáveis Definidas para Entrada e Saída"))
("file_search_lisp" . ("maxima.info-1" 300378 1640 "Funções e Variáveis Definidas para Entrada e Saída"))
("file_search_maxima" . ("maxima.info-1" 300377 1641 "Funções e Variáveis Definidas para Entrada e Saída"))
("file_type" . ("maxima.info-1" 302059 575 "Funções e Variáveis Definidas para Entrada e Saída"))
("filename_merge" . ("maxima.info-1" 298013 344 "Funções e Variáveis Definidas para Entrada e Saída"))
("fill_color" . ("maxima.info-5" 209394 234 "Funções e Variáveis Definidas para draw"))
("fillarray" . ("maxima.info-2" 280291 2248 "Funções e Variáveis Definidas para Arrays"))
("filled_func" . ("maxima.info-5" 200282 428 "Funções e Variáveis Definidas para draw"))
("find_root" . ("maxima.info-2" 261275 2417 "Funções e Variáveis Definidas para Numérico"))
("find_root <1>" . ("maxima.info-2" 261276 2416 "Funções e Variáveis Definidas para Numérico"))
("find_root_abs" . ("maxima.info-2" 263740 681 "Funções e Variáveis Definidas para Numérico"))
("find_root_error" . ("maxima.info-2" 264440 715 "Funções e Variáveis Definidas para Numérico"))
("find_root_rel" . ("maxima.info-2" 265177 669 "Funções e Variáveis Definidas para Numérico"))
("findde" . ("maxima.info-3" 179105 2326 "Funções e Variáveis Definidas para ctensor"))
("first" . ("maxima.info-4" 82359 770 "Funções e Variáveis Definidas para Listas"))
("fix" . ("maxima.info-1" 118954 60 "Operadores Geral"))
("flatten" . ("maxima.info-4" 113039 2630 "Funções e Variáveis Definidas para Conjuntos"))
("flength" . ("maxima.info-6" 151675 77 "Funções e Variáveis para entrada e saída"))
("flipflag" . ("maxima.info-3" 79335 659 "Funções e Variáveis Definidas para itensor"))
("float" . ("maxima.info-2" 3064 326 "Funções e Variáveis Definidas para ponto Flutuante"))
("float2bf" . ("maxima.info-2" 3399 288 "Funções e Variáveis Definidas para ponto Flutuante"))
("floatnump" . ("maxima.info-2" 3697 132 "Funções e Variáveis Definidas para ponto Flutuante"))
("floor" . ("maxima.info-1" 115796 1917 "Operadores Geral"))
("flush" . ("maxima.info-3" 107011 168 "Funções e Variáveis Definidas para itensor"))
("flush1deriv" . ("maxima.info-3" 113078 163 "Funções e Variáveis Definidas para itensor"))
("flushd" . ("maxima.info-3" 107185 165 "Funções e Variáveis Definidas para itensor"))
("flushnd" . ("maxima.info-3" 107355 718 "Funções e Variáveis Definidas para itensor"))
("for" . ("maxima.info-4" 240173 126 "Funções e Variáveis Definidas para Fluxo de Programa"))
("forget" . ("maxima.info-2" 16825 347 "Funções e Variáveis Definidas para Contextos"))
("forget <1>" . ("maxima.info-2" 16826 346 "Funções e Variáveis Definidas para Contextos"))
("fortindent" . ("maxima.info-2" 257313 313 "Funções e Variáveis Definidas para Numérico"))
("fortran" . ("maxima.info-2" 257640 2262 "Funções e Variáveis Definidas para Numérico"))
("fortspaces" . ("maxima.info-2" 259945 191 "Funções e Variáveis Definidas para Numérico"))
("fourcos" . ("maxima.info-2" 269702 135 "Funções e Variáveis Definidas para Séries de Fourier"))
("fourexpand" . ("maxima.info-2" 269426 270 "Funções e Variáveis Definidas para Séries de Fourier"))
("fourier" . ("maxima.info-2" 268946 144 "Funções e Variáveis Definidas para Séries de Fourier"))
("fourint" . ("maxima.info-2" 270104 153 "Funções e Variáveis Definidas para Séries de Fourier"))
("fourintcos" . ("maxima.info-2" 270261 133 "Funções e Variáveis Definidas para Séries de Fourier"))
("fourintsin" . ("maxima.info-2" 270397 132 "Funções e Variáveis Definidas para Séries de Fourier"))
("foursimp" . ("maxima.info-2" 269093 154 "Funções e Variáveis Definidas para Séries de Fourier"))
("foursin" . ("maxima.info-2" 269840 132 "Funções e Variáveis Definidas para Séries de Fourier"))
("fourth" . ("maxima.info-4" 83150 126 "Funções e Variáveis Definidas para Listas"))
("fposition" . ("maxima.info-6" 151756 323 "Funções e Variáveis para entrada e saída"))
("fposition <1>" . ("maxima.info-6" 151757 322 "Funções e Variáveis para entrada e saída"))
("fpprec" . ("maxima.info-2" 3833 287 "Funções e Variáveis Definidas para ponto Flutuante"))
("fpprintprec" . ("maxima.info-2" 4133 848 "Funções e Variáveis Definidas para ponto Flutuante"))
("frame_bracket" . ("maxima.info-3" 169941 317 "Funções e Variáveis Definidas para ctensor"))
("freeof" . ("maxima.info-1" 185432 4167 "Funções e Variáveis Definidas para Expressões"))
("freshline" . ("maxima.info-6" 152094 175 "Funções e Variáveis para entrada e saída"))
("freshline <1>" . ("maxima.info-6" 152095 174 "Funções e Variáveis para entrada e saída"))
("full_listify" . ("maxima.info-4" 115711 578 "Funções e Variáveis Definidas para Conjuntos"))
("fullmap" . ("maxima.info-1" 119018 719 "Operadores Geral"))
("fullmapl" . ("maxima.info-1" 119749 264 "Operadores Geral"))
("fullratsimp" . ("maxima.info-2" 35593 1669 "Funções e Variáveis Definidas para Polinômios"))
("fullratsubst" . ("maxima.info-2" 37280 2145 "Funções e Variáveis Definidas para Polinômios"))
("fullsetify" . ("maxima.info-4" 116294 679 "Funções e Variáveis Definidas para Conjuntos"))
("funcsolve" . ("maxima.info-2" 213338 932 "Funções e Variáveis Definidas para Equações"))
("functions" . ("maxima.info-4" 191106 1887 "Funções e Variáveis para Definição de Função"))
("fundef" . ("maxima.info-4" 193026 864 "Funções e Variáveis para Definição de Função"))
("funmake" . ("maxima.info-4" 193978 3077 "Funções e Variáveis para Definição de Função"))
("funp" . ("maxima.info-2" 268029 301 "Funções e Variáveis Definidas para Séries de Fourier"))
("funp <1>" . ("maxima.info-2" 268030 300 "Funções e Variáveis Definidas para Séries de Fourier"))
("gamma" . ("maxima.info-2" 107831 194 "Funções e Variáveis Definidas para Funções Especiais"))
("gammalim" . ("maxima.info-2" 108037 400 "Funções e Variáveis Definidas para Funções Especiais"))
("gauss_a" . ("maxima.info-5" 3433 537 "Funções e Variáveis Definidas para contrib_ode"))
("gauss_b" . ("maxima.info-5" 3994 62 "Funções e Variáveis Definidas para contrib_ode"))
("gaussprob" . ("maxima.info-6" 85499 178 "Funções e Variáveis Definidas para simplification"))
("gcd" . ("maxima.info-2" 39468 1236 "Funções e Variáveis Definidas para Polinômios"))
("gcdex" . ("maxima.info-2" 40737 1600 "Funções e Variáveis Definidas para Polinômios"))
("gcdex <1>" . ("maxima.info-2" 40738 1599 "Funções e Variáveis Definidas para Polinômios"))
("gcdivide" . ("maxima.info-6" 83996 326 "Funções e Variáveis Definidas para simplification"))
("gcfac" . ("maxima.info-6" 93486 1013 "Funções e Variáveis Definidas para simplification"))
("gcfactor" . ("maxima.info-2" 42367 270 "Funções e Variáveis Definidas para Polinômios"))
("gd" . ("maxima.info-6" 85684 150 "Funções e Variáveis Definidas para simplification"))
("gdet" . ("maxima.info-3" 203121 161 "Funções e Variáveis Definidas para ctensor"))
("gen_laguerre" . ("maxima.info-6" 43038 150 "Funções e Variáveis Definidas para polinômios ortogonais"))
("genfact" . ("maxima.info-1" 189672 228 "Funções e Variáveis Definidas para Expressões"))
("genindex" . ("maxima.info-4" 16249 157 "Funções e Variáveis Definidas para Opções Diversas"))
("genmatrix" . ("maxima.info-3" 22364 2782 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("genmatrix <1>" . ("maxima.info-3" 22365 2781 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("genmatrix <2>" . ("maxima.info-3" 22423 2725 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("gensumnum" . ("maxima.info-4" 16416 259 "Funções e Variáveis Definidas para Opções Diversas"))
("geometric" . ("maxima.info-6" 84557 211 "Funções e Variáveis Definidas para simplification"))
("geometric_mean" . ("maxima.info-5" 37697 936 "Funções e Variáveis Definidas para estatística descritiva"))
("geometric_mean <1>" . ("maxima.info-5" 37698 935 "Funções e Variáveis Definidas para estatística descritiva"))
("geosum" . ("maxima.info-6" 85202 288 "Funções e Variáveis Definidas para simplification"))
("get" . ("maxima.info-4" 83280 1000 "Funções e Variáveis Definidas para Listas"))
("get_lu_factors" . ("maxima.info-5" 309308 298 "Funções e Variáveis Definidas para linearalgebra"))
("gfactor" . ("maxima.info-2" 42646 332 "Funções e Variáveis Definidas para Polinômios"))
("gfactorsum" . ("maxima.info-2" 42985 104 "Funções e Variáveis Definidas para Polinômios"))
("ggf" . ("maxima.info-5" 254854 519 "Funções e Variáveis Definidas para ggf"))
("global_variances" . ("maxima.info-5" 45430 1828 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("global_variances <1>" . ("maxima.info-5" 45431 1827 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("globalsolve" . ("maxima.info-2" 214291 2115 "Funções e Variáveis Definidas para Equações"))
("gnuplot_close" . ("maxima.info-1" 275270 120 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("gnuplot_replot" . ("maxima.info-1" 275531 273 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("gnuplot_replot <1>" . ("maxima.info-1" 275532 272 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("gnuplot_reset" . ("maxima.info-1" 275814 209 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("gnuplot_restart" . ("maxima.info-1" 275394 133 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("gnuplot_start" . ("maxima.info-1" 275060 202 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("go" . ("maxima.info-4" 240306 596 "Funções e Variáveis Definidas para Fluxo de Programa"))
("gosper_in_zeilberger" . ("maxima.info-6" 206859 258 "Funções e Variáveis Definidas para zeilberger"))
("gr2d" . ("maxima.info-5" 216989 12635 "Funções e Variáveis Definidas para draw"))
("gr3d" . ("maxima.info-5" 229766 6384 "Funções e Variáveis Definidas para draw"))
("gradef" . ("maxima.info-2" 148131 1990 "Funções e Variáveis Definidas para Diferenciação"))
("gradef <1>" . ("maxima.info-2" 148132 1989 "Funções e Variáveis Definidas para Diferenciação"))
("gradefs" . ("maxima.info-2" 150175 276 "Funções e Variáveis Definidas para Diferenciação"))
("gramschmidt" . ("maxima.info-3" 25174 1932 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("grid" . ("maxima.info-5" 181840 361 "Funções e Variáveis Definidas para draw"))
("grind" . ("maxima.info-1" 302650 4666 "Funções e Variáveis Definidas para Entrada e Saída"))
("grind <1>" . ("maxima.info-1" 302651 4665 "Funções e Variáveis Definidas para Entrada e Saída"))
("grobner_basis" . ("maxima.info-3" 55239 607 "Funções e Variáveis Definidas para Funções Afins"))
("gschmit" . ("maxima.info-3" 25175 1931 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("halfangles" . ("maxima.info-2" 91812 152 "Funções e Variáveis Definidas para Trigonometria"))
("hankel" . ("maxima.info-5" 309615 291 "Funções e Variáveis Definidas para linearalgebra"))
("hankel <1>" . ("maxima.info-5" 309616 290 "Funções e Variáveis Definidas para linearalgebra"))
("harmonic" . ("maxima.info-6" 84776 242 "Funções e Variáveis Definidas para simplification"))
("harmonic_mean" . ("maxima.info-5" 36742 945 "Funções e Variáveis Definidas para estatística descritiva"))
("harmonic_mean <1>" . ("maxima.info-5" 36743 944 "Funções e Variáveis Definidas para estatística descritiva"))
("hav" . ("maxima.info-6" 86460 139 "Funções e Variáveis Definidas para simplification"))
("head_angle" . ("maxima.info-5" 203213 1249 "Funções e Variáveis Definidas para draw"))
("head_both" . ("maxima.info-5" 201859 620 "Funções e Variáveis Definidas para draw"))
("head_length" . ("maxima.info-5" 202490 714 "Funções e Variáveis Definidas para draw"))
("head_type" . ("maxima.info-5" 204472 820 "Funções e Variáveis Definidas para draw"))
("hermite" . ("maxima.info-6" 43196 127 "Funções e Variáveis Definidas para polinômios ortogonais"))
("hessian" . ("maxima.info-5" 309916 199 "Funções e Variáveis Definidas para linearalgebra"))
("hilbert_matrix" . ("maxima.info-5" 310123 155 "Funções e Variáveis Definidas para linearalgebra"))
("hipow" . ("maxima.info-2" 43093 886 "Funções e Variáveis Definidas para Polinômios"))
("histogram" . ("maxima.info-5" 58700 2278 "Funções e Variáveis Definidas para gráficos estatísticos"))
("histogram <1>" . ("maxima.info-5" 58701 2277 "Funções e Variáveis Definidas para gráficos estatísticos"))
("histogram <2>" . ("maxima.info-5" 58735 2245 "Funções e Variáveis Definidas para gráficos estatísticos"))
("histogram <3>" . ("maxima.info-5" 58800 2186 "Funções e Variáveis Definidas para gráficos estatísticos"))
("hodge" . ("maxima.info-3" 138182 1520 "Funções e Variáveis Definidas para itensor"))
("horner" . ("maxima.info-2" 260143 1115 "Funções e Variáveis Definidas para Numérico"))
("horner <1>" . ("maxima.info-2" 260144 1114 "Funções e Variáveis Definidas para Numérico"))
("i" . ("maxima.info-2" 76646 71 "Funções e Variáveis Definidas para Constantes"))
("ibase" . ("maxima.info-1" 307354 533 "Funções e Variáveis Definidas para Entrada e Saída"))
("ic1" . ("maxima.info-2" 246020 450 "Funções e Variáveis Definidas para Equações Diferenciais"))
("ic2" . ("maxima.info-2" 246488 676 "Funções e Variáveis Definidas para Equações Diferenciais"))
("ic_convert" . ("maxima.info-3" 141937 2253 "Funções e Variáveis Definidas para itensor"))
("icc1" . ("maxima.info-3" 123609 631 "Funções e Variáveis Definidas para itensor"))
("icc2" . ("maxima.info-3" 124259 667 "Funções e Variáveis Definidas para itensor"))
("ichr1" . ("maxima.info-3" 113935 355 "Funções e Variáveis Definidas para itensor"))
("ichr2" . ("maxima.info-3" 114301 283 "Funções e Variáveis Definidas para itensor"))
("icounter" . ("maxima.info-3" 89386 257 "Funções e Variáveis Definidas para itensor"))
("icurvature" . ("maxima.info-3" 114590 584 "Funções e Variáveis Definidas para itensor"))
("ident" . ("maxima.info-3" 27142 72 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("identfor" . ("maxima.info-5" 310282 625 "Funções e Variáveis Definidas para linearalgebra"))
("identfor <1>" . ("maxima.info-5" 310283 624 "Funções e Variáveis Definidas para linearalgebra"))
("identity" . ("maxima.info-4" 116985 285 "Funções e Variáveis Definidas para Conjuntos"))
("idiff" . ("maxima.info-3" 102338 775 "Funções e Variáveis Definidas para itensor"))
("idim" . ("maxima.info-3" 113752 175 "Funções e Variáveis Definidas para itensor"))
("idummy" . ("maxima.info-3" 88848 351 "Funções e Variáveis Definidas para itensor"))
("idummyx" . ("maxima.info-3" 89214 164 "Funções e Variáveis Definidas para itensor"))
("ieqn" . ("maxima.info-2" 216437 1401 "Funções e Variáveis Definidas para Equações"))
("ieqnprint" . ("maxima.info-2" 217895 708 "Funções e Variáveis Definidas para Equações"))
("if" . ("maxima.info-4" 240918 2675 "Funções e Variáveis Definidas para Fluxo de Programa"))
("ifactors" . ("maxima.info-3" 261906 580 "Funções e Variáveis Definidas para Teoria dos Números"))
("ifb" . ("maxima.info-3" 122564 1031 "Funções e Variáveis Definidas para itensor"))
("ifc1" . ("maxima.info-3" 124945 459 "Funções e Variáveis Definidas para itensor"))
("ifc2" . ("maxima.info-3" 125414 420 "Funções e Variáveis Definidas para itensor"))
("ifg" . ("maxima.info-3" 126217 120 "Funções e Variáveis Definidas para itensor"))
("ifgi" . ("maxima.info-3" 126342 120 "Funções e Variáveis Definidas para itensor"))
("ifr" . ("maxima.info-3" 125845 156 "Funções e Variáveis Definidas para itensor"))
("iframe_bracket_form" . ("maxima.info-3" 126466 134 "Funções e Variáveis Definidas para itensor"))
("iframes" . ("maxima.info-3" 122348 205 "Funções e Variáveis Definidas para itensor"))
("ifri" . ("maxima.info-3" 126004 209 "Funções e Variáveis Definidas para itensor"))
("ifs" . ("maxima.info-5" 242151 893 "Funções e Variáveis Definidas para dynamics"))
("ift" . ("maxima.info-2" 254462 430 "Funções e Variáveis Definidas para Numérico"))
("ift <1>" . ("maxima.info-2" 254907 2358 "Funções e Variáveis Definidas para Numérico"))
("igeodesic_coords" . ("maxima.info-3" 117152 1915 "Funções e Variáveis Definidas para itensor"))
("igeowedge_flag" . ("maxima.info-3" 139705 409 "Funções e Variáveis Definidas para itensor"))
("ikt1" . ("maxima.info-3" 128282 450 "Funções e Variáveis Definidas para itensor"))
("ikt2" . ("maxima.info-3" 128740 285 "Funções e Variáveis Definidas para itensor"))
("ilt" . ("maxima.info-2" 160540 2160 "Funções e Variáveis Definidas para Integração"))
("imagpart" . ("maxima.info-1" 189903 238 "Funções e Variáveis Definidas para Expressões"))
("imetric" . ("maxima.info-3" 113315 415 "Funções e Variáveis Definidas para itensor"))
("imetric <1>" . ("maxima.info-3" 113316 414 "Funções e Variáveis Definidas para itensor"))
("implicit_derivative" . ("maxima.info-5" 272031 448 "Funções e Variáveis Definidas para impdiff"))
("implicit_plot" . ("maxima.info-5" 272919 1042 "Funções e Variáveis Definidas para implicit_plot"))
("implicit_plot <1>" . ("maxima.info-5" 272920 1041 "Funções e Variáveis Definidas para implicit_plot"))
("in_netmath" . ("maxima.info-1" 248113 292 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("inchar" . ("maxima.info-1" 307903 681 "Funções e Variáveis Definidas para Entrada e Saída"))
("indexed_tensor" . ("maxima.info-3" 81876 234 "Funções e Variáveis Definidas para itensor"))
("indices" . ("maxima.info-3" 74928 1023 "Funções e Variáveis Definidas para itensor"))
("inf" . ("maxima.info-2" 76858 67 "Funções e Variáveis Definidas para Constantes"))
("inf <1>" . ("maxima.info-4" 16688 48 "Funções e Variáveis Definidas para Opções Diversas"))
("inference_result" . ("maxima.info-6" 107304 1936 "Funções e Variáveis Definidas para inference_result"))
("inferencep" . ("maxima.info-6" 109283 128 "Funções e Variáveis Definidas para inference_result"))
("infeval" . ("maxima.info-1" 64906 400 "Funções e Variáveis Definidas para Linha de Comando"))
("infinity" . ("maxima.info-2" 76926 72 "Funções e Variáveis Definidas para Constantes"))
("infinity <1>" . ("maxima.info-4" 16737 135 "Funções e Variáveis Definidas para Opções Diversas"))
("infix" . ("maxima.info-1" 190155 3510 "Funções e Variáveis Definidas para Expressões"))
("infix <1>" . ("maxima.info-1" 190156 3509 "Funções e Variáveis Definidas para Expressões"))
("infix <2>" . ("maxima.info-1" 190183 3484 "Funções e Variáveis Definidas para Expressões"))
("inflag" . ("maxima.info-1" 193711 734 "Funções e Variáveis Definidas para Expressões"))
("infolists" . ("maxima.info-4" 16876 2176 "Funções e Variáveis Definidas para Opções Diversas"))
("init_atensor" . ("maxima.info-3" 215928 2535 "Funções e Variáveis Definidas para o Pacote atensor"))
("init_atensor <1>" . ("maxima.info-3" 215929 2534 "Funções e Variáveis Definidas para o Pacote atensor"))
("init_ctensor" . ("maxima.info-3" 156400 370 "Funções e Variáveis Definidas para ctensor"))
("inm" . ("maxima.info-3" 126979 353 "Funções e Variáveis Definidas para itensor"))
("inmc1" . ("maxima.info-3" 127341 379 "Funções e Variáveis Definidas para itensor"))
("inmc2" . ("maxima.info-3" 127726 548 "Funções e Variáveis Definidas para itensor"))
("innerproduct" . ("maxima.info-3" 27217 471 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("inpart" . ("maxima.info-1" 194462 1303 "Funções e Variáveis Definidas para Expressões"))
("inprod" . ("maxima.info-3" 27218 470 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("inrt" . ("maxima.info-3" 262502 292 "Funções e Variáveis Definidas para Teoria dos Números"))
("integer_partitions" . ("maxima.info-4" 117273 1952 "Funções e Variáveis Definidas para Conjuntos"))
("integer_partitions <1>" . ("maxima.info-4" 117274 1951 "Funções e Variáveis Definidas para Conjuntos"))
("integerp" . ("maxima.info-4" 19113 956 "Funções e Variáveis Definidas para Opções Diversas"))
("integrate" . ("maxima.info-2" 162720 8627 "Funções e Variáveis Definidas para Integração"))
("integrate <1>" . ("maxima.info-2" 162721 8626 "Funções e Variáveis Definidas para Integração"))
("integrate_use_rootsof" . ("maxima.info-2" 171835 2426 "Funções e Variáveis Definidas para Integração"))
("integration_constant_counter" . ("maxima.info-2" 171494 326 "Funções e Variáveis Definidas para Integração"))
("intersect" . ("maxima.info-4" 119264 104 "Funções e Variáveis Definidas para Conjuntos"))
("intersection" . ("maxima.info-4" 119372 942 "Funções e Variáveis Definidas para Conjuntos"))
("intervalp" . ("maxima.info-6" 43331 113 "Funções e Variáveis Definidas para polinômios ortogonais"))
("intfaclim" . ("maxima.info-2" 43990 760 "Funções e Variáveis Definidas para Polinômios"))
("intopois" . ("maxima.info-2" 108455 70 "Funções e Variáveis Definidas para Funções Especiais"))
("intosum" . ("maxima.info-1" 232697 512 "Funções e Variáveis Definidas para Simplificação"))
("inv_mod" . ("maxima.info-3" 262799 385 "Funções e Variáveis Definidas para Teoria dos Números"))
("invariant1" . ("maxima.info-3" 184901 202 "Funções e Variáveis Definidas para ctensor"))
("invariant2" . ("maxima.info-3" 185111 257 "Funções e Variáveis Definidas para ctensor"))
("inverse_jacobi_cd" . ("maxima.info-2" 122683 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_cn" . ("maxima.info-2" 121983 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_cs" . ("maxima.info-2" 122583 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_dc" . ("maxima.info-2" 122983 96 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_dn" . ("maxima.info-2" 122083 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_ds" . ("maxima.info-2" 122883 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_nc" . ("maxima.info-2" 122483 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_nd" . ("maxima.info-2" 122783 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_ns" . ("maxima.info-2" 122183 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_sc" . ("maxima.info-2" 122283 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_sd" . ("maxima.info-2" 122383 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("inverse_jacobi_sn" . ("maxima.info-2" 121883 94 "Funções e Variáveis Definidas para Funções Elípticas"))
("invert" . ("maxima.info-3" 27704 1126 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("invert_by_lu" . ("maxima.info-5" 310918 175 "Funções e Variáveis Definidas para linearalgebra"))
("ip_grid" . ("maxima.info-5" 216552 207 "Funções e Variáveis Definidas para draw"))
("ip_grid_in" . ("maxima.info-5" 216769 210 "Funções e Variáveis Definidas para draw"))
("is" . ("maxima.info-1" 120016 1941 "Operadores Geral"))
("ishow" . ("maxima.info-3" 74585 333 "Funções e Variáveis Definidas para itensor"))
("isolate" . ("maxima.info-1" 195793 846 "Funções e Variáveis Definidas para Expressões"))
("isolate_wrt_times" . ("maxima.info-1" 196677 779 "Funções e Variáveis Definidas para Expressões"))
("isqrt" . ("maxima.info-1" 122734 112 "Operadores Geral"))
("items_inference" . ("maxima.info-6" 109416 708 "Funções e Variáveis Definidas para inference_result"))
("itr" . ("maxima.info-3" 129033 2670 "Funções e Variáveis Definidas para itensor"))
("jacobi" . ("maxima.info-3" 263188 251 "Funções e Variáveis Definidas para Teoria dos Números"))
("jacobi_cd" . ("maxima.info-2" 121493 93 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_cn" . ("maxima.info-2" 120848 75 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_cs" . ("maxima.info-2" 121394 93 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_dc" . ("maxima.info-2" 121784 93 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_dn" . ("maxima.info-2" 120929 75 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_ds" . ("maxima.info-2" 121685 93 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_nc" . ("maxima.info-2" 121301 87 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_nd" . ("maxima.info-2" 121592 87 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_ns" . ("maxima.info-2" 121010 87 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_p" . ("maxima.info-6" 43448 342 "Funções e Variáveis Definidas para polinômios ortogonais"))
("jacobi_sc" . ("maxima.info-2" 121103 93 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_sd" . ("maxima.info-2" 121202 93 "Funções e Variáveis Definidas para Funções Elípticas"))
("jacobi_sn" . ("maxima.info-2" 120767 75 "Funções e Variáveis Definidas para Funções Elípticas"))
("join" . ("maxima.info-4" 84286 746 "Funções e Variáveis Definidas para Listas"))
("jordan" . ("maxima.info-5" 67399 1674 "Funções e Variáveis Definidas para diag"))
("kdels" . ("maxima.info-3" 90531 858 "Funções e Variáveis Definidas para itensor"))
("kdelta" . ("maxima.info-3" 89658 848 "Funções e Variáveis Definidas para itensor"))
("keepfloat" . ("maxima.info-2" 44773 279 "Funções e Variáveis Definidas para Polinômios"))
("key" . ("maxima.info-5" 211818 748 "Funções e Variáveis Definidas para draw"))
("kill" . ("maxima.info-1" 65318 2832 "Funções e Variáveis Definidas para Linha de Comando"))
("kill <1>" . ("maxima.info-1" 65319 2831 "Funções e Variáveis Definidas para Linha de Comando"))
("kill <2>" . ("maxima.info-1" 65358 2794 "Funções e Variáveis Definidas para Linha de Comando"))
("kill <3>" . ("maxima.info-1" 65386 2768 "Funções e Variáveis Definidas para Linha de Comando"))
("kill <4>" . ("maxima.info-1" 65439 2717 "Funções e Variáveis Definidas para Linha de Comando"))
("kill <5>" . ("maxima.info-1" 65464 2694 "Funções e Variáveis Definidas para Linha de Comando"))
("kill <6>" . ("maxima.info-1" 65496 2664 "Funções e Variáveis Definidas para Linha de Comando"))
("kill <7>" . ("maxima.info-1" 65548 2614 "Funções e Variáveis Definidas para Linha de Comando"))
("killcontext" . ("maxima.info-2" 17183 747 "Funções e Variáveis Definidas para Contextos"))
("kinvariant" . ("maxima.info-3" 205790 95 "Funções e Variáveis Definidas para ctensor"))
("kostka" . ("maxima.info-3" 289900 235 "Funções e Variáveis Definidas para Simetrias"))
("kron_delta" . ("maxima.info-4" 120320 4433 "Funções e Variáveis Definidas para Conjuntos"))
("kronecker_product" . ("maxima.info-5" 311103 102 "Funções e Variáveis Definidas para linearalgebra"))
("kt" . ("maxima.info-3" 206760 103 "Funções e Variáveis Definidas para ctensor"))
("kummer_m" . ("maxima.info-5" 4261 401 "Funções e Variáveis Definidas para contrib_ode"))
("kummer_u" . ("maxima.info-5" 4679 183 "Funções e Variáveis Definidas para contrib_ode"))
("kurtosis" . ("maxima.info-5" 38643 894 "Funções e Variáveis Definidas para estatística descritiva"))
("kurtosis <1>" . ("maxima.info-5" 38644 893 "Funções e Variáveis Definidas para estatística descritiva"))
("kurtosis_bernoulli" . ("maxima.info-5" 161675 701 "Funções e Variáveis Definidas para distribuições discretas"))
("kurtosis_beta" . ("maxima.info-5" 125909 201 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_binomial" . ("maxima.info-5" 153169 233 "Funções e Variáveis Definidas para distribuições discretas"))
("kurtosis_chi2" . ("maxima.info-5" 104138 767 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_continuous_uniform" . ("maxima.info-5" 129261 227 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_discrete_uniform" . ("maxima.info-5" 167858 248 "Funções e Variáveis Definidas para distribuições discretas"))
("kurtosis_exp" . ("maxima.info-5" 115257 684 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_f" . ("maxima.info-5" 108432 201 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_gamma" . ("maxima.info-5" 122274 203 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_geometric" . ("maxima.info-5" 164474 209 "Funções e Variáveis Definidas para distribuições discretas"))
("kurtosis_gumbel" . ("maxima.info-5" 149980 203 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_hypergeometric" . ("maxima.info-5" 170829 281 "Funções e Variáveis Definidas para distribuições discretas"))
("kurtosis_laplace" . ("maxima.info-5" 146005 205 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_logistic" . ("maxima.info-5" 131638 208 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_lognormal" . ("maxima.info-5" 119381 209 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_negative_binomial" . ("maxima.info-5" 174935 251 "Funções e Variáveis Definidas para distribuições discretas"))
("kurtosis_normal" . ("maxima.info-5" 93368 227 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_pareto" . ("maxima.info-5" 133901 207 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_poisson" . ("maxima.info-5" 156584 203 "Funções e Variáveis Definidas para distribuições discretas"))
("kurtosis_rayleigh" . ("maxima.info-5" 142951 1013 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_student_t" . ("maxima.info-5" 97005 206 "Funções e Variáveis Definidas para distribuições contínuas"))
("kurtosis_weibull" . ("maxima.info-5" 136164 207 "Funções e Variáveis Definidas para distribuições contínuas"))
("label_alignment" . ("maxima.info-5" 205306 905 "Funções e Variáveis Definidas para draw"))
("label_orientation" . ("maxima.info-5" 206227 956 "Funções e Variáveis Definidas para draw"))
("labels" . ("maxima.info-1" 68236 1845 "Funções e Variáveis Definidas para Linha de Comando"))
("labels <1>" . ("maxima.info-1" 68237 1844 "Funções e Variáveis Definidas para Linha de Comando"))
("lagrange" . ("maxima.info-5" 274821 2594 "Funções e Variáveis Definidas para interpol"))
("lagrange <1>" . ("maxima.info-5" 274822 2593 "Funções e Variáveis Definidas para interpol"))
("laguerre" . ("maxima.info-6" 43804 146 "Funções e Variáveis Definidas para polinômios ortogonais"))
("lambda" . ("maxima.info-4" 197160 6107 "Funções e Variáveis para Definição de Função"))
("lambda <1>" . ("maxima.info-4" 197216 6053 "Funções e Variáveis para Definição de Função"))
("lambda <2>" . ("maxima.info-4" 197291 5980 "Funções e Variáveis para Definição de Função"))
("laplace" . ("maxima.info-2" 150459 2488 "Funções e Variáveis Definidas para Diferenciação"))
("lassociative" . ("maxima.info-1" 233229 216 "Funções e Variáveis Definidas para Simplificação"))
("last" . ("maxima.info-4" 85036 99 "Funções e Variáveis Definidas para Listas"))
("lbfgs" . ("maxima.info-5" 285944 8751 "Funções e Variáveis Definidas para lbfgs"))
("lbfgs_ncorrections" . ("maxima.info-5" 295105 187 "Funções e Variáveis Definidas para lbfgs"))
("lbfgs_nfeval_max" . ("maxima.info-5" 294781 312 "Funções e Variáveis Definidas para lbfgs"))
("lc2kdt" . ("maxima.info-3" 91666 3316 "Funções e Variáveis Definidas para itensor"))
("lc_l" . ("maxima.info-3" 95013 1098 "Funções e Variáveis Definidas para itensor"))
("lc_u" . ("maxima.info-3" 96122 309 "Funções e Variáveis Definidas para itensor"))
("lcharp" . ("maxima.info-6" 160183 127 "Funções e Variáveis para caracteres"))
("lcm" . ("maxima.info-3" 263443 209 "Funções e Variáveis Definidas para Teoria dos Números"))
("ldefint" . ("maxima.info-2" 174290 734 "Funções e Variáveis Definidas para Integração"))
("ldisp" . ("maxima.info-1" 308604 1066 "Funções e Variáveis Definidas para Entrada e Saída"))
("ldisplay" . ("maxima.info-1" 309680 1280 "Funções e Variáveis Definidas para Entrada e Saída"))
("legendre_p" . ("maxima.info-6" 43958 164 "Funções e Variáveis Definidas para polinômios ortogonais"))
("legendre_q" . ("maxima.info-6" 44130 144 "Funções e Variáveis Definidas para polinômios ortogonais"))
("leinstein" . ("maxima.info-3" 160423 417 "Funções e Variáveis Definidas para ctensor"))
("length" . ("maxima.info-4" 85139 542 "Funções e Variáveis Definidas para Listas"))
("let" . ("maxima.info-4" 40571 4460 "Funções e Variáveis Definidas para Regras e Modelos"))
("let <1>" . ("maxima.info-4" 40572 4459 "Funções e Variáveis Definidas para Regras e Modelos"))
("let_rule_packages" . ("maxima.info-4" 47153 245 "Funções e Variáveis Definidas para Regras e Modelos"))
("letrat" . ("maxima.info-4" 45101 830 "Funções e Variáveis Definidas para Regras e Modelos"))
("letrules" . ("maxima.info-4" 45939 549 "Funções e Variáveis Definidas para Regras e Modelos"))
("letrules <1>" . ("maxima.info-4" 45940 548 "Funções e Variáveis Definidas para Regras e Modelos"))
("letsimp" . ("maxima.info-4" 46497 644 "Funções e Variáveis Definidas para Regras e Modelos"))
("letsimp <1>" . ("maxima.info-4" 46498 643 "Funções e Variáveis Definidas para Regras e Modelos"))
("letsimp <2>" . ("maxima.info-4" 46529 614 "Funções e Variáveis Definidas para Regras e Modelos"))
("levi_civita" . ("maxima.info-3" 91393 261 "Funções e Variáveis Definidas para itensor"))
("lfg" . ("maxima.info-3" 204274 199 "Funções e Variáveis Definidas para ctensor"))
("lfreeof" . ("maxima.info-1" 198990 205 "Funções e Variáveis Definidas para Expressões"))
("lg" . ("maxima.info-3" 205335 172 "Funções e Variáveis Definidas para ctensor"))
("lgtreillis" . ("maxima.info-3" 290141 241 "Funções e Variáveis Definidas para Simetrias"))
("lhospitallim" . ("maxima.info-2" 125407 232 "Funções e Variáveis Definidas para Limites"))
("lhs" . ("maxima.info-2" 218627 1608 "Funções e Variáveis Definidas para Equações"))
("li" . ("maxima.info-2" 80675 2580 "Funções e Variáveis Definidas para Logarítmos"))
("liediff" . ("maxima.info-3" 103134 804 "Funções e Variáveis Definidas para itensor"))
("limit" . ("maxima.info-2" 125648 1562 "Funções e Variáveis Definidas para Limites"))
("limit <1>" . ("maxima.info-2" 125649 1561 "Funções e Variáveis Definidas para Limites"))
("limit <2>" . ("maxima.info-2" 125697 1515 "Funções e Variáveis Definidas para Limites"))
("limsubst" . ("maxima.info-2" 127244 285 "Funções e Variáveis Definidas para Limites"))
("line_type" . ("maxima.info-5" 210347 698 "Funções e Variáveis Definidas para draw"))
("line_width" . ("maxima.info-5" 209637 698 "Funções e Variáveis Definidas para draw"))
("linear" . ("maxima.info-1" 233451 562 "Funções e Variáveis Definidas para Simplificação"))
("linear <1>" . ("maxima.info-6" 83681 306 "Funções e Variáveis Definidas para simplification"))
("linear_program" . ("maxima.info-6" 70146 1057 "Funções e Variáveis Definidas para simplex"))
("linear_solver" . ("maxima.info-6" 206480 188 "Funções e Variáveis Definidas para zeilberger"))
("linearinterpol" . ("maxima.info-5" 277617 2390 "Funções e Variáveis Definidas para interpol"))
("linearinterpol <1>" . ("maxima.info-5" 277618 2389 "Funções e Variáveis Definidas para interpol"))
("linechar" . ("maxima.info-1" 310980 507 "Funções e Variáveis Definidas para Entrada e Saída"))
("linel" . ("maxima.info-1" 311511 442 "Funções e Variáveis Definidas para Entrada e Saída"))
("linenum" . ("maxima.info-1" 70152 119 "Funções e Variáveis Definidas para Linha de Comando"))
("linsolve" . ("maxima.info-2" 220246 2993 "Funções e Variáveis Definidas para Equações"))
("linsolve_params" . ("maxima.info-2" 223458 367 "Funções e Variáveis Definidas para Equações"))
("linsolvewarn" . ("maxima.info-2" 223291 161 "Funções e Variáveis Definidas para Equações"))
("lispdisp" . ("maxima.info-1" 311969 499 "Funções e Variáveis Definidas para Entrada e Saída"))
("list_correlations" . ("maxima.info-5" 49480 3311 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("list_correlations <1>" . ("maxima.info-5" 49481 3310 "Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis"))
("list_nc_monomials" . ("maxima.info-3" 59514 292 "Funções e Variáveis Definidas para Funções Afins"))
("list_nc_monomials <1>" . ("maxima.info-3" 59515 291 "Funções e Variáveis Definidas para Funções Afins"))
("listarith" . ("maxima.info-4" 85699 378 "Funções e Variáveis Definidas para Listas"))
("listarray" . ("maxima.info-2" 282555 3837 "Funções e Variáveis Definidas para Arrays"))
("listconstvars" . ("maxima.info-1" 197465 333 "Funções e Variáveis Definidas para Expressões"))
("listdummyvars" . ("maxima.info-1" 197808 702 "Funções e Variáveis Definidas para Expressões"))
("listify" . ("maxima.info-4" 124806 453 "Funções e Variáveis Definidas para Conjuntos"))
("listoftens" . ("maxima.info-3" 74020 560 "Funções e Variáveis Definidas para itensor"))
("listofvars" . ("maxima.info-1" 198530 452 "Funções e Variáveis Definidas para Expressões"))
("listp" . ("maxima.info-4" 86091 108 "Funções e Variáveis Definidas para Listas"))
("listp <1>" . ("maxima.info-5" 311208 350 "Funções e Variáveis Definidas para linearalgebra"))
("listp <2>" . ("maxima.info-5" 311209 349 "Funções e Variáveis Definidas para linearalgebra"))
("lmax" . ("maxima.info-1" 122851 195 "Operadores Geral"))
("lmin" . ("maxima.info-1" 123052 198 "Operadores Geral"))
("lmxchar" . ("maxima.info-3" 28860 514 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("load" . ("maxima.info-1" 312481 1402 "Funções e Variáveis Definidas para Entrada e Saída"))
("loadfile" . ("maxima.info-1" 313909 463 "Funções e Variáveis Definidas para Entrada e Saída"))
("loadprint" . ("maxima.info-1" 314382 573 "Funções e Variáveis Definidas para Entrada e Saída"))
("local" . ("maxima.info-4" 203423 440 "Funções e Variáveis para Definição de Função"))
("locate_matrix_entry" . ("maxima.info-5" 311564 1065 "Funções e Variáveis Definidas para linearalgebra"))
("log" . ("maxima.info-2" 83278 1692 "Funções e Variáveis Definidas para Logarítmos"))
("logabs" . ("maxima.info-2" 85018 444 "Funções e Variáveis Definidas para Logarítmos"))
("logarc" . ("maxima.info-2" 85478 409 "Funções e Variáveis Definidas para Logarítmos"))
("logarc <1>" . ("maxima.info-2" 85479 408 "Funções e Variáveis Definidas para Logarítmos"))
("logconcoeffp" . ("maxima.info-2" 85912 444 "Funções e Variáveis Definidas para Logarítmos"))
("logcontract" . ("maxima.info-2" 86370 983 "Funções e Variáveis Definidas para Logarítmos"))
("logexpand" . ("maxima.info-2" 87373 489 "Funções e Variáveis Definidas para Logarítmos"))
("lognegint" . ("maxima.info-2" 87876 159 "Funções e Variáveis Definidas para Logarítmos"))
("lognumer" . ("maxima.info-2" 88040 374 "Funções e Variáveis Definidas para Logarítmos"))
("logsimp" . ("maxima.info-2" 88425 162 "Funções e Variáveis Definidas para Logarítmos"))
("logx" . ("maxima.info-5" 179443 406 "Funções e Variáveis Definidas para draw"))
("logy" . ("maxima.info-5" 179867 403 "Funções e Variáveis Definidas para draw"))
("logz" . ("maxima.info-5" 180288 417 "Funções e Variáveis Definidas para draw"))
("lopow" . ("maxima.info-1" 199198 223 "Funções e Variáveis Definidas para Expressões"))
("lorentz_gauge" . ("maxima.info-3" 116923 217 "Funções e Variáveis Definidas para itensor"))
("lowercasep" . ("maxima.info-6" 160317 105 "Funções e Variáveis para caracteres"))
("lpart" . ("maxima.info-1" 199424 238 "Funções e Variáveis Definidas para Expressões"))
("lratsubst" . ("maxima.info-2" 45063 1025 "Funções e Variáveis Definidas para Polinômios"))
("lreduce" . ("maxima.info-4" 125262 1425 "Funções e Variáveis Definidas para Conjuntos"))
("lreduce <1>" . ("maxima.info-4" 125263 1424 "Funções e Variáveis Definidas para Conjuntos"))
("lriem" . ("maxima.info-3" 204959 92 "Funções e Variáveis Definidas para ctensor"))
("lriemann" . ("maxima.info-3" 162129 508 "Funções e Variáveis Definidas para ctensor"))
("lsquares" . ("maxima.info-6" 947 4283 "Funções e Variáveis Definidas para lsquares"))
("lsquares <1>" . ("maxima.info-6" 948 4282 "Funções e Variáveis Definidas para lsquares"))
("lstringp" . ("maxima.info-6" 161163 151 "Funções e Variáveis para seqüências de caracteres"))
("lsum" . ("maxima.info-1" 223872 692 "Funções e Variáveis Definidas para Expressões"))
("ltreillis" . ("maxima.info-3" 290388 270 "Funções e Variáveis Definidas para Simetrias"))
("lu_backsub" . ("maxima.info-5" 312644 158 "Funções e Variáveis Definidas para linearalgebra"))
("lu_factor" . ("maxima.info-5" 312806 5617 "Funções e Variáveis Definidas para linearalgebra"))
("m1pbranch" . ("maxima.info-4" 20075 594 "Funções e Variáveis Definidas para Opções Diversas"))
("macroexpand" . ("maxima.info-4" 166294 1304 "Macros"))
("macroexpand1" . ("maxima.info-4" 167620 1184 "Macros"))
("macroexpansion" . ("maxima.info-4" 203925 6021 "Funções e Variáveis para Definição de Função"))
("macros" . ("maxima.info-4" 168824 334 "Macros"))
("mainvar" . ("maxima.info-1" 234027 765 "Funções e Variáveis Definidas para Simplificação"))
("makeOrders" . ("maxima.info-6" 10049 838 "Funções e Variáveis Definidas para makeOrders"))
("make_array" . ("maxima.info-2" 286439 2016 "Funções e Variáveis Definidas para Arrays"))
("make_random_state" . ("maxima.info-1" 126233 813 "Operadores Geral"))
("make_random_state <1>" . ("maxima.info-1" 126234 812 "Operadores Geral"))
("make_random_state <2>" . ("maxima.info-1" 126272 776 "Operadores Geral"))
("make_random_state <3>" . ("maxima.info-1" 126310 740 "Operadores Geral"))
("make_transform" . ("maxima.info-1" 272237 301 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("makebox" . ("maxima.info-3" 108807 259 "Funções e Variáveis Definidas para itensor"))
("makefact" . ("maxima.info-2" 108529 154 "Funções e Variáveis Definidas para Funções Especiais"))
("makegamma" . ("maxima.info-2" 108690 161 "Funções e Variáveis Definidas para Funções Especiais"))
("makelist" . ("maxima.info-4" 86202 744 "Funções e Variáveis Definidas para Listas"))
("makelist <1>" . ("maxima.info-4" 86203 743 "Funções e Variáveis Definidas para Listas"))
("makeset" . ("maxima.info-4" 126711 1642 "Funções e Variáveis Definidas para Conjuntos"))
("map" . ("maxima.info-4" 243653 1789 "Funções e Variáveis Definidas para Fluxo de Programa"))
("mapatom" . ("maxima.info-4" 245479 225 "Funções e Variáveis Definidas para Fluxo de Programa"))
("maperror" . ("maxima.info-4" 245714 533 "Funções e Variáveis Definidas para Fluxo de Programa"))
("maplist" . ("maxima.info-4" 246260 435 "Funções e Variáveis Definidas para Fluxo de Programa"))
("mat_cond" . ("maxima.info-5" 318526 528 "Funções e Variáveis Definidas para linearalgebra"))
("mat_cond <1>" . ("maxima.info-5" 318527 527 "Funções e Variáveis Definidas para linearalgebra"))
("mat_fullunblocker" . ("maxima.info-5" 319947 219 "Funções e Variáveis Definidas para linearalgebra"))
("mat_function" . ("maxima.info-5" 72300 10169 "Funções e Variáveis Definidas para diag"))
("mat_norm" . ("maxima.info-5" 319073 303 "Funções e Variáveis Definidas para linearalgebra"))
("mat_norm <1>" . ("maxima.info-5" 319074 302 "Funções e Variáveis Definidas para linearalgebra"))
("mat_norm <2>" . ("maxima.info-5" 319106 272 "Funções e Variáveis Definidas para linearalgebra"))
("mat_trace" . ("maxima.info-5" 320170 258 "Funções e Variáveis Definidas para linearalgebra"))
("mat_unblocker" . ("maxima.info-5" 320433 1470 "Funções e Variáveis Definidas para linearalgebra"))
("matchdeclare" . ("maxima.info-4" 47406 8457 "Funções e Variáveis Definidas para Regras e Modelos"))
("matchfix" . ("maxima.info-4" 56044 4988 "Funções e Variáveis Definidas para Regras e Modelos"))
("matchfix <1>" . ("maxima.info-4" 56045 4987 "Funções e Variáveis Definidas para Regras e Modelos"))
("matrix" . ("maxima.info-3" 29381 6024 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("matrix_element_add" . ("maxima.info-3" 35761 1314 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("matrix_element_mult" . ("maxima.info-3" 37098 1982 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("matrix_element_transpose" . ("maxima.info-3" 39101 2196 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("matrix_size" . ("maxima.info-5" 319791 152 "Funções e Variáveis Definidas para linearalgebra"))
("matrixmap" . ("maxima.info-3" 35483 160 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("matrixp" . ("maxima.info-3" 35647 110 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("matrixp <1>" . ("maxima.info-5" 319385 399 "Funções e Variáveis Definidas para linearalgebra"))
("matrixp <2>" . ("maxima.info-5" 319386 398 "Funções e Variáveis Definidas para linearalgebra"))
("mattrace" . ("maxima.info-3" 41331 269 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("max" . ("maxima.info-1" 123256 505 "Operadores Geral"))
("maxapplydepth" . ("maxima.info-1" 234817 158 "Funções e Variáveis Definidas para Simplificação"))
("maxapplyheight" . ("maxima.info-1" 234985 161 "Funções e Variáveis Definidas para Simplificação"))
("maxi" . ("maxima.info-5" 31305 490 "Funções e Variáveis Definidas para estatística descritiva"))
("maxi <1>" . ("maxima.info-5" 31306 489 "Funções e Variáveis Definidas para estatística descritiva"))
("maxima_tempdir" . ("maxima.info-4" 6407 495 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("maxima_userdir" . ("maxima.info-4" 6919 787 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("maximize_sx" . ("maxima.info-6" 71224 268 "Funções e Variáveis Definidas para simplex"))
("maxnegex" . ("maxima.info-1" 235157 173 "Funções e Variáveis Definidas para Simplificação"))
("maxposex" . ("maxima.info-1" 235338 165 "Funções e Variáveis Definidas para Simplificação"))
("maxpsifracdenom" . ("maxima.info-2" 114632 266 "Funções e Variáveis Definidas para Funções Especiais"))
("maxpsifracnum" . ("maxima.info-2" 114361 262 "Funções e Variáveis Definidas para Funções Especiais"))
("maxpsinegint" . ("maxima.info-2" 114046 304 "Funções e Variáveis Definidas para Funções Especiais"))
("maxpsiposint" . ("maxima.info-2" 113870 169 "Funções e Variáveis Definidas para Funções Especiais"))
("maxtayorder" . ("maxima.info-3" 225123 251 "Funções e Variáveis Definidas para Séries"))
("maybe" . ("maxima.info-1" 121976 750 "Operadores Geral"))
("mean" . ("maxima.info-5" 24411 913 "Funções e Variáveis Definidas para estatística descritiva"))
("mean <1>" . ("maxima.info-5" 24412 912 "Funções e Variáveis Definidas para estatística descritiva"))
("mean_bernoulli" . ("maxima.info-5" 159247 537 "Funções e Variáveis Definidas para distribuições discretas"))
("mean_beta" . ("maxima.info-5" 125136 174 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_binomial" . ("maxima.info-5" 152256 212 "Funções e Variáveis Definidas para distribuições discretas"))
("mean_chi2" . ("maxima.info-5" 101377 628 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_continuous_uniform" . ("maxima.info-5" 128372 206 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_deviation" . ("maxima.info-5" 34849 975 "Funções e Variáveis Definidas para estatística descritiva"))
("mean_deviation <1>" . ("maxima.info-5" 34850 974 "Funções e Variáveis Definidas para estatística descritiva"))
("mean_discrete_uniform" . ("maxima.info-5" 166885 227 "Funções e Variáveis Definidas para distribuições discretas"))
("mean_exp" . ("maxima.info-5" 112295 714 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_f" . ("maxima.info-5" 107653 174 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_gamma" . ("maxima.info-5" 121487 176 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_geometric" . ("maxima.info-5" 163679 178 "Funções e Variáveis Definidas para distribuições discretas"))
("mean_gumbel" . ("maxima.info-5" 148681 335 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_hypergeometric" . ("maxima.info-5" 169707 267 "Funções e Variáveis Definidas para distribuições discretas"))
("mean_laplace" . ("maxima.info-5" 145210 178 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_lognormal" . ("maxima.info-5" 118570 182 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_negative_binomial" . ("maxima.info-5" 173950 230 "Funções e Variáveis Definidas para distribuições discretas"))
("mean_normal" . ("maxima.info-5" 92510 195 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_pareto" . ("maxima.info-5" 133098 180 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_poisson" . ("maxima.info-5" 155819 172 "Funções e Variáveis Definidas para distribuições discretas"))
("mean_rayleigh" . ("maxima.info-5" 139407 731 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_student_t" . ("maxima.info-5" 96009 209 "Funções e Variáveis Definidas para distribuições contínuas"))
("mean_weibull" . ("maxima.info-5" 135361 180 "Funções e Variáveis Definidas para distribuições contínuas"))
("meanlog" . ("maxima.info-5" 130837 175 "Funções e Variáveis Definidas para distribuições contínuas"))
("median" . ("maxima.info-5" 33277 778 "Funções e Variáveis Definidas para estatística descritiva"))
("median <1>" . ("maxima.info-5" 33278 777 "Funções e Variáveis Definidas para estatística descritiva"))
("median_deviation" . ("maxima.info-5" 35833 900 "Funções e Variáveis Definidas para estatística descritiva"))
("median_deviation <1>" . ("maxima.info-5" 35834 899 "Funções e Variáveis Definidas para estatística descritiva"))
("member" . ("maxima.info-4" 86959 1364 "Funções e Variáveis Definidas para Listas"))
("metricexpandall" . ("maxima.info-6" 198508 1045 "Funções e Variáveis Definidas para Units"))
("min" . ("maxima.info-1" 123769 505 "Operadores Geral"))
("minf" . ("maxima.info-2" 76999 83 "Funções e Variáveis Definidas para Constantes"))
("minfactorial" . ("maxima.info-3" 263660 548 "Funções e Variáveis Definidas para Teoria dos Números"))
("mini" . ("maxima.info-5" 30810 485 "Funções e Variáveis Definidas para estatística descritiva"))
("mini <1>" . ("maxima.info-5" 30811 484 "Funções e Variáveis Definidas para estatística descritiva"))
("minimalPoly" . ("maxima.info-5" 70159 674 "Funções e Variáveis Definidas para diag"))
("minimize_sx" . ("maxima.info-6" 71502 1961 "Funções e Variáveis Definidas para simplex"))
("minor" . ("maxima.info-3" 41608 191 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("mnewton" . ("maxima.info-6" 11722 1087 "Funções e Variáveis Definidas para mnewton"))
("mod" . ("maxima.info-1" 124623 1254 "Operadores Geral"))
("mod_big_prime" . ("maxima.info-6" 207996 144 "Funções e Variáveis Definidas para zeilberger"))
("mod_test" . ("maxima.info-6" 207447 169 "Funções e Variáveis Definidas para zeilberger"))
("mod_threshold" . ("maxima.info-6" 208145 158 "Funções e Variáveis Definidas para zeilberger"))
("mode_check_errorp" . ("maxima.info-4" 210263 113 "Funções e Variáveis para Definição de Função"))
("mode_check_warnp" . ("maxima.info-4" 210425 96 "Funções e Variáveis para Definição de Função"))
("mode_checkp" . ("maxima.info-4" 210084 128 "Funções e Variáveis para Definição de Função"))
("mode_declare" . ("maxima.info-4" 210593 1814 "Funções e Variáveis para Definição de Função"))
("mode_identity" . ("maxima.info-4" 212511 1330 "Funções e Variáveis para Definição de Função"))
("modular_linear_solver" . ("maxima.info-6" 207621 176 "Funções e Variáveis Definidas para zeilberger"))
("modulus" . ("maxima.info-2" 46113 1189 "Funções e Variáveis Definidas para Polinômios"))
("moebius" . ("maxima.info-4" 128366 1230 "Funções e Variáveis Definidas para Conjuntos"))
("mon2schur" . ("maxima.info-3" 272313 1121 "Funções e Variáveis Definidas para Simetrias"))
("mono" . ("maxima.info-3" 58656 243 "Funções e Variáveis Definidas para Funções Afins"))
("monomial_dimensions" . ("maxima.info-3" 58909 186 "Funções e Variáveis Definidas para Funções Afins"))
("multi_elem" . ("maxima.info-3" 273454 698 "Funções e Variáveis Definidas para Simetrias"))
("multi_orbit" . ("maxima.info-3" 285596 643 "Funções e Variáveis Definidas para Simetrias"))
("multi_pui" . ("maxima.info-3" 274166 420 "Funções e Variáveis Definidas para Simetrias"))
("multinomial" . ("maxima.info-3" 305844 259 "Funções e Variáveis Definidas para Simetrias"))
("multinomial_coeff" . ("maxima.info-4" 129603 1279 "Funções e Variáveis Definidas para Conjuntos"))
("multinomial_coeff <1>" . ("maxima.info-4" 129604 1278 "Funções e Variáveis Definidas para Conjuntos"))
("multiplicative" . ("maxima.info-1" 235511 714 "Funções e Variáveis Definidas para Simplificação"))
("multiplicities" . ("maxima.info-2" 223836 200 "Funções e Variáveis Definidas para Equações"))
("multsym" . ("maxima.info-3" 286257 781 "Funções e Variáveis Definidas para Simetrias"))
("multthru" . ("maxima.info-1" 199670 2330 "Funções e Variáveis Definidas para Expressões"))
("multthru <1>" . ("maxima.info-1" 199671 2329 "Funções e Variáveis Definidas para Expressões"))
("myoptions" . ("maxima.info-1" 70276 215 "Funções e Variáveis Definidas para Linha de Comando"))
("nc_degree" . ("maxima.info-3" 57040 180 "Funções e Variáveis Definidas para Funções Afins"))
("ncexpt" . ("maxima.info-3" 41803 293 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("ncharpoly" . ("maxima.info-3" 42110 796 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("negdistrib" . ("maxima.info-1" 236242 539 "Funções e Variáveis Definidas para Simplificação"))
("negsumdispflag" . ("maxima.info-1" 236795 434 "Funções e Variáveis Definidas para Simplificação"))
("newcontext" . ("maxima.info-2" 17946 285 "Funções e Variáveis Definidas para Contextos"))
("newdet" . ("maxima.info-3" 42931 215 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("newline" . ("maxima.info-6" 160425 54 "Funções e Variáveis para caracteres"))
("newline <1>" . ("maxima.info-6" 152279 237 "Funções e Variáveis para entrada e saída"))
("newline <2>" . ("maxima.info-6" 152280 236 "Funções e Variáveis para entrada e saída"))
("newton" . ("maxima.info-2" 265864 1338 "Funções e Variáveis Definidas para Numérico"))
("newtonepsilon" . ("maxima.info-6" 11267 198 "Funções e Variáveis Definidas para mnewton"))
("newtonmaxiter" . ("maxima.info-6" 11479 228 "Funções e Variáveis Definidas para mnewton"))
("next_prime" . ("maxima.info-3" 264214 145 "Funções e Variáveis Definidas para Teoria dos Números"))
("nextlayerfactor" . ("maxima.info-6" 79241 780 "Funções e Variáveis Definidas para simplification"))
("niceindices" . ("maxima.info-3" 225383 1469 "Funções e Variáveis Definidas para Séries"))
("niceindicespref" . ("maxima.info-3" 226870 1089 "Funções e Variáveis Definidas para Séries"))
("ninth" . ("maxima.info-4" 88331 124 "Funções e Variáveis Definidas para Listas"))
("nm" . ("maxima.info-3" 206867 103 "Funções e Variáveis Definidas para ctensor"))
("nmc" . ("maxima.info-3" 206974 113 "Funções e Variáveis Definidas para ctensor"))
("noeval" . ("maxima.info-1" 237246 216 "Funções e Variáveis Definidas para Simplificação"))
("nolabels" . ("maxima.info-1" 70502 610 "Funções e Variáveis Definidas para Linha de Comando"))
("noncentral_moment" . ("maxima.info-5" 28181 969 "Funções e Variáveis Definidas para estatística descritiva"))
("noncentral_moment <1>" . ("maxima.info-5" 28182 968 "Funções e Variáveis Definidas para estatística descritiva"))
("nonegative_sx" . ("maxima.info-6" 73513 258 "Funções e Variáveis Definidas para simplex"))
("nonmetricity" . ("maxima.info-3" 178606 147 "Funções e Variáveis Definidas para ctensor"))
("nonnegintegerp" . ("maxima.info-5" 321912 103 "Funções e Variáveis Definidas para linearalgebra"))
("nonscalar" . ("maxima.info-3" 43153 135 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("nonscalarp" . ("maxima.info-3" 43294 162 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("nonzeroandfreeof" . ("maxima.info-6" 83436 240 "Funções e Variáveis Definidas para simplification"))
("not" . ("maxima.info-1" 104296 587 "Operadores Geral"))
("notequal" . ("maxima.info-1" 117746 931 "Operadores Geral"))
("noun" . ("maxima.info-1" 237471 218 "Funções e Variáveis Definidas para Simplificação"))
("noundisp" . ("maxima.info-1" 237700 229 "Funções e Variáveis Definidas para Simplificação"))
("nounify" . ("maxima.info-1" 202033 437 "Funções e Variáveis Definidas para Expressões"))
("nouns" . ("maxima.info-1" 237941 364 "Funções e Variáveis Definidas para Simplificação"))
("np" . ("maxima.info-3" 205888 91 "Funções e Variáveis Definidas para ctensor"))
("npi" . ("maxima.info-3" 205982 650 "Funções e Variáveis Definidas para ctensor"))
("nptetrad" . ("maxima.info-3" 170587 716 "Funções e Variáveis Definidas para ctensor"))
("nroots" . ("maxima.info-2" 224042 440 "Funções e Variáveis Definidas para Equações"))
("nterms" . ("maxima.info-1" 202489 369 "Funções e Variáveis Definidas para Expressões"))
("ntermst" . ("maxima.info-3" 185846 392 "Funções e Variáveis Definidas para ctensor"))
("nthroot" . ("maxima.info-2" 224493 329 "Funções e Variáveis Definidas para Equações"))
("nticks" . ("maxima.info-5" 211057 516 "Funções e Variáveis Definidas para draw"))
("ntrig" . ("maxima.info-2" 91970 280 "Funções e Variáveis Definidas para Trigonometria"))
("nullity" . ("maxima.info-5" 322368 97 "Funções e Variáveis Definidas para linearalgebra"))
("nullspace" . ("maxima.info-5" 322018 342 "Funções e Variáveis Definidas para linearalgebra"))
("num" . ("maxima.info-2" 47336 172 "Funções e Variáveis Definidas para Polinômios"))
("num_distinct_partitions" . ("maxima.info-4" 130891 859 "Funções e Variáveis Definidas para Conjuntos"))
("num_distinct_partitions <1>" . ("maxima.info-4" 130892 858 "Funções e Variáveis Definidas para Conjuntos"))
("num_partitions" . ("maxima.info-4" 131765 930 "Funções e Variáveis Definidas para Conjuntos"))
("num_partitions <1>" . ("maxima.info-4" 131766 929 "Funções e Variáveis Definidas para Conjuntos"))
("numberp" . ("maxima.info-4" 20679 1327 "Funções e Variáveis Definidas para Opções Diversas"))
("numer" . ("maxima.info-1" 238316 395 "Funções e Variáveis Definidas para Simplificação"))
("numerval" . ("maxima.info-1" 238724 467 "Funções e Variáveis Definidas para Simplificação"))
("numfactor" . ("maxima.info-2" 108860 556 "Funções e Variáveis Definidas para Funções Especiais"))
("nusum" . ("maxima.info-3" 227971 2213 "Funções e Variáveis Definidas para Séries"))
("obase" . ("maxima.info-1" 314969 489 "Funções e Variáveis Definidas para Entrada e Saída"))
("oddp" . ("maxima.info-1" 125910 124 "Operadores Geral"))
("ode2" . ("maxima.info-2" 247189 4129 "Funções e Variáveis Definidas para Equações Diferenciais"))
("ode_check" . ("maxima.info-5" 1846 1138 "Funções e Variáveis Definidas para contrib_ode"))
("odelin" . ("maxima.info-5" 523 1310 "Funções e Variáveis Definidas para contrib_ode"))
("op" . ("maxima.info-1" 202867 1763 "Funções e Variáveis Definidas para Expressões"))
("opena" . ("maxima.info-6" 152522 182 "Funções e Variáveis para entrada e saída"))
("openr" . ("maxima.info-6" 152709 117 "Funções e Variáveis para entrada e saída"))
("openw" . ("maxima.info-6" 152831 213 "Funções e Variáveis para entrada e saída"))
("operatorp" . ("maxima.info-1" 204656 330 "Funções e Variáveis Definidas para Expressões"))
("operatorp <1>" . ("maxima.info-1" 204657 329 "Funções e Variáveis Definidas para Expressões"))
("opproperties" . ("maxima.info-1" 239206 349 "Funções e Variáveis Definidas para Simplificação"))
("opsubst" . ("maxima.info-1" 239558 237 "Funções e Variáveis Definidas para Simplificação"))
("opsubst <1>" . ("maxima.info-6" 20208 2296 "Funções e Variáveis Definidas para opsubst"))
("opsubst <2>" . ("maxima.info-6" 20209 2295 "Funções e Variáveis Definidas para opsubst"))
("opsubst <3>" . ("maxima.info-6" 20245 2261 "Funções e Variáveis Definidas para opsubst"))
("optimize" . ("maxima.info-1" 204991 388 "Funções e Variáveis Definidas para Expressões"))
("optimprefix" . ("maxima.info-1" 205390 148 "Funções e Variáveis Definidas para Expressões"))
("optionset" . ("maxima.info-1" 71136 363 "Funções e Variáveis Definidas para Linha de Comando"))
("or" . ("maxima.info-1" 103217 1051 "Operadores Geral"))
("orbit" . ("maxima.info-3" 287059 527 "Funções e Variáveis Definidas para Simetrias"))
("ordergreat" . ("maxima.info-1" 205545 248 "Funções e Variáveis Definidas para Expressões"))
("ordergreatp" . ("maxima.info-1" 205800 149 "Funções e Variáveis Definidas para Expressões"))
("orderless" . ("maxima.info-1" 205956 686 "Funções e Variáveis Definidas para Expressões"))
("orderlessp" . ("maxima.info-1" 206660 147 "Funções e Variáveis Definidas para Expressões"))
("orthogonal_complement" . ("maxima.info-5" 322470 287 "Funções e Variáveis Definidas para linearalgebra"))
("orthopoly_recur" . ("maxima.info-6" 44281 1207 "Funções e Variáveis Definidas para polinômios ortogonais"))
("orthopoly_returns_intervals" . ("maxima.info-6" 45509 367 "Funções e Variáveis Definidas para polinômios ortogonais"))
("orthopoly_weight" . ("maxima.info-6" 45883 778 "Funções e Variáveis Definidas para polinômios ortogonais"))
("outative" . ("maxima.info-1" 239803 910 "Funções e Variáveis Definidas para Simplificação"))
("outchar" . ("maxima.info-1" 315473 681 "Funções e Variáveis Definidas para Entrada e Saída"))
("outermap" . ("maxima.info-4" 249269 6853 "Funções e Variáveis Definidas para Fluxo de Programa"))
("outofpois" . ("maxima.info-2" 109424 374 "Funções e Variáveis Definidas para Funções Especiais"))
("packagefile" . ("maxima.info-1" 316174 785 "Funções e Variáveis Definidas para Entrada e Saída"))
("pade" . ("maxima.info-3" 230215 3135 "Funções e Variáveis Definidas para Séries"))
("palette" . ("maxima.info-5" 194104 1934 "Funções e Variáveis Definidas para draw"))
("parGosper" . ("maxima.info-6" 204993 343 "Funções e Variáveis Definidas para zeilberger"))
("parse_string" . ("maxima.info-5" 250447 807 "Funções e Variáveis Definidas para eval_string"))
("parsetoken" . ("maxima.info-6" 161972 612 "Funções e Variáveis para seqüências de caracteres"))
("part" . ("maxima.info-1" 206812 1198 "Funções e Variáveis Definidas para Expressões"))
("part2cont" . ("maxima.info-3" 280634 343 "Funções e Variáveis Definidas para Simetrias"))
("partfrac" . ("maxima.info-3" 264362 1216 "Funções e Variáveis Definidas para Teoria dos Números"))
("partition" . ("maxima.info-1" 208049 593 "Funções e Variáveis Definidas para Expressões"))
("partition_set" . ("maxima.info-4" 132716 756 "Funções e Variáveis Definidas para Conjuntos"))
("partpol" . ("maxima.info-3" 280986 272 "Funções e Variáveis Definidas para Simetrias"))
("partswitch" . ("maxima.info-1" 208651 235 "Funções e Variáveis Definidas para Expressões"))
("pdf_bernoulli" . ("maxima.info-5" 158047 605 "Funções e Variáveis Definidas para distribuições discretas"))
("pdf_beta" . ("maxima.info-5" 123920 227 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_binomial" . ("maxima.info-5" 150924 254 "Funções e Variáveis Definidas para distribuições discretas"))
("pdf_cauchy" . ("maxima.info-5" 146641 229 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_chi2" . ("maxima.info-5" 98785 966 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_continuous_uniform" . ("maxima.info-5" 127473 253 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_discrete_uniform" . ("maxima.info-5" 165940 258 "Funções e Variáveis Definidas para distribuições discretas"))
("pdf_exp" . ("maxima.info-5" 109959 758 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_f" . ("maxima.info-5" 106051 224 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_gamma" . ("maxima.info-5" 120355 229 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_geometric" . ("maxima.info-5" 162871 221 "Funções e Variáveis Definidas para distribuições discretas"))
("pdf_gumbel" . ("maxima.info-5" 147871 229 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_hypergeometric" . ("maxima.info-5" 168657 297 "Funções e Variáveis Definidas para distribuições discretas"))
("pdf_laplace" . ("maxima.info-5" 144394 231 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_logistic" . ("maxima.info-5" 130012 234 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_lognormal" . ("maxima.info-5" 117356 235 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_negative_binomial" . ("maxima.info-5" 172521 272 "Funções e Variáveis Definidas para distribuições discretas"))
("pdf_normal" . ("maxima.info-5" 91348 229 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_pareto" . ("maxima.info-5" 132281 231 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_poisson" . ("maxima.info-5" 154726 215 "Funções e Variáveis Definidas para distribuições discretas"))
("pdf_rank_sum" . ("maxima.info-6" 142399 260 "Funções e Variáveis Definidas para distribuições especiais"))
("pdf_rayleigh" . ("maxima.info-5" 136804 825 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_signed_rank" . ("maxima.info-6" 141892 244 "Funções e Variáveis Definidas para distribuições especiais"))
("pdf_student_t" . ("maxima.info-5" 94756 232 "Funções e Variáveis Definidas para distribuições contínuas"))
("pdf_weibull" . ("maxima.info-5" 134539 233 "Funções e Variáveis Definidas para distribuições contínuas"))
("pearson_skewness" . ("maxima.info-5" 40463 846 "Funções e Variáveis Definidas para estatística descritiva"))
("pearson_skewness <1>" . ("maxima.info-5" 40464 845 "Funções e Variáveis Definidas para estatística descritiva"))
("permanent" . ("maxima.info-3" 43464 143 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("permut" . ("maxima.info-3" 306112 77 "Funções e Variáveis Definidas para Simetrias"))
("permutation" . ("maxima.info-6" 86806 203 "Funções e Variáveis Definidas para simplification"))
("permutations" . ("maxima.info-4" 133480 620 "Funções e Variáveis Definidas para Conjuntos"))
("petrov" . ("maxima.info-3" 172784 3973 "Funções e Variáveis Definidas para ctensor"))
("pfeformat" . ("maxima.info-1" 316986 811 "Funções e Variáveis Definidas para Entrada e Saída"))
("phi" . ("maxima.info-2" 77084 2414 "Funções e Variáveis Definidas para Constantes"))
("pi" . ("maxima.info-2" 79518 201 "Funções e Variáveis Definidas para Constantes"))
("pic_height" . ("maxima.info-5" 189749 583 "Funções e Variáveis Definidas para draw"))
("pic_width" . ("maxima.info-5" 189145 584 "Funções e Variáveis Definidas para draw"))
("pickapart" . ("maxima.info-1" 208895 2976 "Funções e Variáveis Definidas para Expressões"))
("piece" . ("maxima.info-1" 211888 212 "Funções e Variáveis Definidas para Expressões"))
("playback" . ("maxima.info-1" 71518 2091 "Funções e Variáveis Definidas para Linha de Comando"))
("playback <1>" . ("maxima.info-1" 71519 2090 "Funções e Variáveis Definidas para Linha de Comando"))
("playback <2>" . ("maxima.info-1" 71545 2066 "Funções e Variáveis Definidas para Linha de Comando"))
("playback <3>" . ("maxima.info-1" 71574 2039 "Funções e Variáveis Definidas para Linha de Comando"))
("playback <4>" . ("maxima.info-1" 71610 2005 "Funções e Variáveis Definidas para Linha de Comando"))
("playback <5>" . ("maxima.info-1" 71641 1976 "Funções e Variáveis Definidas para Linha de Comando"))
("playback <6>" . ("maxima.info-1" 71672 1947 "Funções e Variáveis Definidas para Linha de Comando"))
("playback <7>" . ("maxima.info-1" 71702 1919 "Funções e Variáveis Definidas para Linha de Comando"))
("plog" . ("maxima.info-2" 88597 145 "Funções e Variáveis Definidas para Logarítmos"))
("plot2d" . ("maxima.info-1" 248414 6969 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot2d <1>" . ("maxima.info-1" 248415 6968 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot2d <2>" . ("maxima.info-1" 248478 6909 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot3d" . ("maxima.info-1" 270429 1768 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot3d <1>" . ("maxima.info-1" 270495 1704 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot3d <2>" . ("maxima.info-1" 270538 1663 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot3d <3>" . ("maxima.info-1" 270612 1593 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot3d <4>" . ("maxima.info-1" 270686 1523 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plot_options" . ("maxima.info-1" 255558 14511 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("plotdf" . ("maxima.info-6" 51810 9638 "Funções e Variáveis Definidas para plotdf"))
("plotdf <1>" . ("maxima.info-6" 51811 9637 "Funções e Variáveis Definidas para plotdf"))
("plsquares" . ("maxima.info-6" 5310 4287 "Funções e Variáveis Definidas para lsquares"))
("plsquares <1>" . ("maxima.info-6" 5311 4286 "Funções e Variáveis Definidas para lsquares"))
("plsquares <2>" . ("maxima.info-6" 5363 4236 "Funções e Variáveis Definidas para lsquares"))
("pochhammer" . ("maxima.info-6" 46672 1313 "Funções e Variáveis Definidas para polinômios ortogonais"))
("pochhammer_max_index" . ("maxima.info-6" 47998 510 "Funções e Variáveis Definidas para polinômios ortogonais"))
("point_size" . ("maxima.info-5" 197157 512 "Funções e Variáveis Definidas para draw"))
("point_type" . ("maxima.info-5" 197680 1661 "Funções e Variáveis Definidas para draw"))
("points_joined" . ("maxima.info-5" 199353 920 "Funções e Variáveis Definidas para draw"))
("poisdiff" . ("maxima.info-2" 109814 157 "Funções e Variáveis Definidas para Funções Especiais"))
("poisexpt" . ("maxima.info-2" 109977 125 "Funções e Variáveis Definidas para Funções Especiais"))
("poisint" . ("maxima.info-2" 110105 197 "Funções e Variáveis Definidas para Funções Especiais"))
("poislim" . ("maxima.info-2" 110310 300 "Funções e Variáveis Definidas para Funções Especiais"))
("poismap" . ("maxima.info-2" 110619 326 "Funções e Variáveis Definidas para Funções Especiais"))
("poisplus" . ("maxima.info-2" 110958 85 "Funções e Variáveis Definidas para Funções Especiais"))
("poissimp" . ("maxima.info-2" 111047 99 "Funções e Variáveis Definidas para Funções Especiais"))
("poisson" . ("maxima.info-2" 111152 125 "Funções e Variáveis Definidas para Funções Especiais"))
("poissubst" . ("maxima.info-2" 111283 901 "Funções e Variáveis Definidas para Funções Especiais"))
("poistimes" . ("maxima.info-2" 112212 88 "Funções e Variáveis Definidas para Funções Especiais"))
("poistrim" . ("maxima.info-2" 112305 412 "Funções e Variáveis Definidas para Funções Especiais"))
("polarform" . ("maxima.info-1" 212114 148 "Funções e Variáveis Definidas para Expressões"))
("polartorect" . ("maxima.info-2" 252889 726 "Funções e Variáveis Definidas para Numérico"))
("polartorect <1>" . ("maxima.info-2" 255011 2258 "Funções e Variáveis Definidas para Numérico"))
("poly_add" . ("maxima.info-5" 260778 250 "Funções e Variáveis Definidas para grobner"))
("poly_buchberger" . ("maxima.info-5" 265706 187 "Funções e Variáveis Definidas para grobner"))
("poly_buchberger_criterion" . ("maxima.info-5" 265389 314 "Funções e Variáveis Definidas para grobner"))
("poly_coefficient_ring" . ("maxima.info-5" 258277 357 "Funções e Variáveis Definidas para grobner"))
("poly_colon_ideal" . ("maxima.info-5" 267962 224 "Funções e Variáveis Definidas para grobner"))
("poly_content" . ("maxima.info-5" 264132 201 "Funções e Variáveis Definidas para grobner"))
("poly_depends_p" . ("maxima.info-5" 267556 123 "Funções e Variáveis Definidas para grobner"))
("poly_elimination_ideal" . ("maxima.info-5" 267684 269 "Funções e Variáveis Definidas para grobner"))
("poly_elimination_order" . ("maxima.info-5" 259091 397 "Funções e Variáveis Definidas para grobner"))
("poly_exact_divide" . ("maxima.info-5" 264984 201 "Funções e Variáveis Definidas para grobner"))
("poly_expand" . ("maxima.info-5" 262270 1551 "Funções e Variáveis Definidas para grobner"))
("poly_expt" . ("maxima.info-5" 263843 281 "Funções e Variáveis Definidas para grobner"))
("poly_gcd" . ("maxima.info-5" 268471 107 "Funções e Variáveis Definidas para grobner"))
("poly_grobner" . ("maxima.info-5" 267189 171 "Funções e Variáveis Definidas para grobner"))
("poly_grobner_algorithm" . ("maxima.info-5" 259949 255 "Funções e Variáveis Definidas para grobner"))
("poly_grobner_debug" . ("maxima.info-5" 259803 138 "Funções e Variáveis Definidas para grobner"))
("poly_grobner_equal" . ("maxima.info-5" 268582 670 "Funções e Variáveis Definidas para grobner"))
("poly_grobner_member" . ("maxima.info-5" 269551 449 "Funções e Variáveis Definidas para grobner"))
("poly_grobner_subsetp" . ("maxima.info-5" 269263 284 "Funções e Variáveis Definidas para grobner"))
("poly_ideal_intersection" . ("maxima.info-5" 268191 157 "Funções e Variáveis Definidas para grobner"))
("poly_ideal_polysaturation" . ("maxima.info-5" 271173 299 "Funções e Variáveis Definidas para grobner"))
("poly_ideal_polysaturation1" . ("maxima.info-5" 270755 409 "Funções e Variáveis Definidas para grobner"))
("poly_ideal_saturation" . ("maxima.info-5" 270371 375 "Funções e Variáveis Definidas para grobner"))
("poly_ideal_saturation1" . ("maxima.info-5" 270008 354 "Funções e Variáveis Definidas para grobner"))
("poly_lcm" . ("maxima.info-5" 268353 113 "Funções e Variáveis Definidas para grobner"))
("poly_minimization" . ("maxima.info-5" 266627 287 "Funções e Variáveis Definidas para grobner"))
("poly_monomial_order" . ("maxima.info-5" 258026 240 "Funções e Variáveis Definidas para grobner"))
("poly_multiply" . ("maxima.info-5" 261307 240 "Funções e Variáveis Definidas para grobner"))
("poly_normal_form" . ("maxima.info-5" 265193 189 "Funções e Variáveis Definidas para grobner"))
("poly_normalize" . ("maxima.info-5" 261957 235 "Funções e Variáveis Definidas para grobner"))
("poly_normalize_list" . ("maxima.info-5" 266925 258 "Funções e Variáveis Definidas para grobner"))
("poly_primary_elimination_order" . ("maxima.info-5" 258646 210 "Funções e Variáveis Definidas para grobner"))
("poly_primitive_part" . ("maxima.info-5" 261710 243 "Funções e Variáveis Definidas para grobner"))
("poly_pseudo_divide" . ("maxima.info-5" 264336 629 "Funções e Variáveis Definidas para grobner"))
("poly_reduced_grobner" . ("maxima.info-5" 267364 188 "Funções e Variáveis Definidas para grobner"))
("poly_reduction" . ("maxima.info-5" 266408 210 "Funções e Variáveis Definidas para grobner"))
("poly_return_term_list" . ("maxima.info-5" 259507 286 "Funções e Variáveis Definidas para grobner"))
("poly_s_polynomial" . ("maxima.info-5" 261551 154 "Funções e Variáveis Definidas para grobner"))
("poly_saturation_extension" . ("maxima.info-5" 271477 179 "Funções e Variáveis Definidas para grobner"))
("poly_secondary_elimination_order" . ("maxima.info-5" 258871 207 "Funções e Variáveis Definidas para grobner"))
("poly_subtract" . ("maxima.info-5" 261032 270 "Funções e Variáveis Definidas para grobner"))
("poly_top_reduction_only" . ("maxima.info-5" 260211 239 "Funções e Variáveis Definidas para grobner"))
("polydecomp" . ("maxima.info-2" 47515 1955 "Funções e Variáveis Definidas para Polinômios"))
("polymod" . ("maxima.info-1" 124283 326 "Operadores Geral"))
("polymod <1>" . ("maxima.info-1" 124284 325 "Operadores Geral"))
("polynome2ele" . ("maxima.info-3" 292347 562 "Funções e Variáveis Definidas para Simetrias"))
("polynomialp" . ("maxima.info-5" 322762 1590 "Funções e Variáveis Definidas para linearalgebra"))
("polynomialp <1>" . ("maxima.info-5" 322763 1589 "Funções e Variáveis Definidas para linearalgebra"))
("polynomialp <2>" . ("maxima.info-5" 322820 1534 "Funções e Variáveis Definidas para linearalgebra"))
("polytocompanion" . ("maxima.info-5" 324372 301 "Funções e Variáveis Definidas para linearalgebra"))
("posfun" . ("maxima.info-1" 240738 129 "Funções e Variáveis Definidas para Simplificação"))
("potential" . ("maxima.info-2" 175036 550 "Funções e Variáveis Definidas para Integração"))
("power_mod" . ("maxima.info-3" 265601 541 "Funções e Variáveis Definidas para Teoria dos Números"))
("powerdisp" . ("maxima.info-3" 233396 413 "Funções e Variáveis Definidas para Séries"))
("powers" . ("maxima.info-1" 212266 140 "Funções e Variáveis Definidas para Expressões"))
("powerseries" . ("maxima.info-3" 233826 1712 "Funções e Variáveis Definidas para Séries"))
("powerset" . ("maxima.info-4" 134115 1138 "Funções e Variáveis Definidas para Conjuntos"))
("powerset <1>" . ("maxima.info-4" 134116 1137 "Funções e Variáveis Definidas para Conjuntos"))
("pred" . ("maxima.info-1" 126040 191 "Operadores Geral"))
("prederror" . ("maxima.info-4" 246708 471 "Funções e Variáveis Definidas para Fluxo de Programa"))
("prev_prime" . ("maxima.info-3" 267100 145 "Funções e Variáveis Definidas para Teoria dos Números"))
("primep" . ("maxima.info-3" 266149 801 "Funções e Variáveis Definidas para Teoria dos Números"))
("primep_number_of_tests" . ("maxima.info-3" 266967 127 "Funções e Variáveis Definidas para Teoria dos Números"))
("print" . ("maxima.info-1" 317807 1276 "Funções e Variáveis Definidas para Entrada e Saída"))
("printf" . ("maxima.info-6" 153051 3101 "Funções e Variáveis para entrada e saída"))
("printf <1>" . ("maxima.info-6" 153052 3100 "Funções e Variáveis para entrada e saída"))
("printpois" . ("maxima.info-2" 112736 197 "Funções e Variáveis Definidas para Funções Especiais"))
("printprops" . ("maxima.info-1" 73685 524 "Funções e Variáveis Definidas para Linha de Comando"))
("printprops <1>" . ("maxima.info-1" 73686 523 "Funções e Variáveis Definidas para Linha de Comando"))
("printprops <2>" . ("maxima.info-1" 73722 489 "Funções e Variáveis Definidas para Linha de Comando"))
("prodrac" . ("maxima.info-3" 292921 250 "Funções e Variáveis Definidas para Simetrias"))
("product" . ("maxima.info-1" 212412 2561 "Funções e Variáveis Definidas para Expressões"))
("product_use_gamma" . ("maxima.info-6" 103928 252 "Funções e Variáveis Definidas para solve_rec"))
("programmode" . ("maxima.info-2" 224835 454 "Funções e Variáveis Definidas para Equações"))
("prompt" . ("maxima.info-1" 74224 218 "Funções e Variáveis Definidas para Linha de Comando"))
("properties" . ("maxima.info-4" 22019 119 "Funções e Variáveis Definidas para Opções Diversas"))
("props" . ("maxima.info-4" 22142 284 "Funções e Variáveis Definidas para Opções Diversas"))
("propvars" . ("maxima.info-4" 22434 236 "Funções e Variáveis Definidas para Opções Diversas"))
("psexpand" . ("maxima.info-3" 235546 469 "Funções e Variáveis Definidas para Séries"))
("psi" . ("maxima.info-2" 112943 911 "Funções e Variáveis Definidas para Funções Especiais"))
("psi <1>" . ("maxima.info-3" 171313 1445 "Funções e Variáveis Definidas para ctensor"))
("ptriangularize" . ("maxima.info-5" 324681 454 "Funções e Variáveis Definidas para linearalgebra"))
("pui" . ("maxima.info-3" 274597 1331 "Funções e Variáveis Definidas para Simetrias"))
("pui2comp" . ("maxima.info-3" 275954 1295 "Funções e Variáveis Definidas para Simetrias"))
("pui2ele" . ("maxima.info-3" 277261 409 "Funções e Variáveis Definidas para Simetrias"))
("pui2polynome" . ("maxima.info-3" 293182 652 "Funções e Variáveis Definidas para Simetrias"))
("pui_direct" . ("maxima.info-3" 287601 2227 "Funções e Variáveis Definidas para Simetrias"))
("puireduc" . ("maxima.info-3" 277690 708 "Funções e Variáveis Definidas para Simetrias"))
("put" . ("maxima.info-4" 22676 847 "Funções e Variáveis Definidas para Opções Diversas"))
("qput" . ("maxima.info-4" 23530 808 "Funções e Variáveis Definidas para Opções Diversas"))
("qrange" . ("maxima.info-5" 34067 772 "Funções e Variáveis Definidas para estatística descritiva"))
("qrange <1>" . ("maxima.info-5" 34068 771 "Funções e Variáveis Definidas para estatística descritiva"))
("quad_qag" . ("maxima.info-2" 181924 2468 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qag <1>" . ("maxima.info-2" 181991 2403 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qagi" . ("maxima.info-2" 186387 2370 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qagi <1>" . ("maxima.info-2" 186388 2369 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qags" . ("maxima.info-2" 184456 1883 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qags <1>" . ("maxima.info-2" 184457 1882 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qawc" . ("maxima.info-2" 188806 2879 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qawc <1>" . ("maxima.info-2" 188807 2878 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qawf" . ("maxima.info-2" 191728 2733 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qawf <1>" . ("maxima.info-2" 191799 2664 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qawo" . ("maxima.info-2" 194518 2883 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qawo <1>" . ("maxima.info-2" 194594 2809 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qaws" . ("maxima.info-2" 197460 2850 "Funções e Variáveis Definidas para QUADPACK"))
("quad_qaws <1>" . ("maxima.info-2" 197534 2778 "Funções e Variáveis Definidas para QUADPACK"))
("quantile" . ("maxima.info-5" 32316 949 "Funções e Variáveis Definidas para estatística descritiva"))
("quantile <1>" . ("maxima.info-5" 32317 948 "Funções e Variáveis Definidas para estatística descritiva"))
("quantile_bernoulli" . ("maxima.info-5" 158914 321 "Funções e Variáveis Definidas para distribuições discretas"))
("quantile_beta" . ("maxima.info-5" 124811 313 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_binomial" . ("maxima.info-5" 151890 354 "Funções e Variáveis Definidas para distribuições discretas"))
("quantile_cauchy" . ("maxima.info-5" 147122 317 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_chi2" . ("maxima.info-5" 100478 876 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_continuous_uniform" . ("maxima.info-5" 128002 358 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_discrete_uniform" . ("maxima.info-5" 166497 376 "Funções e Variáveis Definidas para distribuições discretas"))
("quantile_exp" . ("maxima.info-5" 111493 784 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_f" . ("maxima.info-5" 106924 713 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_gamma" . ("maxima.info-5" 121159 316 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_geometric" . ("maxima.info-5" 163346 321 "Funções e Variáveis Definidas para distribuições discretas"))
("quantile_gumbel" . ("maxima.info-5" 148352 317 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_hypergeometric" . ("maxima.info-5" 169286 408 "Funções e Variáveis Definidas para distribuições discretas"))
("quantile_laplace" . ("maxima.info-5" 144879 319 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_logistic" . ("maxima.info-5" 130502 323 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_lognormal" . ("maxima.info-5" 118233 325 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_negative_binomial" . ("maxima.info-5" 173552 386 "Funções e Variáveis Definidas para distribuições discretas"))
("quantile_normal" . ("maxima.info-5" 92199 303 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_pareto" . ("maxima.info-5" 132766 320 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_poisson" . ("maxima.info-5" 155494 313 "Funções e Variáveis Definidas para distribuições discretas"))
("quantile_rayleigh" . ("maxima.info-5" 138469 920 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_student_t" . ("maxima.info-5" 95677 324 "Funções e Variáveis Definidas para distribuições contínuas"))
("quantile_weibull" . ("maxima.info-5" 135028 321 "Funções e Variáveis Definidas para distribuições contínuas"))
("quartile_skewness" . ("maxima.info-5" 41318 942 "Funções e Variáveis Definidas para estatística descritiva"))
("quartile_skewness <1>" . ("maxima.info-5" 41319 941 "Funções e Variáveis Definidas para estatística descritiva"))
("quit" . ("maxima.info-1" 74453 373 "Funções e Variáveis Definidas para Linha de Comando"))
("qunit" . ("maxima.info-3" 267248 425 "Funções e Variáveis Definidas para Teoria dos Números"))
("quotient" . ("maxima.info-2" 49496 333 "Funções e Variáveis Definidas para Polinômios"))
("quotient <1>" . ("maxima.info-2" 49497 332 "Funções e Variáveis Definidas para Polinômios"))
("radcan" . ("maxima.info-1" 240872 1314 "Funções e Variáveis Definidas para Simplificação"))
("radexpand" . ("maxima.info-1" 242225 859 "Funções e Variáveis Definidas para Simplificação"))
("radsubstflag" . ("maxima.info-1" 243099 179 "Funções e Variáveis Definidas para Simplificação"))
("random" . ("maxima.info-1" 127217 1672 "Operadores Geral"))
("random_bernoulli" . ("maxima.info-5" 162389 462 "Funções e Variáveis Definidas para distribuições discretas"))
("random_bernoulli <1>" . ("maxima.info-5" 162390 461 "Funções e Variáveis Definidas para distribuições discretas"))
("random_beta" . ("maxima.info-5" 126850 601 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_beta <1>" . ("maxima.info-5" 126851 600 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_beta_algorithm" . ("maxima.info-5" 126117 710 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_binomial" . ("maxima.info-5" 154050 654 "Funções e Variáveis Definidas para distribuições discretas"))
("random_binomial <1>" . ("maxima.info-5" 154051 653 "Funções e Variáveis Definidas para distribuições discretas"))
("random_binomial_algorithm" . ("maxima.info-5" 153409 623 "Funções e Variáveis Definidas para distribuições discretas"))
("random_cauchy" . ("maxima.info-5" 147451 405 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_cauchy <1>" . ("maxima.info-5" 147452 404 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_chi2" . ("maxima.info-5" 105423 607 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_chi2 <1>" . ("maxima.info-5" 105424 606 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_chi2_algorithm" . ("maxima.info-5" 104920 484 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_continuous_uniform" . ("maxima.info-5" 129495 499 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_continuous_uniform <1>" . ("maxima.info-5" 129496 498 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_discrete_uniform" . ("maxima.info-5" 168113 524 "Funções e Variáveis Definidas para distribuições discretas"))
("random_discrete_uniform <1>" . ("maxima.info-5" 168114 523 "Funções e Variáveis Definidas para distribuições discretas"))
("random_exp" . ("maxima.info-5" 116742 592 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_exp <1>" . ("maxima.info-5" 116743 591 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_exp_algorithm" . ("maxima.info-5" 115954 769 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_f" . ("maxima.info-5" 109350 588 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_f <1>" . ("maxima.info-5" 109351 587 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_f_algorithm" . ("maxima.info-5" 108640 687 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_gamma" . ("maxima.info-5" 123285 614 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_gamma <1>" . ("maxima.info-5" 123286 613 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_gamma_algorithm" . ("maxima.info-5" 122484 782 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_geometric" . ("maxima.info-5" 165295 623 "Funções e Variáveis Definidas para distribuições discretas"))
("random_geometric <1>" . ("maxima.info-5" 165296 622 "Funções e Variáveis Definidas para distribuições discretas"))
("random_geometric_algorithm" . ("maxima.info-5" 164690 586 "Funções e Variáveis Definidas para distribuições discretas"))
("random_gumbel" . ("maxima.info-5" 150190 407 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_gumbel <1>" . ("maxima.info-5" 150191 406 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_hypergeometric" . ("maxima.info-5" 171768 731 "Funções e Variáveis Definidas para distribuições discretas"))
("random_hypergeometric <1>" . ("maxima.info-5" 171769 730 "Funções e Variáveis Definidas para distribuições discretas"))
("random_hypergeometric_algorithm" . ("maxima.info-5" 171118 630 "Funções e Variáveis Definidas para distribuições discretas"))
("random_laplace" . ("maxima.info-5" 146217 409 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_laplace <1>" . ("maxima.info-5" 146218 408 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_logistic" . ("maxima.info-5" 131853 413 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_logistic <1>" . ("maxima.info-5" 131854 412 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_lognormal" . ("maxima.info-5" 119597 732 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_lognormal <1>" . ("maxima.info-5" 119598 731 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_negative_binomial" . ("maxima.info-5" 175825 714 "Funções e Variáveis Definidas para distribuições discretas"))
("random_negative_binomial <1>" . ("maxima.info-5" 175826 713 "Funções e Variáveis Definidas para distribuições discretas"))
("random_negative_binomial_algorithm" . ("maxima.info-5" 175193 614 "Funções e Variáveis Definidas para distribuições discretas"))
("random_normal" . ("maxima.info-5" 94110 626 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_normal <1>" . ("maxima.info-5" 94111 625 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_normal_algorithm" . ("maxima.info-5" 93603 492 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_pareto" . ("maxima.info-5" 134115 409 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_pareto <1>" . ("maxima.info-5" 134116 408 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_permutation" . ("maxima.info-4" 135261 841 "Funções e Variáveis Definidas para Conjuntos"))
("random_poisson" . ("maxima.info-5" 157413 613 "Funções e Variáveis Definidas para distribuições discretas"))
("random_poisson <1>" . ("maxima.info-5" 157414 612 "Funções e Variáveis Definidas para distribuições discretas"))
("random_poisson_algorithm" . ("maxima.info-5" 156794 603 "Funções e Variáveis Definidas para distribuições discretas"))
("random_rayleigh" . ("maxima.info-5" 143977 402 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_rayleigh <1>" . ("maxima.info-5" 143978 401 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_student_t" . ("maxima.info-5" 98143 621 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_student_t <1>" . ("maxima.info-5" 98144 620 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_student_t_algorithm" . ("maxima.info-5" 97218 902 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_weibull" . ("maxima.info-5" 136378 411 "Funções e Variáveis Definidas para distribuições contínuas"))
("random_weibull <1>" . ("maxima.info-5" 136379 410 "Funções e Variáveis Definidas para distribuições contínuas"))
("range" . ("maxima.info-5" 31805 503 "Funções e Variáveis Definidas para estatística descritiva"))
("range <1>" . ("maxima.info-5" 31806 502 "Funções e Variáveis Definidas para estatística descritiva"))
("rank" . ("maxima.info-3" 43612 271 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("rank <1>" . ("maxima.info-5" 325393 343 "Funções e Variáveis Definidas para linearalgebra"))
("rassociative" . ("maxima.info-1" 243285 204 "Funções e Variáveis Definidas para Simplificação"))
("rat" . ("maxima.info-2" 49837 2541 "Funções e Variáveis Definidas para Polinômios"))
("rat <1>" . ("maxima.info-2" 49838 2540 "Funções e Variáveis Definidas para Polinômios"))
("ratalgdenom" . ("maxima.info-2" 52435 304 "Funções e Variáveis Definidas para Polinômios"))
("ratchristof" . ("maxima.info-3" 203286 122 "Funções e Variáveis Definidas para ctensor"))
("ratcoef" . ("maxima.info-2" 52749 1165 "Funções e Variáveis Definidas para Polinômios"))
("ratcoef <1>" . ("maxima.info-2" 52750 1164 "Funções e Variáveis Definidas para Polinômios"))
("ratdenom" . ("maxima.info-2" 53934 645 "Funções e Variáveis Definidas para Polinômios"))
("ratdenomdivide" . ("maxima.info-2" 54603 1862 "Funções e Variáveis Definidas para Polinômios"))
("ratdiff" . ("maxima.info-2" 56481 1873 "Funções e Variáveis Definidas para Polinômios"))
("ratdisrep" . ("maxima.info-2" 58375 452 "Funções e Variáveis Definidas para Polinômios"))
("rateinstein" . ("maxima.info-3" 203415 252 "Funções e Variáveis Definidas para ctensor"))
("ratepsilon" . ("maxima.info-2" 58843 173 "Funções e Variáveis Definidas para Polinômios"))
("ratexpand" . ("maxima.info-2" 59026 2351 "Funções e Variáveis Definidas para Polinômios"))
("ratexpand <1>" . ("maxima.info-2" 59027 2350 "Funções e Variáveis Definidas para Polinômios"))
("ratfac" . ("maxima.info-2" 61412 1083 "Funções e Variáveis Definidas para Polinômios"))
("rational" . ("maxima.info-6" 83064 364 "Funções e Variáveis Definidas para simplification"))
("rationalize" . ("maxima.info-1" 128912 3293 "Operadores Geral"))
("ratmx" . ("maxima.info-3" 43891 610 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("ratnumer" . ("maxima.info-2" 62519 643 "Funções e Variáveis Definidas para Polinômios"))
("ratnump" . ("maxima.info-2" 63187 150 "Funções e Variáveis Definidas para Polinômios"))
("ratp" . ("maxima.info-2" 63341 279 "Funções e Variáveis Definidas para Polinômios"))
("ratprint" . ("maxima.info-2" 63631 217 "Funções e Variáveis Definidas para Polinômios"))
("ratriemann" . ("maxima.info-3" 203679 296 "Funções e Variáveis Definidas para ctensor"))
("ratsimp" . ("maxima.info-2" 63858 2202 "Funções e Variáveis Definidas para Polinômios"))
("ratsimp <1>" . ("maxima.info-2" 63859 2201 "Funções e Variáveis Definidas para Polinômios"))
("ratsimpexpons" . ("maxima.info-2" 66096 190 "Funções e Variáveis Definidas para Polinômios"))
("ratsubst" . ("maxima.info-2" 66295 1536 "Funções e Variáveis Definidas para Polinômios"))
("ratvars" . ("maxima.info-2" 67848 1020 "Funções e Variáveis Definidas para Polinômios"))
("ratvars <1>" . ("maxima.info-2" 67849 1019 "Funções e Variáveis Definidas para Polinômios"))
("ratvars <2>" . ("maxima.info-2" 67891 979 "Funções e Variáveis Definidas para Polinômios"))
("ratweight" . ("maxima.info-2" 68902 1165 "Funções e Variáveis Definidas para Polinômios"))
("ratweight <1>" . ("maxima.info-2" 68903 1164 "Funções e Variáveis Definidas para Polinômios"))
("ratweights" . ("maxima.info-2" 70091 304 "Funções e Variáveis Definidas para Polinômios"))
("ratweyl" . ("maxima.info-3" 203990 272 "Funções e Variáveis Definidas para ctensor"))
("ratwtlvl" . ("maxima.info-2" 70402 255 "Funções e Variáveis Definidas para Polinômios"))
("read" . ("maxima.info-1" 320308 535 "Funções e Variáveis Definidas para Entrada e Saída"))
("read_hashed_array" . ("maxima.info-6" 17900 424 "Funções e Variáveis Definidas para numericalio"))
("read_hashed_array <1>" . ("maxima.info-6" 17901 423 "Funções e Variáveis Definidas para numericalio"))
("read_lisp_array" . ("maxima.info-6" 16679 589 "Funções e Variáveis Definidas para numericalio"))
("read_lisp_array <1>" . ("maxima.info-6" 16680 588 "Funções e Variáveis Definidas para numericalio"))
("read_list" . ("maxima.info-6" 18688 209 "Funções e Variáveis Definidas para numericalio"))
("read_list <1>" . ("maxima.info-6" 18689 208 "Funções e Variáveis Definidas para numericalio"))
("read_matrix" . ("maxima.info-6" 16171 498 "Funções e Variáveis Definidas para numericalio"))
("read_matrix <1>" . ("maxima.info-6" 16172 497 "Funções e Variáveis Definidas para numericalio"))
("read_maxima_array" . ("maxima.info-6" 17288 592 "Funções e Variáveis Definidas para numericalio"))
("read_maxima_array <1>" . ("maxima.info-6" 17289 591 "Funções e Variáveis Definidas para numericalio"))
("read_nested_list" . ("maxima.info-6" 18332 347 "Funções e Variáveis Definidas para numericalio"))
("read_nested_list <1>" . ("maxima.info-6" 18333 346 "Funções e Variáveis Definidas para numericalio"))
("readline" . ("maxima.info-6" 156207 220 "Funções e Variáveis para entrada e saída"))
("readonly" . ("maxima.info-1" 320855 640 "Funções e Variáveis Definidas para Entrada e Saída"))
("realonly" . ("maxima.info-2" 225303 157 "Funções e Variáveis Definidas para Equações"))
("realpart" . ("maxima.info-1" 214996 246 "Funções e Variáveis Definidas para Expressões"))
("realroots" . ("maxima.info-2" 225467 2187 "Funções e Variáveis Definidas para Equações"))
("realroots <1>" . ("maxima.info-2" 225468 2186 "Funções e Variáveis Definidas para Equações"))
("realroots <2>" . ("maxima.info-2" 225510 2146 "Funções e Variáveis Definidas para Equações"))
("realroots <3>" . ("maxima.info-2" 225551 2107 "Funções e Variáveis Definidas para Equações"))
("rearray" . ("maxima.info-2" 288468 364 "Funções e Variáveis Definidas para Arrays"))
("rectform" . ("maxima.info-1" 215255 136 "Funções e Variáveis Definidas para Expressões"))
("recttopolar" . ("maxima.info-2" 253633 809 "Funções e Variáveis Definidas para Numérico"))
("recttopolar <1>" . ("maxima.info-2" 254959 2308 "Funções e Variáveis Definidas para Numérico"))
("rediff" . ("maxima.info-3" 103946 115 "Funções e Variáveis Definidas para itensor"))
("reduce_consts" . ("maxima.info-6" 91949 1445 "Funções e Variáveis Definidas para simplification"))
("reduce_order" . ("maxima.info-6" 96871 1800 "Funções e Variáveis Definidas para solve_rec"))
("refcheck" . ("maxima.info-4" 263461 216 "Funções e Variáveis Definidas para Depuração"))
("rem" . ("maxima.info-4" 24347 109 "Funções e Variáveis Definidas para Opções Diversas"))
("remainder" . ("maxima.info-2" 70674 348 "Funções e Variáveis Definidas para Polinômios"))
("remainder <1>" . ("maxima.info-2" 70675 347 "Funções e Variáveis Definidas para Polinômios"))
("remarray" . ("maxima.info-2" 288840 557 "Funções e Variáveis Definidas para Arrays"))
("remarray <1>" . ("maxima.info-2" 288841 556 "Funções e Variáveis Definidas para Arrays"))
("rembox" . ("maxima.info-1" 215395 3113 "Funções e Variáveis Definidas para Expressões"))
("rembox <1>" . ("maxima.info-1" 215396 3112 "Funções e Variáveis Definidas para Expressões"))
("rembox <2>" . ("maxima.info-1" 215438 3072 "Funções e Variáveis Definidas para Expressões"))
("remcomps" . ("maxima.info-3" 86128 131 "Funções e Variáveis Definidas para itensor"))
("remcon" . ("maxima.info-3" 81064 252 "Funções e Variáveis Definidas para itensor"))
("remcon <1>" . ("maxima.info-3" 81065 251 "Funções e Variáveis Definidas para itensor"))
("remcoord" . ("maxima.info-3" 108513 284 "Funções e Variáveis Definidas para itensor"))
("remcoord <1>" . ("maxima.info-3" 108514 283 "Funções e Variáveis Definidas para itensor"))
("remfun" . ("maxima.info-2" 267694 327 "Funções e Variáveis Definidas para Séries de Fourier"))
("remfun <1>" . ("maxima.info-2" 267695 326 "Funções e Variáveis Definidas para Séries de Fourier"))
("remfunction" . ("maxima.info-1" 74842 653 "Funções e Variáveis Definidas para Linha de Comando"))
("remfunction <1>" . ("maxima.info-1" 74843 652 "Funções e Variáveis Definidas para Linha de Comando"))
("remlet" . ("maxima.info-4" 61110 1006 "Funções e Variáveis Definidas para Regras e Modelos"))
("remlet <1>" . ("maxima.info-4" 61111 1005 "Funções e Variáveis Definidas para Regras e Modelos"))
("remlet <2>" . ("maxima.info-4" 61149 969 "Funções e Variáveis Definidas para Regras e Modelos"))
("remlet <3>" . ("maxima.info-4" 61173 947 "Funções e Variáveis Definidas para Regras e Modelos"))
("remove" . ("maxima.info-4" 24462 1534 "Funções e Variáveis Definidas para Opções Diversas"))
("remove <1>" . ("maxima.info-4" 24463 1533 "Funções e Variáveis Definidas para Opções Diversas"))
("remove <2>" . ("maxima.info-4" 24518 1480 "Funções e Variáveis Definidas para Opções Diversas"))
("remove <3>" . ("maxima.info-4" 24587 1413 "Funções e Variáveis Definidas para Opções Diversas"))
("remove <4>" . ("maxima.info-4" 24626 1376 "Funções e Variáveis Definidas para Opções Diversas"))
("rempart" . ("maxima.info-6" 82096 243 "Funções e Variáveis Definidas para simplification"))
("remrule" . ("maxima.info-4" 62149 2055 "Funções e Variáveis Definidas para Regras e Modelos"))
("remrule <1>" . ("maxima.info-4" 62150 2054 "Funções e Variáveis Definidas para Regras e Modelos"))
("remsym" . ("maxima.info-3" 100250 166 "Funções e Variáveis Definidas para itensor"))
("remvalue" . ("maxima.info-4" 26031 442 "Funções e Variáveis Definidas para Opções Diversas"))
("remvalue <1>" . ("maxima.info-4" 26032 441 "Funções e Variáveis Definidas para Opções Diversas"))
("rename" . ("maxima.info-3" 75963 3341 "Funções e Variáveis Definidas para itensor"))
("rename <1>" . ("maxima.info-3" 75964 3340 "Funções e Variáveis Definidas para itensor"))
("reset" . ("maxima.info-1" 75526 481 "Funções e Variáveis Definidas para Linha de Comando"))
("residue" . ("maxima.info-2" 175600 651 "Funções e Variáveis Definidas para Integração"))
("resolvante" . ("maxima.info-3" 294133 7353 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_alternee1" . ("maxima.info-3" 301524 411 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_bipartite" . ("maxima.info-3" 301943 764 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_diedrale" . ("maxima.info-3" 302717 688 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_klein" . ("maxima.info-3" 303414 329 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_klein3" . ("maxima.info-3" 303747 323 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_produit_sym" . ("maxima.info-3" 304079 1070 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_unitaire" . ("maxima.info-3" 305154 321 "Funções e Variáveis Definidas para Simetrias"))
("resolvante_vierer" . ("maxima.info-3" 305481 318 "Funções e Variáveis Definidas para Simetrias"))
("rest" . ("maxima.info-4" 88459 312 "Funções e Variáveis Definidas para Listas"))
("rest <1>" . ("maxima.info-4" 88460 311 "Funções e Variáveis Definidas para Listas"))
("resultant" . ("maxima.info-2" 71030 994 "Funções e Variáveis Definidas para Polinômios"))
("resultant <1>" . ("maxima.info-2" 71031 993 "Funções e Variáveis Definidas para Polinômios"))
("return" . ("maxima.info-4" 247196 151 "Funções e Variáveis Definidas para Fluxo de Programa"))
("reveal" . ("maxima.info-1" 321515 2439 "Funções e Variáveis Definidas para Entrada e Saída"))
("reverse" . ("maxima.info-4" 88778 203 "Funções e Variáveis Definidas para Listas"))
("revert" . ("maxima.info-3" 236033 1850 "Funções e Variáveis Definidas para Séries"))
("revert2" . ("maxima.info-3" 236034 1849 "Funções e Variáveis Definidas para Séries"))
("rhs" . ("maxima.info-2" 227705 1606 "Funções e Variáveis Definidas para Equações"))
("ric" . ("maxima.info-3" 205158 80 "Funções e Variáveis Definidas para ctensor"))
("ricci" . ("maxima.info-3" 158843 250 "Funções e Variáveis Definidas para ctensor"))
("riem" . ("maxima.info-3" 204638 308 "Funções e Variáveis Definidas para ctensor"))
("riemann" . ("maxima.info-3" 160851 1243 "Funções e Variáveis Definidas para ctensor"))
("rinvariant" . ("maxima.info-3" 162856 267 "Funções e Variáveis Definidas para ctensor"))
("risch" . ("maxima.info-2" 176260 1034 "Funções e Variáveis Definidas para Integração"))
("rk" . ("maxima.info-5" 243067 2415 "Funções e Variáveis Definidas para dynamics"))
("rk <1>" . ("maxima.info-5" 243068 2414 "Funções e Variáveis Definidas para dynamics"))
("rmxchar" . ("maxima.info-1" 323984 153 "Funções e Variáveis Definidas para Entrada e Saída"))
("rncombine" . ("maxima.info-4" 26490 755 "Funções e Variáveis Definidas para Opções Diversas"))
("romberg" . ("maxima.info-6" 62085 5027 "Funções e Variáveis Definidas para romberg"))
("romberg <1>" . ("maxima.info-6" 62086 5026 "Funções e Variáveis Definidas para romberg"))
("rombergabs" . ("maxima.info-6" 67197 539 "Funções e Variáveis Definidas para romberg"))
("rombergit" . ("maxima.info-6" 67752 446 "Funções e Variáveis Definidas para romberg"))
("rombergmin" . ("maxima.info-6" 68220 277 "Funções e Variáveis Definidas para romberg"))
("rombergtol" . ("maxima.info-6" 68512 542 "Funções e Variáveis Definidas para romberg"))
("room" . ("maxima.info-4" 7727 370 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("room <1>" . ("maxima.info-4" 7728 369 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("room <2>" . ("maxima.info-4" 7750 349 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("rootsconmode" . ("maxima.info-2" 229323 176 "Funções e Variáveis Definidas para Equações"))
("rootscontract" . ("maxima.info-2" 229504 2662 "Funções e Variáveis Definidas para Equações"))
("rootsepsilon" . ("maxima.info-2" 232182 193 "Funções e Variáveis Definidas para Equações"))
("rot_horizontal" . ("maxima.info-5" 186579 617 "Funções e Variáveis Definidas para draw"))
("rot_vertical" . ("maxima.info-5" 185986 568 "Funções e Variáveis Definidas para draw"))
("row" . ("maxima.info-3" 44525 112 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("rowop" . ("maxima.info-5" 325148 239 "Funções e Variáveis Definidas para linearalgebra"))
("rowswap" . ("maxima.info-5" 325742 166 "Funções e Variáveis Definidas para linearalgebra"))
("rreduce" . ("maxima.info-4" 136114 1544 "Funções e Variáveis Definidas para Conjuntos"))
("rreduce <1>" . ("maxima.info-4" 136115 1543 "Funções e Variáveis Definidas para Conjuntos"))
("run_testsuite" . ("maxima.info-1" 23600 1210 "Definições para Detecção e Relato de Erros"))
("run_testsuite <1>" . ("maxima.info-1" 23601 1209 "Definições para Detecção e Relato de Erros"))
("run_testsuite <2>" . ("maxima.info-1" 23632 1180 "Definições para Detecção e Relato de Erros"))
("run_testsuite <3>" . ("maxima.info-1" 23672 1142 "Definições para Detecção e Relato de Erros"))
("save" . ("maxima.info-1" 324144 3111 "Funções e Variáveis Definidas para Entrada e Saída"))
("save <1>" . ("maxima.info-1" 324145 3110 "Funções e Variáveis Definidas para Entrada e Saída"))
("save <2>" . ("maxima.info-1" 324215 3042 "Funções e Variáveis Definidas para Entrada e Saída"))
("save <3>" . ("maxima.info-1" 324282 2977 "Funções e Variáveis Definidas para Entrada e Saída"))
("save <4>" . ("maxima.info-1" 324329 2932 "Funções e Variáveis Definidas para Entrada e Saída"))
("save <5>" . ("maxima.info-1" 324388 2875 "Funções e Variáveis Definidas para Entrada e Saída"))
("savedef" . ("maxima.info-1" 327320 387 "Funções e Variáveis Definidas para Entrada e Saída"))
("savefactors" . ("maxima.info-2" 72044 336 "Funções e Variáveis Definidas para Polinômios"))
("scalarmatrixp" . ("maxima.info-3" 44642 503 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("scalarp" . ("maxima.info-4" 27255 251 "Funções e Variáveis Definidas para Opções Diversas"))
("scaled_bessel_i" . ("maxima.info-2" 107062 488 "Funções e Variáveis Definidas para Funções Especiais"))
("scaled_bessel_i0" . ("maxima.info-2" 107570 76 "Funções e Variáveis Definidas para Funções Especiais"))
("scaled_bessel_i1" . ("maxima.info-2" 107650 76 "Funções e Variáveis Definidas para Funções Especiais"))
("scalefactors" . ("maxima.info-3" 45162 1036 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("scanmap" . ("maxima.info-4" 247352 1659 "Funções e Variáveis Definidas para Fluxo de Programa"))
("scanmap <1>" . ("maxima.info-4" 247353 1658 "Funções e Variáveis Definidas para Fluxo de Programa"))
("schur2comp" . ("maxima.info-3" 278407 648 "Funções e Variáveis Definidas para Simetrias"))
("sconc" . ("maxima.info-6" 162604 391 "Funções e Variáveis para seqüências de caracteres"))
("sconcat" . ("maxima.info-1" 291868 384 "Funções e Variáveis Definidas para Entrada e Saída"))
("scopy" . ("maxima.info-6" 163003 118 "Funções e Variáveis para seqüências de caracteres"))
("scsimp" . ("maxima.info-1" 243494 427 "Funções e Variáveis Definidas para Simplificação"))
("scurvature" . ("maxima.info-3" 159653 161 "Funções e Variáveis Definidas para ctensor"))
("sdowncase" . ("maxima.info-6" 163127 247 "Funções e Variáveis para seqüências de caracteres"))
("sdowncase <1>" . ("maxima.info-6" 163128 246 "Funções e Variáveis para seqüências de caracteres"))
("sdowncase <2>" . ("maxima.info-6" 163168 208 "Funções e Variáveis para seqüências de caracteres"))
("sec" . ("maxima.info-2" 92262 38 "Funções e Variáveis Definidas para Trigonometria"))
("sech" . ("maxima.info-2" 92303 51 "Funções e Variáveis Definidas para Trigonometria"))
("second" . ("maxima.info-4" 88987 128 "Funções e Variáveis Definidas para Listas"))
("sequal" . ("maxima.info-6" 163384 183 "Funções e Variáveis para seqüências de caracteres"))
("sequalignore" . ("maxima.info-6" 163570 116 "Funções e Variáveis para seqüências de caracteres"))
("set_partitions" . ("maxima.info-4" 140401 1764 "Funções e Variáveis Definidas para Conjuntos"))
("set_partitions <1>" . ("maxima.info-4" 140402 1763 "Funções e Variáveis Definidas para Conjuntos"))
("set_plot_option" . ("maxima.info-1" 272553 2370 "Funções e Variáveis Definidas para Montagem de Gráficos"))
("set_random_state" . ("maxima.info-1" 127066 146 "Operadores Geral"))
("set_up_dot_simplifications" . ("maxima.info-3" 55865 877 "Funções e Variáveis Definidas para Funções Afins"))
("set_up_dot_simplifications <1>" . ("maxima.info-3" 55866 876 "Funções e Variáveis Definidas para Funções Afins"))
("setcheck" . ("maxima.info-4" 263685 1299 "Funções e Variáveis Definidas para Depuração"))
("setcheckbreak" . ("maxima.info-4" 265025 510 "Funções e Variáveis Definidas para Depuração"))
("setdifference" . ("maxima.info-4" 137683 872 "Funções e Variáveis Definidas para Conjuntos"))
("setelmx" . ("maxima.info-3" 46232 226 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("setequalp" . ("maxima.info-4" 138561 631 "Funções e Variáveis Definidas para Conjuntos"))
("setify" . ("maxima.info-4" 139196 584 "Funções e Variáveis Definidas para Conjuntos"))
("setp" . ("maxima.info-4" 139787 602 "Funções e Variáveis Definidas para Conjuntos"))
("setunits" . ("maxima.info-6" 179571 5021 "Funções e Variáveis Definidas para Units"))
("setup_autoload" . ("maxima.info-4" 27514 1391 "Funções e Variáveis Definidas para Opções Diversas"))
("setval" . ("maxima.info-4" 265556 281 "Funções e Variáveis Definidas para Depuração"))
("seventh" . ("maxima.info-4" 89119 128 "Funções e Variáveis Definidas para Listas"))
("sexplode" . ("maxima.info-6" 163689 92 "Funções e Variáveis para seqüências de caracteres"))
("sf" . ("maxima.info-3" 219584 280 "Funções e Variáveis Definidas para o Pacote atensor"))
("show" . ("maxima.info-1" 327731 277 "Funções e Variáveis Definidas para Entrada e Saída"))
("showcomps" . ("maxima.info-3" 86265 2571 "Funções e Variáveis Definidas para itensor"))
("showratvars" . ("maxima.info-1" 328017 158 "Funções e Variáveis Definidas para Entrada e Saída"))
("showtime" . ("maxima.info-1" 76031 369 "Funções e Variáveis Definidas para Linha de Comando"))
("sign" . ("maxima.info-1" 132229 384 "Operadores Geral"))
("signum" . ("maxima.info-1" 132617 325 "Operadores Geral"))
("similaritytransform" . ("maxima.info-3" 46462 1206 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("simple_linear_regression" . ("maxima.info-6" 137277 4243 "Funções e Variáveis Definidas para stats"))
("simple_linear_regression <1>" . ("maxima.info-6" 137278 4242 "Funções e Variáveis Definidas para stats"))
("simplified_output" . ("maxima.info-6" 206281 190 "Funções e Variáveis Definidas para zeilberger"))
("simplify_products" . ("maxima.info-6" 98680 203 "Funções e Variáveis Definidas para solve_rec"))
("simplify_sum" . ("maxima.info-6" 98890 1077 "Funções e Variáveis Definidas para solve_rec"))
("simplode" . ("maxima.info-6" 163787 665 "Funções e Variáveis para seqüências de caracteres"))
("simplode <1>" . ("maxima.info-6" 163788 664 "Funções e Variáveis para seqüências de caracteres"))
("simpmetderiv" . ("maxima.info-3" 109930 3108 "Funções e Variáveis Definidas para itensor"))
("simpmetderiv <1>" . ("maxima.info-3" 109931 3107 "Funções e Variáveis Definidas para itensor"))
("simpsum" . ("maxima.info-1" 243933 413 "Funções e Variáveis Definidas para Simplificação"))
("simtran" . ("maxima.info-3" 46463 1205 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("sin" . ("maxima.info-2" 92358 35 "Funções e Variáveis Definidas para Trigonometria"))
("sinh" . ("maxima.info-2" 92396 48 "Funções e Variáveis Definidas para Trigonometria"))
("sinnpiflag" . ("maxima.info-2" 269250 83 "Funções e Variáveis Definidas para Séries de Fourier"))
("sinsert" . ("maxima.info-6" 164463 569 "Funções e Variáveis para seqüências de caracteres"))
("sinvertcase" . ("maxima.info-6" 165046 478 "Funções e Variáveis para seqüências de caracteres"))
("sinvertcase <1>" . ("maxima.info-6" 165047 477 "Funções e Variáveis para seqüências de caracteres"))
("sinvertcase <2>" . ("maxima.info-6" 165089 437 "Funções e Variáveis para seqüências de caracteres"))
("sixth" . ("maxima.info-4" 89252 125 "Funções e Variáveis Definidas para Listas"))
("skewness" . ("maxima.info-5" 39545 910 "Funções e Variáveis Definidas para estatística descritiva"))
("skewness <1>" . ("maxima.info-5" 39546 909 "Funções e Variáveis Definidas para estatística descritiva"))
("skewness_bernoulli" . ("maxima.info-5" 160952 710 "Funções e Variáveis Definidas para distribuições discretas"))
("skewness_beta" . ("maxima.info-5" 125698 204 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_binomial" . ("maxima.info-5" 152926 236 "Funções e Variáveis Definidas para distribuições discretas"))
("skewness_chi2" . ("maxima.info-5" 103338 785 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_continuous_uniform" . ("maxima.info-5" 129024 230 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_discrete_uniform" . ("maxima.info-5" 167600 251 "Funções e Variáveis Definidas para distribuições discretas"))
("skewness_exp" . ("maxima.info-5" 114554 690 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_f" . ("maxima.info-5" 108221 204 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_gamma" . ("maxima.info-5" 122061 206 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_geometric" . ("maxima.info-5" 164259 208 "Funções e Variáveis Definidas para distribuições discretas"))
("skewness_gumbel" . ("maxima.info-5" 149408 565 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_hypergeometric" . ("maxima.info-5" 170537 284 "Funções e Variáveis Definidas para distribuições discretas"))
("skewness_laplace" . ("maxima.info-5" 145790 208 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_logistic" . ("maxima.info-5" 131420 211 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_lognormal" . ("maxima.info-5" 119162 212 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_negative_binomial" . ("maxima.info-5" 174674 254 "Funções e Variáveis Definidas para distribuições discretas"))
("skewness_normal" . ("maxima.info-5" 93131 229 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_pareto" . ("maxima.info-5" 133684 210 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_poisson" . ("maxima.info-5" 156375 202 "Funções e Variáveis Definidas para distribuições discretas"))
("skewness_rayleigh" . ("maxima.info-5" 141899 1039 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_student_t" . ("maxima.info-5" 96764 233 "Funções e Variáveis Definidas para distribuições contínuas"))
("skewness_weibull" . ("maxima.info-5" 135947 210 "Funções e Variáveis Definidas para distribuições contínuas"))
("slength" . ("maxima.info-6" 165546 88 "Funções e Variáveis para seqüências de caracteres"))
("smake" . ("maxima.info-6" 165638 201 "Funções e Variáveis para seqüências de caracteres"))
("smismatch" . ("maxima.info-6" 165844 529 "Funções e Variáveis para seqüências de caracteres"))
("smismatch <1>" . ("maxima.info-6" 165845 528 "Funções e Variáveis para seqüências de caracteres"))
("solve" . ("maxima.info-2" 232386 7076 "Funções e Variáveis Definidas para Equações"))
("solve <1>" . ("maxima.info-2" 232387 7075 "Funções e Variáveis Definidas para Equações"))
("solve <2>" . ("maxima.info-2" 232421 7043 "Funções e Variáveis Definidas para Equações"))
("solve_inconsistent_error" . ("maxima.info-2" 241123 721 "Funções e Variáveis Definidas para Equações"))
("solve_rec" . ("maxima.info-6" 99976 3029 "Funções e Variáveis Definidas para solve_rec"))
("solve_rec_rat" . ("maxima.info-6" 103038 879 "Funções e Variáveis Definidas para solve_rec"))
("solvedecomposes" . ("maxima.info-2" 239607 178 "Funções e Variáveis Definidas para Equações"))
("solveexplicit" . ("maxima.info-2" 239792 223 "Funções e Variáveis Definidas para Equações"))
("solvefactors" . ("maxima.info-2" 240030 240 "Funções e Variáveis Definidas para Equações"))
("solvenullwarn" . ("maxima.info-2" 240283 302 "Funções e Variáveis Definidas para Equações"))
("solveradcan" . ("maxima.info-2" 240595 245 "Funções e Variáveis Definidas para Equações"))
("solvetrigwarn" . ("maxima.info-2" 240848 261 "Funções e Variáveis Definidas para Equações"))
("some" . ("maxima.info-4" 142199 3033 "Funções e Variáveis Definidas para Conjuntos"))
("some <1>" . ("maxima.info-4" 142200 3032 "Funções e Variáveis Definidas para Conjuntos"))
("somrac" . ("maxima.info-3" 293843 247 "Funções e Variáveis Definidas para Simetrias"))
("sort" . ("maxima.info-1" 132951 2419 "Operadores Geral"))
("sort <1>" . ("maxima.info-1" 132952 2418 "Operadores Geral"))
("space" . ("maxima.info-6" 160480 58 "Funções e Variáveis para caracteres"))
("sparse" . ("maxima.info-3" 47699 204 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("specint" . ("maxima.info-2" 114907 1282 "Funções e Variáveis Definidas para Funções Especiais"))
("spherical_bessel_j" . ("maxima.info-6" 48515 186 "Funções e Variáveis Definidas para polinômios ortogonais"))
("spherical_bessel_y" . ("maxima.info-6" 48712 185 "Funções e Variáveis Definidas para polinômios ortogonais"))
("spherical_hankel1" . ("maxima.info-6" 48908 159 "Funções e Variáveis Definidas para polinômios ortogonais"))
("spherical_hankel2" . ("maxima.info-6" 49077 158 "Funções e Variáveis Definidas para polinômios ortogonais"))
("spherical_harmonic" . ("maxima.info-6" 49245 120 "Funções e Variáveis Definidas para polinômios ortogonais"))
("splice" . ("maxima.info-4" 169172 1701 "Macros"))
("split" . ("maxima.info-6" 166387 879 "Funções e Variáveis para seqüências de caracteres"))
("split <1>" . ("maxima.info-6" 166388 878 "Funções e Variáveis para seqüências de caracteres"))
("split <2>" . ("maxima.info-6" 166424 844 "Funções e Variáveis para seqüências de caracteres"))
("sposition" . ("maxima.info-6" 167294 305 "Funções e Variáveis para seqüências de caracteres"))
("sprint" . ("maxima.info-6" 156435 797 "Funções e Variáveis para entrada e saída"))
("sqfr" . ("maxima.info-2" 72392 722 "Funções e Variáveis Definidas para Polinômios"))
("sqrt" . ("maxima.info-1" 135401 359 "Operadores Geral"))
("sqrtdenest" . ("maxima.info-6" 94579 1098 "Funções e Variáveis Definidas para simplification"))
("sqrtdispflag" . ("maxima.info-1" 135771 160 "Operadores Geral"))
("sremove" . ("maxima.info-6" 167607 861 "Funções e Variáveis para seqüências de caracteres"))
("sremove <1>" . ("maxima.info-6" 167608 860 "Funções e Variáveis para seqüências de caracteres"))
("sremove <2>" . ("maxima.info-6" 167653 817 "Funções e Variáveis para seqüências de caracteres"))
("sremove <3>" . ("maxima.info-6" 167706 766 "Funções e Variáveis para seqüências de caracteres"))
("sremovefirst" . ("maxima.info-6" 168492 355 "Funções e Variáveis para seqüências de caracteres"))
("sremovefirst <1>" . ("maxima.info-6" 168493 354 "Funções e Variáveis para seqüências de caracteres"))
("sremovefirst <2>" . ("maxima.info-6" 168543 306 "Funções e Variáveis para seqüências de caracteres"))
("sremovefirst <3>" . ("maxima.info-6" 168601 250 "Funções e Variáveis para seqüências de caracteres"))
("sreverse" . ("maxima.info-6" 168861 142 "Funções e Variáveis para seqüências de caracteres"))
("ssearch" . ("maxima.info-6" 169008 741 "Funções e Variáveis para seqüências de caracteres"))
("ssearch <1>" . ("maxima.info-6" 169009 740 "Funções e Variáveis para seqüências de caracteres"))
("ssearch <2>" . ("maxima.info-6" 169054 697 "Funções e Variáveis para seqüências de caracteres"))
("ssearch <3>" . ("maxima.info-6" 169107 646 "Funções e Variáveis para seqüências de caracteres"))
("ssort" . ("maxima.info-6" 169777 719 "Funções e Variáveis para seqüências de caracteres"))
("ssort <1>" . ("maxima.info-6" 169778 718 "Funções e Variáveis para seqüências de caracteres"))
("sstatus" . ("maxima.info-1" 76415 310 "Funções e Variáveis Definidas para Linha de Comando"))
("ssubst" . ("maxima.info-6" 170514 1102 "Funções e Variáveis para seqüências de caracteres"))
("ssubst <1>" . ("maxima.info-6" 170515 1101 "Funções e Variáveis para seqüências de caracteres"))
("ssubst <2>" . ("maxima.info-6" 170570 1048 "Funções e Variáveis para seqüências de caracteres"))
("ssubst <3>" . ("maxima.info-6" 170633 987 "Funções e Variáveis para seqüências de caracteres"))
("ssubstfirst" . ("maxima.info-6" 171647 428 "Funções e Variáveis para seqüências de caracteres"))
("ssubstfirst <1>" . ("maxima.info-6" 171648 427 "Funções e Variáveis para seqüências de caracteres"))
("ssubstfirst <2>" . ("maxima.info-6" 171708 369 "Funções e Variáveis para seqüências de caracteres"))
("ssubstfirst <3>" . ("maxima.info-6" 171844 237 "Funções e Variáveis para seqüências de caracteres"))
("staircase" . ("maxima.info-5" 245545 3706 "Funções e Variáveis Definidas para dynamics"))
("stardisp" . ("maxima.info-1" 328183 164 "Funções e Variáveis Definidas para Entrada e Saída"))
("stats_numer" . ("maxima.info-6" 112345 292 "Funções e Variáveis Definidas para stats"))
("status" . ("maxima.info-4" 8114 1367 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("status <1>" . ("maxima.info-4" 8115 1366 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("status <2>" . ("maxima.info-4" 8146 1337 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("std" . ("maxima.info-5" 26860 642 "Funções e Variáveis Definidas para estatística descritiva"))
("std <1>" . ("maxima.info-5" 26861 641 "Funções e Variáveis Definidas para estatística descritiva"))
("std1" . ("maxima.info-5" 27514 654 "Funções e Variáveis Definidas para estatística descritiva"))
("std1 <1>" . ("maxima.info-5" 27515 653 "Funções e Variáveis Definidas para estatística descritiva"))
("std_bernoulli" . ("maxima.info-5" 160369 568 "Funções e Variáveis Definidas para distribuições discretas"))
("std_beta" . ("maxima.info-5" 125503 187 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_binomial" . ("maxima.info-5" 152699 219 "Funções e Variáveis Definidas para distribuições discretas"))
("std_chi2" . ("maxima.info-5" 102673 648 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_continuous_uniform" . ("maxima.info-5" 128803 213 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_discrete_uniform" . ("maxima.info-5" 167358 234 "Funções e Variáveis Definidas para distribuições discretas"))
("std_exp" . ("maxima.info-5" 113806 733 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_f" . ("maxima.info-5" 108026 187 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_gamma" . ("maxima.info-5" 121864 189 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_geometric" . ("maxima.info-5" 164060 191 "Funções e Variáveis Definidas para distribuições discretas"))
("std_gumbel" . ("maxima.info-5" 149211 189 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_hypergeometric" . ("maxima.info-5" 170261 267 "Funções e Variáveis Definidas para distribuições discretas"))
("std_laplace" . ("maxima.info-5" 145591 191 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_logistic" . ("maxima.info-5" 131218 194 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_lognormal" . ("maxima.info-5" 118959 195 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_negative_binomial" . ("maxima.info-5" 174429 237 "Funções e Variáveis Definidas para distribuições discretas"))
("std_normal" . ("maxima.info-5" 92921 202 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_pareto" . ("maxima.info-5" 133483 193 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_poisson" . ("maxima.info-5" 156182 185 "Funções e Variáveis Definidas para distribuições discretas"))
("std_rayleigh" . ("maxima.info-5" 141037 847 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_student_t" . ("maxima.info-5" 96564 192 "Funções e Variáveis Definidas para distribuições contínuas"))
("std_weibull" . ("maxima.info-5" 135746 193 "Funções e Variáveis Definidas para distribuições contínuas"))
("stirling" . ("maxima.info-6" 143318 1810 "Funções e Variáveis Definidas para stirling"))
("stirling1" . ("maxima.info-4" 145256 2029 "Funções e Variáveis Definidas para Conjuntos"))
("stirling2" . ("maxima.info-4" 147318 2389 "Funções e Variáveis Definidas para Conjuntos"))
("strim" . ("maxima.info-6" 172090 384 "Funções e Variáveis para seqüências de caracteres"))
("striml" . ("maxima.info-6" 172479 140 "Funções e Variáveis para seqüências de caracteres"))
("strimr" . ("maxima.info-6" 172623 149 "Funções e Variáveis para seqüências de caracteres"))
("string" . ("maxima.info-1" 328356 245 "Funções e Variáveis Definidas para Entrada e Saída"))
("stringdisp" . ("maxima.info-1" 328611 780 "Funções e Variáveis Definidas para Entrada e Saída"))
("stringout" . ("maxima.info-1" 329406 2332 "Funções e Variáveis Definidas para Entrada e Saída"))
("stringout <1>" . ("maxima.info-1" 329407 2331 "Funções e Variáveis Definidas para Entrada e Saída"))
("stringout <2>" . ("maxima.info-1" 329482 2258 "Funções e Variáveis Definidas para Entrada e Saída"))
("stringout <3>" . ("maxima.info-1" 329534 2208 "Funções e Variáveis Definidas para Entrada e Saída"))
("stringout <4>" . ("maxima.info-1" 329581 2163 "Funções e Variáveis Definidas para Entrada e Saída"))
("stringp" . ("maxima.info-6" 161323 144 "Funções e Variáveis para seqüências de caracteres"))
("sublis" . ("maxima.info-1" 135936 204 "Operadores Geral"))
("sublis_apply_lambda" . ("maxima.info-1" 136470 287 "Operadores Geral"))
("sublist" . ("maxima.info-1" 136150 317 "Operadores Geral"))
("sublist_indices" . ("maxima.info-4" 89381 1004 "Funções e Variáveis Definidas para Listas"))
("submatrix" . ("maxima.info-3" 47912 297 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("submatrix <1>" . ("maxima.info-3" 47913 296 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("submatrix <2>" . ("maxima.info-3" 47981 230 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("subsample" . ("maxima.info-5" 17421 6499 "Funções e Variáveis Definidas para manipulação da dados"))
("subsample <1>" . ("maxima.info-5" 17422 6498 "Funções e Variáveis Definidas para manipulação da dados"))
("subset" . ("maxima.info-4" 149745 622 "Funções e Variáveis Definidas para Conjuntos"))
("subsetp" . ("maxima.info-4" 150371 409 "Funções e Variáveis Definidas para Conjuntos"))
("subst" . ("maxima.info-1" 136770 1820 "Operadores Geral"))
("substinpart" . ("maxima.info-1" 138634 2464 "Operadores Geral"))
("substpart" . ("maxima.info-1" 141132 1140 "Operadores Geral"))
("substring" . ("maxima.info-6" 172778 632 "Funções e Variáveis para seqüências de caracteres"))
("substring <1>" . ("maxima.info-6" 172779 631 "Funções e Variáveis para seqüências de caracteres"))
("subvar" . ("maxima.info-2" 289415 697 "Funções e Variáveis Definidas para Arrays"))
("subvarp" . ("maxima.info-1" 142281 165 "Operadores Geral"))
("sum" . ("maxima.info-1" 218523 5289 "Funções e Variáveis Definidas para Expressões"))
("sumcontract" . ("maxima.info-1" 244362 647 "Funções e Variáveis Definidas para Simplificação"))
("sumexpand" . ("maxima.info-1" 245026 961 "Funções e Variáveis Definidas para Simplificação"))
("summand_to_rec" . ("maxima.info-6" 104189 1234 "Funções e Variáveis Definidas para solve_rec"))
("summand_to_rec <1>" . ("maxima.info-6" 104190 1233 "Funções e Variáveis Definidas para solve_rec"))
("sumsplitfact" . ("maxima.info-1" 245993 154 "Funções e Variáveis Definidas para Simplificação"))
("sunlisp" . ("maxima.info-6" 160965 187 "Funções e Variáveis para seqüências de caracteres"))
("supcase" . ("maxima.info-6" 173439 576 "Funções e Variáveis para seqüências de caracteres"))
("supcase <1>" . ("maxima.info-6" 173440 575 "Funções e Variáveis para seqüências de caracteres"))
("supcase <2>" . ("maxima.info-6" 173478 539 "Funções e Variáveis para seqüências de caracteres"))
("supcontext" . ("maxima.info-2" 18236 260 "Funções e Variáveis Definidas para Contextos"))
("supcontext <1>" . ("maxima.info-2" 18237 259 "Funções e Variáveis Definidas para Contextos"))
("surface_hide" . ("maxima.info-5" 213807 557 "Funções e Variáveis Definidas para draw"))
("symbolp" . ("maxima.info-1" 142451 242 "Operadores Geral"))
("symmdifference" . ("maxima.info-4" 150784 1087 "Funções e Variáveis Definidas para Conjuntos"))
("symmetric" . ("maxima.info-1" 246154 228 "Funções e Variáveis Definidas para Simplificação"))
("symmetricp" . ("maxima.info-3" 185742 100 "Funções e Variáveis Definidas para ctensor"))
("system" . ("maxima.info-1" 338130 880 "Funções e Variáveis Definidas para Entrada e Saída"))
("tab" . ("maxima.info-6" 160541 49 "Funções e Variáveis para caracteres"))
("take_inference" . ("maxima.info-6" 110133 1878 "Funções e Variáveis Definidas para inference_result"))
("take_inference <1>" . ("maxima.info-6" 110134 1877 "Funções e Variáveis Definidas para inference_result"))
("take_inference <2>" . ("maxima.info-6" 110176 1837 "Funções e Variáveis Definidas para inference_result"))
("tan" . ("maxima.info-2" 92448 39 "Funções e Variáveis Definidas para Trigonometria"))
("tanh" . ("maxima.info-2" 92490 52 "Funções e Variáveis Definidas para Trigonometria"))
("taylor" . ("maxima.info-3" 237897 7981 "Funções e Variáveis Definidas para Séries"))
("taylor <1>" . ("maxima.info-3" 237898 7980 "Funções e Variáveis Definidas para Séries"))
("taylor <2>" . ("maxima.info-3" 237943 7937 "Funções e Variáveis Definidas para Séries"))
("taylor <3>" . ("maxima.info-3" 238004 7878 "Funções e Variáveis Definidas para Séries"))
("taylor <4>" . ("maxima.info-3" 238131 7755 "Funções e Variáveis Definidas para Séries"))
("taylor_logexpand" . ("maxima.info-3" 247199 687 "Funções e Variáveis Definidas para Séries"))
("taylor_order_coefficients" . ("maxima.info-3" 247910 296 "Funções e Variáveis Definidas para Séries"))
("taylor_simplifier" . ("maxima.info-3" 248216 132 "Funções e Variáveis Definidas para Séries"))
("taylor_truncate_polynomials" . ("maxima.info-3" 248355 316 "Funções e Variáveis Definidas para Séries"))
("taylordepth" . ("maxima.info-3" 245931 233 "Funções e Variáveis Definidas para Séries"))
("taylorinfo" . ("maxima.info-3" 246172 897 "Funções e Variáveis Definidas para Séries"))
("taylorp" . ("maxima.info-3" 247079 116 "Funções e Variáveis Definidas para Séries"))
("taytorat" . ("maxima.info-3" 248684 198 "Funções e Variáveis Definidas para Séries"))
("tcl_output" . ("maxima.info-1" 319099 1199 "Funções e Variáveis Definidas para Entrada e Saída"))
("tcl_output <1>" . ("maxima.info-1" 319100 1198 "Funções e Variáveis Definidas para Entrada e Saída"))
("tcl_output <2>" . ("maxima.info-1" 319148 1152 "Funções e Variáveis Definidas para Entrada e Saída"))
("tcontract" . ("maxima.info-3" 281269 212 "Funções e Variáveis Definidas para Simetrias"))
("tellrat" . ("maxima.info-2" 73133 2301 "Funções e Variáveis Definidas para Polinômios"))
("tellrat <1>" . ("maxima.info-2" 73134 2300 "Funções e Variáveis Definidas para Polinômios"))
("tellsimp" . ("maxima.info-4" 64212 2478 "Funções e Variáveis Definidas para Regras e Modelos"))
("tellsimpafter" . ("maxima.info-4" 66715 9912 "Funções e Variáveis Definidas para Regras e Modelos"))
("tensorkill" . ("maxima.info-3" 207090 200 "Funções e Variáveis Definidas para ctensor"))
("tentex" . ("maxima.info-3" 140580 1078 "Funções e Variáveis Definidas para itensor"))
("tenth" . ("maxima.info-4" 90392 126 "Funções e Variáveis Definidas para Listas"))
("terminal" . ("maxima.info-5" 180723 1095 "Funções e Variáveis Definidas para draw"))
("test_mean" . ("maxima.info-6" 112649 4586 "Funções e Variáveis Definidas para stats"))
("test_mean <1>" . ("maxima.info-6" 112650 4585 "Funções e Variáveis Definidas para stats"))
("test_means_difference" . ("maxima.info-6" 117312 5064 "Funções e Variáveis Definidas para stats"))
("test_means_difference <1>" . ("maxima.info-6" 117313 5063 "Funções e Variáveis Definidas para stats"))
("test_normality" . ("maxima.info-6" 136183 1078 "Funções e Variáveis Definidas para stats"))
("test_rank_sum" . ("maxima.info-6" 133336 2802 "Funções e Variáveis Definidas para stats"))
("test_rank_sum <1>" . ("maxima.info-6" 133337 2801 "Funções e Variáveis Definidas para stats"))
("test_sign" . ("maxima.info-6" 128061 1994 "Funções e Variáveis Definidas para stats"))
("test_sign <1>" . ("maxima.info-6" 128062 1993 "Funções e Variáveis Definidas para stats"))
("test_signed_rank" . ("maxima.info-6" 130097 3192 "Funções e Variáveis Definidas para stats"))
("test_signed_rank <1>" . ("maxima.info-6" 130098 3191 "Funções e Variáveis Definidas para stats"))
("test_variance" . ("maxima.info-6" 122471 2630 "Funções e Variáveis Definidas para stats"))
("test_variance <1>" . ("maxima.info-6" 122472 2629 "Funções e Variáveis Definidas para stats"))
("test_variance_ratio" . ("maxima.info-6" 125165 2828 "Funções e Variáveis Definidas para stats"))
("test_variance_ratio <1>" . ("maxima.info-6" 125166 2827 "Funções e Variáveis Definidas para stats"))
("testsuite_files" . ("maxima.info-1" 24838 712 "Definições para Detecção e Relato de Erros"))
("tex" . ("maxima.info-1" 331797 2101 "Funções e Variáveis Definidas para Entrada e Saída"))
("tex <1>" . ("maxima.info-1" 331798 2100 "Funções e Variáveis Definidas para Entrada e Saída"))
("tex <2>" . ("maxima.info-1" 331825 2075 "Funções e Variáveis Definidas para Entrada e Saída"))
("tex <3>" . ("maxima.info-1" 331855 2048 "Funções e Variáveis Definidas para Entrada e Saída"))
("texput" . ("maxima.info-1" 333953 4132 "Funções e Variáveis Definidas para Entrada e Saída"))
("texput <1>" . ("maxima.info-1" 333954 4131 "Funções e Variáveis Definidas para Entrada e Saída"))
("texput <2>" . ("maxima.info-1" 333986 4101 "Funções e Variáveis Definidas para Entrada e Saída"))
("texput <3>" . ("maxima.info-1" 334035 4054 "Funções e Variáveis Definidas para Entrada e Saída"))
("third" . ("maxima.info-4" 90523 130 "Funções e Variáveis Definidas para Listas"))
("throw" . ("maxima.info-4" 249035 183 "Funções e Variáveis Definidas para Fluxo de Programa"))
("time" . ("maxima.info-4" 9517 565 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("timedate" . ("maxima.info-4" 10097 604 "Funções e Variáveis Definidas para Ambiente em Tempo de Execução"))
("timer" . ("maxima.info-4" 265847 1328 "Funções e Variáveis Definidas para Depuração"))
("timer <1>" . ("maxima.info-4" 265848 1327 "Funções e Variáveis Definidas para Depuração"))
("timer <2>" . ("maxima.info-4" 265888 1289 "Funções e Variáveis Definidas para Depuração"))
("timer_devalue" . ("maxima.info-4" 268029 490 "Funções e Variáveis Definidas para Depuração"))
("timer_info" . ("maxima.info-4" 268539 837 "Funções e Variáveis Definidas para Depuração"))
("timer_info <1>" . ("maxima.info-4" 268540 836 "Funções e Variáveis Definidas para Depuração"))
("title" . ("maxima.info-5" 182217 500 "Funções e Variáveis Definidas para draw"))
("tldefint" . ("maxima.info-2" 177311 116 "Funções e Variáveis Definidas para Integração"))
("tlimit" . ("maxima.info-2" 127540 176 "Funções e Variáveis Definidas para Limites"))
("tlimit <1>" . ("maxima.info-2" 127541 175 "Funções e Variáveis Definidas para Limites"))
("tlimit <2>" . ("maxima.info-2" 127590 128 "Funções e Variáveis Definidas para Limites"))
("tlimswitch" . ("maxima.info-2" 127723 166 "Funções e Variáveis Definidas para Limites"))
("to_lisp" . ("maxima.info-1" 76730 111 "Funções e Variáveis Definidas para Linha de Comando"))
("todd_coxeter" . ("maxima.info-4" 456 1757 "Funções e Variáveis Definidas para Grupos"))
("todd_coxeter <1>" . ("maxima.info-4" 457 1756 "Funções e Variáveis Definidas para Grupos"))
("toeplitz" . ("maxima.info-5" 325912 825 "Funções e Variáveis Definidas para linearalgebra"))
("toeplitz <1>" . ("maxima.info-5" 325913 824 "Funções e Variáveis Definidas para linearalgebra"))
("tokens" . ("maxima.info-6" 174037 868 "Funções e Variáveis para seqüências de caracteres"))
("tokens <1>" . ("maxima.info-6" 174038 867 "Funções e Variáveis para seqüências de caracteres"))
("totaldisrep" . ("maxima.info-2" 75464 440 "Funções e Variáveis Definidas para Polinômios"))
("totalfourier" . ("maxima.info-2" 269975 126 "Funções e Variáveis Definidas para Séries de Fourier"))
("totient" . ("maxima.info-3" 267683 131 "Funções e Variáveis Definidas para Teoria dos Números"))
("tpartpol" . ("maxima.info-3" 281493 213 "Funções e Variáveis Definidas para Simetrias"))
("tr" . ("maxima.info-3" 206637 119 "Funções e Variáveis Definidas para ctensor"))
("tr_array_as_ref" . ("maxima.info-4" 219493 429 "Funções e Variáveis para Definição de Função"))
("tr_bound_function_applyp" . ("maxima.info-4" 219985 395 "Funções e Variáveis para Definição de Função"))
("tr_file_tty_messagesp" . ("maxima.info-4" 220443 335 "Funções e Variáveis para Definição de Função"))
("tr_float_can_branch_complex" . ("maxima.info-4" 220842 574 "Funções e Variáveis para Definição de Função"))
("tr_function_call_default" . ("maxima.info-4" 221479 719 "Funções e Variáveis para Definição de Função"))
("tr_numer" . ("maxima.info-4" 222255 153 "Funções e Variáveis para Definição de Função"))
("tr_optimize_max_loop" . ("maxima.info-4" 222460 278 "Funções e Variáveis para Definição de Função"))
("tr_semicompile" . ("maxima.info-4" 222794 214 "Funções e Variáveis para Definição de Função"))
("tr_state_vars" . ("maxima.info-4" 223056 519 "Funções e Variáveis para Definição de Função"))
("tr_warn_bad_function_calls" . ("maxima.info-4" 223783 215 "Funções e Variáveis para Definição de Função"))
("tr_warn_fexpr" . ("maxima.info-4" 224050 227 "Funções e Variáveis para Definição de Função"))
("tr_warn_meval" . ("maxima.info-4" 224315 152 "Funções e Variáveis para Definição de Função"))
("tr_warn_mode" . ("maxima.info-4" 224503 126 "Funções e Variáveis para Definição de Função"))
("tr_warn_undeclared" . ("maxima.info-4" 224679 116 "Funções e Variáveis para Definição de Função"))
("tr_warn_undefined_variable" . ("maxima.info-4" 224853 104 "Funções e Variáveis para Definição de Função"))
("tr_warnings_get" . ("maxima.info-4" 223620 106 "Funções e Variáveis para Definição de Função"))
("trace" . ("maxima.info-4" 269409 1277 "Funções e Variáveis Definidas para Depuração"))
("trace <1>" . ("maxima.info-4" 269410 1276 "Funções e Variáveis Definidas para Depuração"))
("trace <2>" . ("maxima.info-4" 269450 1238 "Funções e Variáveis Definidas para Depuração"))
("trace_options" . ("maxima.info-4" 270743 2336 "Funções e Variáveis Definidas para Depuração"))
("trace_options <1>" . ("maxima.info-4" 270744 2335 "Funções e Variáveis Definidas para Depuração"))
("tracematrix" . ("maxima.info-6" 82872 185 "Funções e Variáveis Definidas para simplification"))
("transcompile" . ("maxima.info-4" 213902 245 "Funções e Variáveis para Definição de Função"))
("translate" . ("maxima.info-4" 214202 2402 "Funções e Variáveis para Definição de Função"))
("translate <1>" . ("maxima.info-4" 214238 2370 "Funções e Variáveis para Definição de Função"))
("translate <2>" . ("maxima.info-4" 214268 2342 "Funções e Variáveis para Definição de Função"))
("translate_file" . ("maxima.info-4" 216758 2394 "Funções e Variáveis para Definição de Função"))
("translate_file <1>" . ("maxima.info-4" 216830 2324 "Funções e Variáveis para Definição de Função"))
("transparent" . ("maxima.info-5" 200723 519 "Funções e Variáveis Definidas para draw"))
("transpose" . ("maxima.info-3" 48218 401 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("transrun" . ("maxima.info-4" 219231 210 "Funções e Variáveis para Definição de Função"))
("tree_reduce" . ("maxima.info-4" 151878 1407 "Funções e Variáveis Definidas para Conjuntos"))
("tree_reduce <1>" . ("maxima.info-4" 151879 1406 "Funções e Variáveis Definidas para Conjuntos"))
("treillis" . ("maxima.info-3" 290664 227 "Funções e Variáveis Definidas para Simetrias"))
("treinat" . ("maxima.info-3" 290897 546 "Funções e Variáveis Definidas para Simetrias"))
("triangularize" . ("maxima.info-3" 48629 1054 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("trigexpand" . ("maxima.info-2" 92546 1491 "Funções e Variáveis Definidas para Trigonometria"))
("trigexpandplus" . ("maxima.info-2" 94070 342 "Funções e Variáveis Definidas para Trigonometria"))
("trigexpandtimes" . ("maxima.info-2" 94421 346 "Funções e Variáveis Definidas para Trigonometria"))
("triginverses" . ("maxima.info-2" 94774 483 "Funções e Variáveis Definidas para Trigonometria"))
("trigrat" . ("maxima.info-2" 97004 2531 "Funções e Variáveis Definidas para Trigonometria"))
("trigreduce" . ("maxima.info-2" 95279 1030 "Funções e Variáveis Definidas para Trigonometria"))
("trigreduce <1>" . ("maxima.info-2" 95280 1029 "Funções e Variáveis Definidas para Trigonometria"))
("trigsign" . ("maxima.info-2" 96334 261 "Funções e Variáveis Definidas para Trigonometria"))
("trigsimp" . ("maxima.info-2" 96606 392 "Funções e Variáveis Definidas para Trigonometria"))
("trivial_solutions" . ("maxima.info-6" 207122 229 "Funções e Variáveis Definidas para zeilberger"))
("true" . ("maxima.info-2" 79727 139 "Funções e Variáveis Definidas para Constantes"))
("trunc" . ("maxima.info-3" 248889 576 "Funções e Variáveis Definidas para Séries"))
("ttyoff" . ("maxima.info-1" 339031 359 "Funções e Variáveis Definidas para Entrada e Saída"))
("ueivects" . ("maxima.info-3" 49697 1239 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("ufg" . ("maxima.info-3" 204478 157 "Funções e Variáveis Definidas para ctensor"))
("uforget" . ("maxima.info-6" 184620 1373 "Funções e Variáveis Definidas para Units"))
("ug" . ("maxima.info-3" 205512 85 "Funções e Variáveis Definidas para ctensor"))
("ultraspherical" . ("maxima.info-6" 49674 213 "Funções e Variáveis Definidas para polinômios ortogonais"))
("undiff" . ("maxima.info-3" 104066 509 "Funções e Variáveis Definidas para itensor"))
("union" . ("maxima.info-4" 153318 981 "Funções e Variáveis Definidas para Conjuntos"))
("unit_step" . ("maxima.info-6" 49373 290 "Funções e Variáveis Definidas para polinômios ortogonais"))
("uniteigenvectors" . ("maxima.info-3" 49696 1240 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("unitvector" . ("maxima.info-3" 50971 226 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("unknown" . ("maxima.info-1" 246391 154 "Funções e Variáveis Definidas para Simplificação"))
("unorder" . ("maxima.info-1" 142699 828 "Operadores Geral"))
("unsum" . ("maxima.info-3" 249475 1229 "Funções e Variáveis Definidas para Séries"))
("untellrat" . ("maxima.info-2" 75918 101 "Funções e Variáveis Definidas para Polinômios"))
("untimer" . ("maxima.info-4" 267222 781 "Funções e Variáveis Definidas para Depuração"))
("untimer <1>" . ("maxima.info-4" 267223 780 "Funções e Variáveis Definidas para Depuração"))
("untrace" . ("maxima.info-4" 273157 387 "Funções e Variáveis Definidas para Depuração"))
("untrace <1>" . ("maxima.info-4" 273158 386 "Funções e Variáveis Definidas para Depuração"))
("uppercasep" . ("maxima.info-6" 160594 106 "Funções e Variáveis para caracteres"))
("uric" . ("maxima.info-3" 205241 91 "Funções e Variáveis Definidas para ctensor"))
("uricci" . ("maxima.info-3" 159102 536 "Funções e Variáveis Definidas para ctensor"))
("uriem" . ("maxima.info-3" 205054 101 "Funções e Variáveis Definidas para ctensor"))
("uriemann" . ("maxima.info-3" 162651 201 "Funções e Variáveis Definidas para ctensor"))
("use_fast_arrays" . ("maxima.info-2" 290119 1531 "Funções e Variáveis Definidas para Arrays"))
("user_preamble" . ("maxima.info-5" 187628 882 "Funções e Variáveis Definidas para draw"))
("usersetunits" . ("maxima.info-6" 189630 8835 "Funções e Variáveis Definidas para Units"))
("uvect" . ("maxima.info-3" 50972 225 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("values" . ("maxima.info-1" 76844 240 "Funções e Variáveis Definidas para Linha de Comando"))
("vandermonde_matrix" . ("maxima.info-5" 326746 160 "Funções e Variáveis Definidas para linearalgebra"))
("var" . ("maxima.info-5" 25332 628 "Funções e Variáveis Definidas para estatística descritiva"))
("var <1>" . ("maxima.info-5" 25333 627 "Funções e Variáveis Definidas para estatística descritiva"))
("var1" . ("maxima.info-5" 25965 887 "Funções e Variáveis Definidas para estatística descritiva"))
("var1 <1>" . ("maxima.info-5" 25966 886 "Funções e Variáveis Definidas para estatística descritiva"))
("var_bernoulli" . ("maxima.info-5" 159799 555 "Funções e Variáveis Definidas para distribuições discretas"))
("var_beta" . ("maxima.info-5" 125318 177 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_binomial" . ("maxima.info-5" 152476 215 "Funções e Variáveis Definidas para distribuições discretas"))
("var_chi2" . ("maxima.info-5" 102022 634 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_continuous_uniform" . ("maxima.info-5" 128586 209 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_discrete_uniform" . ("maxima.info-5" 167120 230 "Funções e Variáveis Definidas para distribuições discretas"))
("var_exp" . ("maxima.info-5" 113024 767 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_f" . ("maxima.info-5" 107835 183 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_gamma" . ("maxima.info-5" 121671 185 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_geometric" . ("maxima.info-5" 163865 187 "Funções e Variáveis Definidas para distribuições discretas"))
("var_gumbel" . ("maxima.info-5" 149024 179 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_hypergeometric" . ("maxima.info-5" 169983 268 "Funções e Variáveis Definidas para distribuições discretas"))
("var_laplace" . ("maxima.info-5" 145396 187 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_logistic" . ("maxima.info-5" 131020 190 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_lognormal" . ("maxima.info-5" 118760 191 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_negative_binomial" . ("maxima.info-5" 174188 233 "Funções e Variáveis Definidas para distribuições discretas"))
("var_normal" . ("maxima.info-5" 92713 200 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_pareto" . ("maxima.info-5" 133286 189 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_poisson" . ("maxima.info-5" 155999 175 "Funções e Variáveis Definidas para distribuições discretas"))
("var_rayleigh" . ("maxima.info-5" 140152 870 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_student_t" . ("maxima.info-5" 96227 331 "Funções e Variáveis Definidas para distribuições contínuas"))
("var_weibull" . ("maxima.info-5" 135549 189 "Funções e Variáveis Definidas para distribuições contínuas"))
("vect_cross" . ("maxima.info-3" 52576 235 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("vectorpotential" . ("maxima.info-1" 143537 322 "Operadores Geral"))
("vectorsimp" . ("maxima.info-3" 51210 1355 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("verbify" . ("maxima.info-1" 224571 376 "Funções e Variáveis Definidas para Expressões"))
("verbose" . ("maxima.info-3" 250712 145 "Funções e Variáveis Definidas para Séries"))
("vers" . ("maxima.info-6" 86015 132 "Funções e Variáveis Definidas para simplification"))
("warnings" . ("maxima.info-6" 206675 177 "Funções e Variáveis Definidas para zeilberger"))
("weyl" . ("maxima.info-3" 205601 73 "Funções e Variáveis Definidas para ctensor"))
("weyl <1>" . ("maxima.info-3" 163132 472 "Funções e Variáveis Definidas para ctensor"))
("while" . ("maxima.info-4" 249223 45 "Funções e Variáveis Definidas para Fluxo de Programa"))
("with_stdout" . ("maxima.info-1" 339410 1149 "Funções e Variáveis Definidas para Entrada e Saída"))
("write_data" . ("maxima.info-6" 18904 919 "Funções e Variáveis Definidas para numericalio"))
("write_data <1>" . ("maxima.info-6" 18905 918 "Funções e Variáveis Definidas para numericalio"))
("writefile" . ("maxima.info-1" 340573 1300 "Funções e Variáveis Definidas para Entrada e Saída"))
("wronskian" . ("maxima.info-6" 82349 504 "Funções e Variáveis Definidas para simplification"))
("xlabel" . ("maxima.info-5" 182743 554 "Funções e Variáveis Definidas para draw"))
("xrange" . ("maxima.info-5" 177441 606 "Funções e Variáveis Definidas para draw"))
("xreduce" . ("maxima.info-4" 154304 1752 "Funções e Variáveis Definidas para Conjuntos"))
("xreduce <1>" . ("maxima.info-4" 154305 1751 "Funções e Variáveis Definidas para Conjuntos"))
("xthru" . ("maxima.info-1" 143870 1239 "Operadores Geral"))
("xtics" . ("maxima.info-5" 184550 456 "Funções e Variáveis Definidas para draw"))
("xu_grid" . ("maxima.info-5" 212587 594 "Funções e Variáveis Definidas para draw"))
("xy_file" . ("maxima.info-5" 187221 384 "Funções e Variáveis Definidas para draw"))
("ylabel" . ("maxima.info-5" 183323 555 "Funções e Variáveis Definidas para draw"))
("yrange" . ("maxima.info-5" 178066 643 "Funções e Variáveis Definidas para draw"))
("ytics" . ("maxima.info-5" 185026 450 "Funções e Variáveis Definidas para draw"))
("yv_grid" . ("maxima.info-5" 213197 594 "Funções e Variáveis Definidas para draw"))
("zerobern" . ("maxima.info-3" 267819 177 "Funções e Variáveis Definidas para Teoria dos Números"))
("zeroequiv" . ("maxima.info-1" 145121 1128 "Operadores Geral"))
("zerofor" . ("maxima.info-5" 326911 568 "Funções e Variáveis Definidas para linearalgebra"))
("zerofor <1>" . ("maxima.info-5" 326912 567 "Funções e Variáveis Definidas para linearalgebra"))
("zeromatrix" . ("maxima.info-3" 52819 105 "Funções e Variáveis Definidas para Matrizes e Álgebra Linear"))
("zeromatrixp" . ("maxima.info-5" 327490 294 "Funções e Variáveis Definidas para linearalgebra"))
("zeta" . ("maxima.info-3" 268002 660 "Funções e Variáveis Definidas para Teoria dos Números"))
("zeta%pi" . ("maxima.info-3" 268670 611 "Funções e Variáveis Definidas para Teoria dos Números"))
("zlabel" . ("maxima.info-5" 183904 620 "Funções e Variáveis Definidas para draw"))
("zrange" . ("maxima.info-5" 178727 697 "Funções e Variáveis Definidas para draw"))
("ztics" . ("maxima.info-5" 185496 470 "Funções e Variáveis Definidas para draw"))
("|" . ("maxima.info-3" 135288 1389 "Funções e Variáveis Definidas para itensor"))
("~" . ("maxima.info-3" 133665 1614 "Funções e Variáveis Definidas para itensor"))
))
(section-pairs '(
; CONTENT: (<NODE NAME> . (<FILENAME> <BYTE OFFSET> <LENGTH IN CHARACTERS>))
("Arquivos" . ("maxima.info-1" 277869 394))
("Casos de teste para contrib_ode" . ("maxima.info-5" 6629 678))
("Comandos Palavra Chave" . ("maxima.info-4" 260727 2454))
("Comentários" . ("maxima.info-1" 276403 1291))
("Compartilhado" . ("maxima.info-4" 13181 637))
("Complexo" . ("maxima.info-1" 148515 553))
("Definições para Detecção e Relato de Erros" . ("maxima.info-1" 23502 2590))
("Depurando o Código Fonte" . ("maxima.info-4" 256508 3983))
("Descartando" . ("maxima.info-1" 30614 706))
("Desigualdade" . ("maxima.info-1" 157234 176))
("Documentação" . ("maxima.info-1" 31470 942))
("Função" . ("maxima.info-4" 156802 5009))
("Funções e Variáveis Definidas específicas para estatística descritiva de várias variáveis" . ("maxima.info-5" 42552 10156))
("Funções e Variáveis Definidas para Ajuda" . ("maxima.info-1" 32535 7139))
("Funções e Variáveis Definidas para Ambiente em Tempo de Execução" . ("maxima.info-4" 5323 6779))
("Funções e Variáveis Definidas para Arrays" . ("maxima.info-2" 270814 20606))
("Funções e Variáveis Definidas para Conjuntos" . ("maxima.info-4" 101714 53688))
("Funções e Variáveis Definidas para Constantes" . ("maxima.info-2" 76317 3513))
("Funções e Variáveis Definidas para Contextos" . ("maxima.info-2" 5300 12938))
("Funções e Variáveis Definidas para Depuração" . ("maxima.info-4" 263356 9852))
("Funções e Variáveis Definidas para Diferenciação" . ("maxima.info-2" 128280 24312))
("Funções e Variáveis Definidas para Entrada e Saída de Dados" . ("maxima.info-1" 278395 62218))
("Funções e Variáveis Definidas para Equações" . ("maxima.info-2" 200676 40341))
("Funções e Variáveis Definidas para Equações Diferenciais" . ("maxima.info-2" 243037 8184))
("Funções e Variáveis Definidas para Expressões" . ("maxima.info-1" 161982 62015))
("Funções e Variáveis Definidas para Fluxo de Programa" . ("maxima.info-4" 227848 27824))
("Funções e Variáveis Definidas para Funções Afins" . ("maxima.info-3" 54416 5608))
("Funções e Variáveis Definidas para Funções Elípticas" . ("maxima.info-2" 120645 2313))
("Funções e Variáveis Definidas para Funções Especiais" . ("maxima.info-2" 101694 14126))
("Funções e Variáveis Definidas para Grupos" . ("maxima.info-4" 359 1851))
("Funções e Variáveis Definidas para Integrais Elípticas" . ("maxima.info-2" 123249 1735))
("Funções e Variáveis Definidas para Integração" . ("maxima.info-2" 154505 22526))
("Funções e Variáveis Definidas para Limites" . ("maxima.info-2" 125308 2521))
("Funções e Variáveis Definidas para Linha de Comando" . ("maxima.info-1" 49625 26797))
("Funções e Variáveis Definidas para Listas" . ("maxima.info-4" 78236 12211))
("Funções e Variáveis Definidas para Logarítmos" . ("maxima.info-2" 80170 8378))
("Funções e Variáveis Definidas para Matrizes e Álgebra Linear" . ("maxima.info-3" 4215 48928))
("Funções e Variáveis Definidas para Montagem de Gráficos" . ("maxima.info-1" 246919 28456))
("Funções e Variáveis Definidas para Numérico" . ("maxima.info-2" 252787 14135))
("Funções e Variáveis Definidas para Opções Diversas" . ("maxima.info-4" 13964 14684))
("Funções e Variáveis Definidas para Polinômios" . ("maxima.info-2" 22188 52829))
("Funções e Variáveis Definidas para QUADPACK" . ("maxima.info-2" 181823 18170))
("Funções e Variáveis Definidas para Regras e Modelos" . ("maxima.info-4" 30466 45704))
("Funções e Variáveis Definidas para Simetrias" . ("maxima.info-3" 269580 36022))
("Funções e Variáveis Definidas para Simplificação" . ("maxima.info-1" 225288 20673))
("Funções e Variáveis Definidas para Séries" . ("maxima.info-3" 222402 28114))
("Funções e Variáveis Definidas para Séries de Fourier" . ("maxima.info-2" 267384 3078))
("Funções e Variáveis Definidas para Teoria dos Números" . ("maxima.info-3" 251215 17739))
("Funções e Variáveis Definidas para Trigonometria" . ("maxima.info-2" 90202 9130))
("Funções e Variáveis Definidas para Units" . ("maxima.info-6" 179476 20097))
("Funções e Variáveis Definidas para augmented_lagrangian" . ("maxima.info-4" 273921 2357))
("Funções e Variáveis Definidas para bode" . ("maxima.info-4" 276584 3224))
("Funções e Variáveis Definidas para contrib_ode" . ("maxima.info-5" 256 4699))
("Funções e Variáveis Definidas para ctensor" . ("maxima.info-3" 149798 60656))
("Funções e Variáveis Definidas para diag" . ("maxima.info-5" 65538 16869))
("Funções e Variáveis Definidas para distribuições contínuas" . ("maxima.info-5" 91214 57807))
("Funções e Variáveis Definidas para distribuições discretas" . ("maxima.info-5" 150791 25038))
("Funções e Variáveis Definidas para distribuições especiais" . ("maxima.info-6" 141759 1134))
("Funções e Variáveis Definidas para draw" . ("maxima.info-5" 177348 59488))
("Funções e Variáveis Definidas para dynamics" . ("maxima.info-5" 240179 8935))
("Funções e Variáveis Definidas para estatística descritiva" . ("maxima.info-5" 24281 17794))
("Funções e Variáveis Definidas para eval_string" . ("maxima.info-5" 249625 1607))
("Funções e Variáveis Definidas para f90" . ("maxima.info-5" 251517 1755))
("Funções e Variáveis Definidas para ggf" . ("maxima.info-5" 253532 1783))
("Funções e Variáveis Definidas para grobner" . ("maxima.info-5" 257846 13484))
("Funções e Variáveis Definidas para gráficos estatísticos" . ("maxima.info-5" 53038 11932))
("Funções e Variáveis Definidas para impdiff" . ("maxima.info-5" 271932 544))
("Funções e Variáveis Definidas para implicit_plot" . ("maxima.info-5" 272808 1150))
("Funções e Variáveis Definidas para inference_result" . ("maxima.info-6" 107187 4767))
("Funções e Variáveis Definidas para interpol" . ("maxima.info-5" 274720 9575))
("Funções e Variáveis Definidas para itensor" . ("maxima.info-3" 73100 70624))
("Funções e Variáveis Definidas para lbfgs" . ("maxima.info-5" 285849 9344))
("Funções e Variáveis Definidas para lindstedt" . ("maxima.info-5" 295585 1493))
("Funções e Variáveis Definidas para linearalgebra" . ("maxima.info-5" 301994 25390))
("Funções e Variáveis Definidas para lsquares" . ("maxima.info-6" 356 9143))
("Funções e Variáveis Definidas para makeOrders" . ("maxima.info-6" 9944 940))
("Funções e Variáveis Definidas para manipulação da dados" . ("maxima.info-5" 15313 8576))
("Funções e Variáveis Definidas para mnewton" . ("maxima.info-6" 11168 1611))
("Funções e Variáveis Definidas para numericalio" . ("maxima.info-6" 16064 3688))
("Funções e Variáveis Definidas para o Pacote atensor" . ("maxima.info-3" 215811 5480))
("Funções e Variáveis Definidas para opsubst" . ("maxima.info-6" 20109 2392))
("Funções e Variáveis Definidas para plotdf" . ("maxima.info-6" 51713 9732))
("Funções e Variáveis Definidas para polinômios ortogonais" . ("maxima.info-6" 42184 7505))
("Funções e Variáveis Definidas para ponto Flutuante" . ("maxima.info-2" 409 4455))
("Funções e Variáveis Definidas para romberg" . ("maxima.info-6" 61986 6931))
("Funções e Variáveis Definidas para simplex" . ("maxima.info-6" 69875 3808))
("Funções e Variáveis Definidas para simplification" . ("maxima.info-6" 74566 20655))
("Funções e Variáveis Definidas para solve_rec" . ("maxima.info-6" 96768 8580))
("Funções e Variáveis Definidas para stats" . ("maxima.info-6" 112250 28810))
("Funções e Variáveis Definidas para stirling" . ("maxima.info-6" 143217 1908))
("Funções e Variáveis Definidas para zeilberger" . ("maxima.info-6" 202308 5888))
("Funções e Variáveis para Definição de Função" . ("maxima.info-4" 171020 54822))
("Funções e Variáveis para caracteres" . ("maxima.info-6" 157447 3174))
("Funções e Variáveis para entrada e saída" . ("maxima.info-6" 150813 6307))
("Funções e Variáveis para seqüências de caracteres" . ("maxima.info-6" 160850 13684))
("Identificadores" . ("maxima.info-1" 151861 2225))
("Interrupções" . ("maxima.info-4" 4054 1074))
("Introdução a Ambiente em Tempo de Execução" . ("maxima.info-4" 2769 1044))
("Introdução a Conjuntos" . ("maxima.info-4" 91028 10386))
("Introdução a Definição de Função" . ("maxima.info-4" 156589 77))
("Introdução a Equações Diferenciais" . ("maxima.info-2" 242368 475))
("Introdução a Expressões" . ("maxima.info-1" 146798 1567))
("Introdução a Fluxo de Programa" . ("maxima.info-4" 227522 171))
("Introdução a Funções Elípticas e Integrais" . ("maxima.info-2" 116691 3657))
("Introdução a Funções Especiais" . ("maxima.info-2" 100007 1482))
("Introdução a Integração" . ("maxima.info-2" 153455 852))
("Introdução a Linha de Comando" . ("maxima.info-1" 40152 9167))
("Introdução a Listas" . ("maxima.info-4" 77319 783))
("Introdução a Matrizes e Álgebra Linear" . ("maxima.info-3" 628 176))
("Introdução a Numérico" . ("maxima.info-2" 251838 55))
("Introdução a Opções Diversas" . ("maxima.info-4" 12714 277))
("Introdução a Polinômios" . ("maxima.info-2" 18871 3071))
("Introdução a QUADPACK" . ("maxima.info-2" 177615 3964))
("Introdução a Regras e Modelos" . ("maxima.info-4" 29351 940))
("Introdução a Séries" . ("maxima.info-3" 221828 429))
("Introdução a Units" . ("maxima.info-6" 175245 4003))
("Introdução a contrib_ode" . ("maxima.info-4" 280322 5431))
("Introdução a ctensor" . ("maxima.info-3" 145197 4425))
("Introdução a distrib" . ("maxima.info-5" 82910 7918))
("Introdução a draw" . ("maxima.info-5" 176859 370))
("Introdução a dynamics" . ("maxima.info-5" 238433 1567))
("Introdução a grobner" . ("maxima.info-5" 255758 1917))
("Introdução a interpol" . ("maxima.info-5" 274322 265))
("Introdução a itensor" . ("maxima.info-3" 60526 12147))
("Introdução a lbfgs" . ("maxima.info-5" 284705 1004))
("Introdução a linearalgebra" . ("maxima.info-5" 297508 4340))
("Introdução a manipulação de seqüências de caracteres" . ("maxima.info-6" 145650 4845))
("Introdução a numericalio" . ("maxima.info-6" 13203 2634))
("Introdução a plotdf" . ("maxima.info-6" 50218 1335))
("Introdução a polinômios ortogonais" . ("maxima.info-6" 22936 18695))
("Introdução a simplex" . ("maxima.info-6" 69401 348))
("Introdução a simplification" . ("maxima.info-6" 74169 242))
("Introdução a solve_rec" . ("maxima.info-6" 96035 600))
("Introdução a stats" . ("maxima.info-6" 105878 1108))
("Introdução a zeilberger" . ("maxima.info-6" 200093 2025))
("Introdução ao Pacote Trigonométrico" . ("maxima.info-2" 89164 865))
("Introdução ao Pacote atensor" . ("maxima.info-3" 211675 3924))
("Introdução ao pacote descriptive" . ("maxima.info-5" 9542 5471))
("Lisp e Maxima" . ("maxima.info-1" 26530 3887))
("Macros" . ("maxima.info-4" 162121 8591))
("N-Argumentos" . ("maxima.info-1" 77596 500))
("Operador Préfixado" . ("maxima.info-1" 79382 294))
("Operador Pósfixado" . ("maxima.info-1" 78845 397))
("Operador não fixado" . ("maxima.info-1" 78230 476))
("Operadores Aritméticos" . ("maxima.info-1" 79816 8320))
("Operadores Geral" . ("maxima.info-1" 88659 56687))
("Operadores Relacionais" . ("maxima.info-1" 88443 122))
("Pacotes de Fourier" . ("maxima.info-2" 252049 526))
("Possibilidades de melhorias em contrib_ode" . ("maxima.info-5" 5250 1170))
("Referências bibliográficas para contrib_ode" . ("maxima.info-5" 7462 1443))
("Seqüências de caracteres" . ("maxima.info-1" 154228 2816))
("Sintaxe" . ("maxima.info-1" 157547 4238))
("Substantivos e Verbos" . ("maxima.info-1" 149203 2483))
)))
(load-info-hashtables (maxima::maxima-load-pathname-directory) deffn-defvr-pairs section-pairs))
